@@ -38,11 +38,29 @@
 #include <stddef.h>
 /* JSON-C */
 #include <json-c/json.h>
+/* GSL */
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
+/* PROJ */
+#include <proj.h>
 /* PostgreSQL */
 /* MEOS */
 #include <meos.h>
 #include "general/meos_catalog.h" /* For meosType */
 
+/*****************************************************************************
+ * Internal function accessing the Gnu Scientic Library (GSL)
+ *****************************************************************************/
+
+extern gsl_rng *gsl_get_generation_rng(void);
+extern gsl_rng *gsl_get_aggregation_rng(void);
+
+/*****************************************************************************
+ * Internal function accessing the PROJ library
+ *****************************************************************************/
+
+extern PJ_CONTEXT *proj_get_context(void);
+
 /*****************************************************************************
  * Direct access to a single point in the GSERIALIZED struct
  *****************************************************************************/
@@ -165,6 +183,8 @@
 #define DatumGetTimestampTz(X)((TimestampTz) DatumGetInt64(X))
 #endif /* MEOS */
 
+extern Datum datum_floor(Datum d);
+extern Datum datum_ceil(Datum d);
 extern Datum datum_degrees(Datum d, Datum normalize);
 extern Datum datum_radians(Datum d);
 extern uint32 datum_hash(Datum d, meosType basetype);
@@ -276,15 +296,15 @@ extern char *spanset_out(const SpanSet *ss, int maxdd);
 /* Constructor functions for set and span types */
 
 extern Set *set_cp(const Set *s);
-extern Set *set_make(const Datum *values, int count, meosType basetype, bool ordered);
-extern Set *set_make_exp(const Datum *values, int count, int maxcount, meosType basetype, bool ordered);
-extern Set *set_make_free(Datum *values, int count, meosType basetype, bool ordered);
+extern Set *set_make(const Datum *values, int count, meosType basetype, bool order);
+extern Set *set_make_exp(const Datum *values, int count, int maxcount, meosType basetype, bool order);
+extern Set *set_make_free(Datum *values, int count, meosType basetype, bool order);
 extern Span *span_cp(const Span *s);
 extern Span *span_make(Datum lower, Datum upper, bool lower_inc, bool upper_inc, meosType basetype);
 extern void span_set(Datum lower, Datum upper, bool lower_inc, bool upper_inc, meosType basetype, meosType spantype, Span *s);
 extern SpanSet *spanset_cp(const SpanSet *ss);
-extern SpanSet *spanset_make_exp(Span *spans, int count, int maxcount, bool normalize, bool ordered);
-extern SpanSet *spanset_make_free(Span *spans, int count, bool normalize, bool ordered);
+extern SpanSet *spanset_make_exp(Span *spans, int count, int maxcount, bool normalize, bool order);
+extern SpanSet *spanset_make_free(Span *spans, int count, bool normalize, bool order);
 
 /*****************************************************************************/
 
@@ -318,8 +338,8 @@ extern Datum numspan_width(const Span *s);
 extern Datum numspanset_width(const SpanSet *ss, bool boundspan);
 extern Datum set_end_value(const Set *s);
 extern int set_mem_size(const Set *s);
-extern void set_set_span(const Set *s, Span *sp);
-extern Span *set_span(const Set *s);
+extern void set_set_subspan(const Set *s, int minidx, int maxidx, Span *result);
+extern void set_set_span(const Set *s, Span *result);
 extern Datum set_start_value(const Set *s);
 extern bool set_value_n(const Set *s, int n, Datum *result);
 extern Datum *set_vals(const Set *s);
@@ -355,7 +375,6 @@ extern void tstzspan_set_datespan(const Span *s1, Span *s2);
  *****************************************************************************/
 
 extern int set_cmp_int(const Set *s1, const Set *s2);
-extern bool set_eq_int(const Set *s1, const Set *s2);
 extern int span_cmp_int(const Span *s1, const Span *s2);
 extern bool span_eq_int(const Span *s1, const Span *s2);
 extern int spanset_cmp_int(const SpanSet *ss1, const SpanSet *ss2);
@@ -415,7 +434,6 @@ extern bool right_value_spanset(Datum value, const SpanSet *ss);
 extern bool right_span_value(const Span *s, Datum value);
 extern bool right_spanset_value(const SpanSet *ss, Datum value);
 
-
 /*****************************************************************************/
 
 /* Set functions for set and span types */
@@ -485,7 +503,7 @@ extern void tbox_set(const Span *s, const Span *p, TBox *box);
 extern STBox *box3d_to_stbox(const BOX3D *box);
 extern STBox *gbox_to_stbox(const GBOX *box);
 extern void float_set_tbox(double d, TBox *box);
-extern STBox *gbox_to_stbox(const GBOX *box);
+extern void gbox_set_stbox(const GBOX *box, int srid, STBox *result);
 extern bool geo_set_stbox(const GSERIALIZED *gs, STBox *box);
 extern void geoarr_set_stbox(const Datum *values, int count, STBox *box);
 extern void int_set_tbox(int i, TBox *box);
@@ -510,7 +528,7 @@ extern void tstzspanset_set_tbox(const SpanSet *ss, TBox *box);
 
 /* Transformation functions for box types */
 
-extern TBox *tbox_shift_scale_value(const TBox *box, Datum shift, Datum width, meosType basetype, bool hasshift, bool haswidth);
+extern TBox *tbox_shift_scale_value(const TBox *box, Datum shift, Datum width, bool hasshift, bool haswidth);
 extern void stbox_expand(const STBox *box1, STBox *box2);
 extern void tbox_expand(const TBox *box1, TBox *box2);
 
@@ -561,7 +579,6 @@ extern TSequence *tgeompointseq_from_mfjson(json_object *mfjson, int srid, inter
 extern TSequence *tgeompointseq_in(const char *str, interpType interp);
 extern TSequenceSet *tgeompointseqset_from_mfjson(json_object *mfjson, int srid, interpType interp);
 extern TSequenceSet *tgeompointseqset_in(const char *str);
-extern char *tinstant_as_mfjson(const TInstant *inst, bool with_bbox, int precision, char *srs);
 extern TInstant *tinstant_from_mfjson(json_object *mfjson, bool isgeo, int srid, meosType temptype);
 extern TInstant *tinstant_in(const char *str, meosType temptype);
 extern char *tinstant_out(const TInstant *inst, int maxdd);
@@ -578,11 +595,9 @@ extern char **tpointarr_as_text(const Temporal **temparr, int count, int maxdd,
 extern char *tpointinst_as_mfjson(const TInstant *inst, bool with_bbox, int precision, char *srs);
 extern char *tpointseq_as_mfjson(const TSequence *seq, bool with_bbox, int precision, char *srs);
 extern char *tpointseqset_as_mfjson(const TSequenceSet *ss, bool with_bbox, int precision, char *srs);
-extern char *tsequence_as_mfjson(const TSequence *seq, bool with_bbox, int precision, char *srs);
 extern TSequence *tsequence_from_mfjson(json_object *mfjson, bool isgeo, int srid, meosType temptype, interpType interp);
 extern TSequence *tsequence_in(const char *str, meosType temptype, interpType interp);
 extern char *tsequence_out(const TSequence *seq, int maxdd);
-extern char *tsequenceset_as_mfjson(const TSequenceSet *ss, bool with_bbox, int precision, char *srs);
 extern TSequenceSet *tsequenceset_from_mfjson(json_object *mfjson, bool isgeo, int srid, meosType temptype, interpType interp);
 extern TSequenceSet *tsequenceset_in(const char *str, meosType temptype, interpType interp);
 extern char *tsequenceset_out(const TSequenceSet *ss, int maxdd);
@@ -643,10 +658,9 @@ extern size_t temporal_mem_size(const Temporal *temp);
 extern Datum temporal_min_value(const Temporal *temp);
 extern const TSequence **temporal_seqs(const Temporal *temp, int *count);
 extern void temporal_set_bbox(const Temporal *temp, void *box);
-extern void temporal_set_tstzspan(const Temporal *temp, Span *s);
-extern const TSequence **temporal_seqs(const Temporal *temp, int *count);
 extern Datum temporal_start_value (const Temporal *temp);
 extern Datum *temporal_vals(const Temporal *temp, int *count);
+extern bool temporal_value_n(const Temporal *temp, int n, Datum *result);
 extern Datum *temporal_values(const Temporal *temp, int *count);
 extern uint32 tinstant_hash(const TInstant *inst);
 extern const TInstant **tinstant_insts(const TInstant *inst, int *count);
@@ -671,8 +685,6 @@ extern const TInstant *tsequence_min_inst(const TSequence *seq);
 extern Datum tsequence_min_val(const TSequence *seq);
 extern TSequence **tsequence_segments(const TSequence *seq, int *count);
 extern const TSequence **tsequence_seqs(const TSequence *seq, int *count);
-extern void tsequence_set_bbox(const TSequence *seq, void *box);
-extern void tsequence_expand_bbox(TSequence *seq, const TInstant *inst);
 extern TimestampTz tsequence_start_timestamptz(const TSequence *seq);
 extern SpanSet *tsequence_time(const TSequence *seq);
 extern TimestampTz *tsequence_timestamps(const TSequence *seq, int *count);
@@ -691,20 +703,18 @@ extern int tsequenceset_num_instants(const TSequenceSet *ss);
 extern int tsequenceset_num_timestamps(const TSequenceSet *ss);
 extern TSequence **tsequenceset_segments(const TSequenceSet *ss, int *count);
 extern const TSequence **tsequenceset_seqs(const TSequenceSet *ss);
-extern void tsequenceset_set_bbox(const TSequenceSet *ss, void *box);
 extern TimestampTz tsequenceset_start_timestamptz(const TSequenceSet *ss);
 extern SpanSet *tsequenceset_time(const TSequenceSet *ss);
-extern Interval *tsequenceset_timespan(const TSequenceSet *ss);
 extern bool tsequenceset_timestamptz_n(const TSequenceSet *ss, int n, TimestampTz *result);
 extern TimestampTz *tsequenceset_timestamps(const TSequenceSet *ss, int *count);
 extern bool tsequenceset_value_at_timestamptz(const TSequenceSet *ss, TimestampTz t, bool strict, Datum *result);
+extern bool tsequenceset_value_n(const TSequenceSet *ss, int n, Datum *result);
 extern Datum *tsequenceset_vals(const TSequenceSet *ss, int *count);
 
 /*****************************************************************************/
 
 /* Transformation functions for temporal types */
 
-extern Temporal *temporal_compact(const Temporal *temp);
 extern void temporal_restart(Temporal *temp, int count);
 extern TSequence *temporal_tsequence(const Temporal *temp, interpType interp);
 extern TSequenceSet *temporal_tsequenceset(const Temporal *temp, interpType interp);
@@ -716,7 +726,6 @@ extern Temporal *tnumber_shift_scale_value(const Temporal *temp, Datum shift, Da
 extern TInstant *tnumberinst_shift_value(const TInstant *inst, Datum shift);
 extern TSequence *tnumberseq_shift_scale_value(const TSequence *seq, Datum shift, Datum width, bool hasshift, bool haswidth);
 extern TSequenceSet *tnumberseqset_shift_scale_value(const TSequenceSet *ss, Datum start, Datum width, bool hasshift, bool haswidth);
-extern TSequence *tsequence_compact(const TSequence *seq);
 extern void tsequence_restart(TSequence *seq, int count);
 extern Temporal *tsequence_set_interp(const TSequence *seq, interpType interp);
 extern TSequence *tsequence_shift_scale_time(const TSequence *seq, const Interval *shift, const Interval *duration);
@@ -725,7 +734,6 @@ extern TInstant *tsequence_to_tinstant(const TSequence *seq);
 extern TSequenceSet *tsequence_to_tsequenceset(const TSequence *seq);
 extern TSequenceSet *tsequence_to_tsequenceset_free(TSequence *seq);
 extern TSequenceSet *tsequence_to_tsequenceset_interp(const TSequence *seq, interpType interp);
-extern TSequenceSet *tsequenceset_compact(const TSequenceSet *ss);
 extern void tsequenceset_restart(TSequenceSet *ss, int count);
 extern Temporal *tsequenceset_set_interp(const TSequenceSet *ss, interpType interp);
 extern TSequenceSet *tsequenceset_shift_scale_time(const TSequenceSet *ss, const Interval *start, const Interval *duration);
@@ -742,7 +750,7 @@ extern TSequence *tsequenceset_to_tsequence(const TSequenceSet *ss);
 extern Temporal *tinstant_merge(const TInstant *inst1, const TInstant *inst2);
 extern Temporal *tinstant_merge_array(const TInstant **instants, int count);
 extern Temporal *tsequence_append_tinstant(TSequence *seq, const TInstant *inst, double maxdist, const Interval *maxt, bool expand);
-extern Temporal *tsequence_append_tsequence(TSequence *seq1, const TSequence *seq2, bool expand);
+extern Temporal *tsequence_append_tsequence(const TSequence *seq1, const TSequence *seq2, bool expand);
 extern Temporal *tsequence_delete_timestamptz(const TSequence *seq, TimestampTz t, bool connect);
 extern Temporal *tsequence_delete_tstzset(const TSequence *seq, const Set *s, bool connect);
 extern Temporal *tsequence_delete_tstzspan(const TSequence *seq, const Span *s, bool connect);
@@ -836,71 +844,26 @@ extern bool tsequenceset_eq(const TSequenceSet *ss1, const TSequenceSet *ss2);
 
 extern int always_eq_base_temporal(Datum value, const Temporal *temp);
 extern int always_eq_temporal_base(const Temporal *temp, Datum value);
-extern int always_eq_tinstant_base(const TInstant *inst, Datum value);
-extern int always_eq_tpointinst_base(const TInstant *inst, Datum value);
-extern int always_eq_tpointseq_base(const TSequence *seq, Datum value);
-extern int always_eq_tpointseqset_base(const TSequenceSet *ss, Datum value);
-extern int always_eq_tsequence_base(const TSequence *seq, Datum value);
-extern int always_eq_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int always_ne_base_temporal(Datum value, const Temporal *temp);
 extern int always_ne_temporal_base(const Temporal *temp, Datum value);
-extern int always_ne_tinstant_base(const TInstant *inst, Datum value);
-extern int always_ne_tpointinst_base(const TInstant *inst, Datum value);
-extern int always_ne_tpointseq_base(const TSequence *seq, Datum value);
-extern int always_ne_tpointseqset_base(const TSequenceSet *ss, Datum value);
-extern int always_ne_tsequence_base(const TSequence *seq, Datum value);
-extern int always_ne_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int always_ge_base_temporal(Datum value, const Temporal *temp);
 extern int always_ge_temporal_base(const Temporal *temp, Datum value);
-extern int always_ge_tinstant_base(const TInstant *inst, Datum value);
-extern int always_ge_tsequence_base(const TSequence *seq, Datum value);
-extern int always_ge_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int always_gt_base_temporal(Datum value, const Temporal *temp);
 extern int always_gt_temporal_base(const Temporal *temp, Datum value);
-extern int always_gt_tinstant_base(const TInstant *inst, Datum value);
-extern int always_gt_tsequence_base(const TSequence *seq, Datum value);
-extern int always_gt_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int always_le_base_temporal(Datum value, const Temporal *temp);
 extern int always_le_temporal_base(const Temporal *temp, Datum value);
-extern int always_le_tinstant_base(const TInstant *inst, Datum value);
-extern int always_le_tsequence_base(const TSequence *seq, Datum value);
-extern int always_le_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int always_lt_base_temporal(Datum value, const Temporal *temp);
 extern int always_lt_temporal_base(const Temporal *temp, Datum value);
-extern int always_lt_tinstant_base(const TInstant *inst, Datum value);
-extern int always_lt_tsequence_base(const TSequence *seq, Datum value);
-extern int always_lt_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int ever_eq_base_temporal(Datum value, const Temporal *temp);
 extern int ever_eq_temporal_base(const Temporal *temp, Datum value);
-extern int ever_eq_tinstant_base(const TInstant *inst, Datum value);
-extern int ever_eq_tpointinst_base(const TInstant *inst, Datum value);
-extern int ever_eq_tpointseq_base(const TSequence *seq, Datum value);
-extern int ever_eq_tpointseqset_base(const TSequenceSet *ss, Datum value);
-extern int ever_eq_tsequence_base(const TSequence *seq, Datum value);
-extern int ever_eq_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int ever_ne_base_temporal(Datum value, const Temporal *temp);
 extern int ever_ne_temporal_base(const Temporal *temp, Datum value);
-extern int ever_ne_tinstant_base(const TInstant *inst, Datum value);
-extern int ever_ne_tpointinst_base(const TInstant *inst, Datum value);
-extern int ever_ne_tpointseq_base(const TSequence *seq, Datum value);
-extern int ever_ne_tpointseqset_base(const TSequenceSet *ss, Datum value);
-extern int ever_ne_tsequence_base(const TSequence *seq, Datum value);
-extern int ever_ne_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int ever_ge_base_temporal(Datum value, const Temporal *temp);
 extern int ever_ge_temporal_base(const Temporal *temp, Datum value);
-extern int ever_ge_tinstant_base(const TInstant *inst, Datum value);
-extern int ever_ge_tsequence_base(const TSequence *seq, Datum value);
-extern int ever_ge_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int ever_gt_base_temporal(Datum value, const Temporal *temp);
 extern int ever_gt_temporal_base(const Temporal *temp, Datum value);
-extern int ever_gt_tinstant_base(const TInstant *inst, Datum value);
-extern int ever_gt_tsequence_base(const TSequence *seq, Datum value);
-extern int ever_gt_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int ever_le_base_temporal(Datum value, const Temporal *temp);
 extern int ever_le_temporal_base(const Temporal *temp, Datum value);
-extern int ever_le_tinstant_base(const TInstant *inst, Datum value);
-extern int ever_le_tsequence_base(const TSequence *seq, Datum value);
-extern int ever_le_tsequenceset_base(const TSequenceSet *ss, Datum value);
 extern int ever_lt_base_temporal(Datum value, const Temporal *temp);
 extern int ever_lt_temporal_base(const Temporal *temp, Datum value);
 
@@ -943,6 +906,7 @@ extern double tpointseq_length(const TSequence *seq);
 extern TSequence *tpointseq_speed(const TSequence *seq);
 extern int tpointseq_srid(const TSequence *seq);
 extern STBox *tpointseq_stboxes(const TSequence *seq, int *count);
+extern STBox *tpointseq_split_n_stboxes(const TSequence *seq, int max_count, int *count);
 extern TSequenceSet *tpointseqset_azimuth(const TSequenceSet *ss);
 extern TSequenceSet *tpointseqset_cumulative_length(const TSequenceSet *ss);
 extern bool tpointseqset_is_simple(const TSequenceSet *ss);
@@ -950,6 +914,7 @@ extern double tpointseqset_length(const TSequenceSet *ss);
 extern TSequenceSet *tpointseqset_speed(const TSequenceSet *ss);
 extern int tpointseqset_srid(const TSequenceSet *ss);
 extern STBox *tpointseqset_stboxes(const TSequenceSet *ss, int *count);
+extern STBox *tpointseqset_split_n_stboxes(const TSequenceSet *ss, int max_count, int *count);
 extern GSERIALIZED *tpointseqset_trajectory(const TSequenceSet *ss);
 extern Temporal *tpoint_get_coord(const Temporal *temp, int coord);
 
@@ -991,15 +956,24 @@ extern TSequenceSet *tsequenceset_compact(const TSequenceSet *ss);
 /* Aggregate functions for temporal types */
 
 extern void skiplist_free(SkipList *list);
-extern Temporal *temporal_app_tinst_transfn(Temporal *state, const TInstant *inst, double maxdist, Interval *maxt);
+extern Temporal *temporal_app_tinst_transfn(Temporal *state, const TInstant *inst, double maxdist, const Interval *maxt);
 extern Temporal *temporal_app_tseq_transfn(Temporal *state, const TSequence *seq);
 
 /*****************************************************************************/
 
-/* Multidimensional tiling functions for temporal types */
+/* Tile functions for span and temporal types */
 
-extern Temporal **tnumber_value_split(const Temporal *temp, Datum size, Datum origin, Datum **buckets, int *count);
-extern TBox *tbox_tile(Datum value, TimestampTz t, Datum vsize, Interval *duration, Datum vorigin, TimestampTz torigin, meosType basetype);
+extern Span *numspanset_spans(const SpanSet *ss, Datum vsize, Datum vorigin, int *count);
+extern Span *spanset_time_spans(const SpanSet *ss, const Interval *duration, Datum torigin, int *count);
+extern Span *spanset_value_spans(const SpanSet *ss, Datum vsize, Datum vorigin, int *count);
+extern Span *timespanset_spans(const SpanSet *ss, const Interval *duration, Datum torigin, int *count);
+extern Span *tnumber_value_spans(const Temporal *temp, Datum size, Datum origin, int *count);
+extern TBox *tnumber_value_boxes(const Temporal *temp, Datum vsize, Datum vorigin, int *count);
+extern TBox *tnumber_time_boxes(const Temporal *temp, const Interval *duration, TimestampTz torigin, int *count);
+extern TBox *tnumber_value_time_boxes(const Temporal *temp, Datum vsize, const Interval *duration, Datum vorigin, TimestampTz torigin, int *count);
+extern Temporal **tnumber_value_split(const Temporal *temp, Datum vsize, Datum vorigin, Datum **bins, int *count);
+extern TBox *tbox_get_value_time_tile(Datum value, TimestampTz t, Datum vsize, const Interval *duration, Datum vorigin, TimestampTz torigin, meosType basetype, meosType spantype);
+extern Temporal **tnumber_value_time_split(const Temporal *temp, Datum size, const Interval *duration, Datum vorigin, TimestampTz torigin, Datum **value_bins, TimestampTz **time_bins, int *count);
 
 /*****************************************************************************/
 
