@@ -30,7 +30,7 @@
 /**
  * @file
  * @brief Create a cache of metadata information about temporal types and
- * span types in global arrays
+ * span types in global constant arrays
  */
 
 #include "general/meos_catalog.h"
@@ -40,11 +40,7 @@
 #include <limits.h>
 /* PostgreSQL */
 #include <postgres.h>
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <common/hashfn.h>
-#else
-  #include <access/hash.h>
-#endif
+#include <common/hashfn.h>
 /* MEOS */
 #include <meos.h>
 #include "general/doublen.h"
@@ -53,16 +49,16 @@
 #endif
 
 /*****************************************************************************
- * Global variables
+ * Global constants
  *****************************************************************************/
 
 /**
- * @brief Global array containing the type names corresponding to the
+ * @brief Global constant array containing the type names corresponding to the
  * enumeration meosType defined in file `meos_catalog.h`
  */
-static const char *_MEOSTYPE_NAMES[] =
+static const char *MEOS_TYPE_NAMES[] =
 {
-  [T_UNKNOWN] = "",
+  [T_UNKNOWN] = "unknown",
   [T_BOOL] = "bool",
   [T_DATE] = "date",
   [T_DATEMULTIRANGE] = "datemultirange",
@@ -84,6 +80,8 @@ static const char *_MEOSTYPE_NAMES[] =
   [T_INTSPAN] = "intspan",
   [T_INTSPANSET] = "intspanset",
   [T_INT8] = "int8",
+  [T_INT8MULTIRANGE] = "int8multirange",
+  [T_INT8RANGE] = "int8range",
   [T_BIGINTSET] = "bigintset",
   [T_BIGINTSPAN] = "bigintspan",
   [T_BIGINTSPANSET] = "bigintspanset",
@@ -114,13 +112,15 @@ static const char *_MEOSTYPE_NAMES[] =
   [T_NPOINTSET] = "npointset",
   [T_NSEGMENT] = "nsegment",
   [T_TNPOINT] = "tnpoint",
+  [T_POSE] = "pose",
+  [T_TPOSE] = "tpose",
 };
 
 /**
- * @brief Global array containing the operator names corresponding to the
- * enumeration meosOper defined in file `meos_catalog.h`
+ * @brief Global constant array containing the operator names corresponding to
+ * the enumeration meosOper defined in file `meos_catalog.h`
  */
-static const char *_MEOSOPER_NAMES[] =
+static const char *MEOS_OPER_NAMES[] =
 {
   [UNKNOWN_OP] = "",
   [EQ_OP] = "=",
@@ -167,13 +167,13 @@ static const char *_MEOSOPER_NAMES[] =
   [ALWAYSGE_OP] = "%>=",
 };
 
-#define TEMPSUBTYPE_STR_MAX_LEN 12
+#define TEMPSUBTYPE_STR_MAXLEN 12
 
 /**
- * @brief Global array storing the string representation of the concrete
- * subtypes of temporal types
+ * @brief Global constant array storing the string representation of the
+ * concrete subtypes of temporal types
  */
-static const char *_TEMPSUBTYPE_NAMES[] =
+static const char *MEOS_TEMPSUBTYPE_NAMES[] =
 {
   [ANYTEMPSUBTYPE] = "Any subtype",
   [TINSTANT] = "Instant",
@@ -181,15 +181,15 @@ static const char *_TEMPSUBTYPE_NAMES[] =
   [TSEQUENCESET] = "SequenceSet"
 };
 
-#define INTERP_STR_MAX_LEN 8
+#define INTERP_STR_MAXLEN 8
 
 /**
 
- * @brief Global array containing the interpolation names corresponding to the
- * enumeration interpType defined in file `meos_catalog.h`
+ * @brief Global constant array containing the interpolation names
+ * corresponding to the enumeration interpType defined in file `meos_catalog.h`
  * @note The names are in lowercase since they are used in error messages
  */
-static const char * _INTERPTYPE_NAMES[] =
+static const char * MEOS_INTERPTYPE_NAMES[] =
 {
   [INTERP_NONE] = "None",
   [DISCRETE] = "Discrete",
@@ -200,9 +200,10 @@ static const char * _INTERPTYPE_NAMES[] =
 /*****************************************************************************/
 
 /**
- * @brief Global array that keeps type information for the defined set types
+ * @brief Global constant array that keeps type information for the defined set
+ * types
  */
-static settype_catalog_struct _SETTYPE_CATALOG[] =
+static const settype_catalog_struct MEOS_SETTYPE_CATALOG[] =
 {
   /* settype        basetype */
   {T_INTSET,        T_INT4},
@@ -217,9 +218,10 @@ static settype_catalog_struct _SETTYPE_CATALOG[] =
 };
 
 /**
- * @brief Global array that keeps type information for the defined span types
+ * @brief Global constant array that keeps type information for the defined
+ * span types
  */
-static spantype_catalog_struct _SPANTYPE_CATALOG[] =
+static const spantype_catalog_struct MEOS_SPANTYPE_CATALOG[] =
 {
   /* spantype       basetype */
   {T_INTSPAN,       T_INT4},
@@ -230,9 +232,10 @@ static spantype_catalog_struct _SPANTYPE_CATALOG[] =
 };
 
 /**
- * @brief Global array that keeps type information for the defined span set types
+ * @brief Global constant array that keeps type information for the defined
+ * span set types
  */
-static spansettype_catalog_struct _SPANSETTYPE_CATALOG[] =
+static const spansettype_catalog_struct MEOS_SPANSETTYPE_CATALOG[] =
 {
   /* spansettype    spantype */
   {T_INTSPANSET,    T_INTSPAN},
@@ -243,9 +246,10 @@ static spansettype_catalog_struct _SPANSETTYPE_CATALOG[] =
 };
 
 /**
- * @brief Global array that keeps type information for the defined temporal types
+ * @brief Global constant array that keeps type information for the defined
+ * temporal types
  */
-static temptype_catalog_struct _TEMPTYPE_CATALOG[] =
+static const temptype_catalog_struct MEOS_TEMPTYPE_CATALOG[] =
 {
   /* temptype    basetype */
   {T_TDOUBLE2,   T_DOUBLE2},
@@ -258,6 +262,7 @@ static temptype_catalog_struct _TEMPTYPE_CATALOG[] =
   {T_TGEOMPOINT, T_GEOMETRY},
   {T_TGEOGPOINT, T_GEOGRAPHY},
   {T_TNPOINT,    T_NPOINT},
+  {T_TPOSE,      T_POSE},
 };
 
 /*****************************************************************************/
@@ -268,7 +273,7 @@ static temptype_catalog_struct _TEMPTYPE_CATALOG[] =
 const char *
 meostype_name(meosType type)
 {
-  return _MEOSTYPE_NAMES[type];
+  return MEOS_TYPE_NAMES[type];
 }
 
 /*****************************************************************************/
@@ -280,7 +285,7 @@ meostype_name(meosType type)
 const char *
 tempsubtype_name(tempSubtype subtype)
 {
-  return _TEMPSUBTYPE_NAMES[subtype];
+  return MEOS_TEMPSUBTYPE_NAMES[subtype];
 }
 
 /**
@@ -322,11 +327,11 @@ tempsubtype_from_string(const char *str, int16 *subtype)
   tmpstr[i - tmpstartpos] = '\0';
   size_t len = strlen(tmpstr);
   /* Now check for the type */
-  size_t n = sizeof(_TEMPSUBTYPE_NAMES) / sizeof(char *);
+  size_t n = sizeof(MEOS_TEMPSUBTYPE_NAMES) / sizeof(char *);
   for (i = 0; i < n; i++)
   {
-    if (len == strnlen(_TEMPSUBTYPE_NAMES[i], TEMPSUBTYPE_STR_MAX_LEN) &&
-      ! pg_strncasecmp(tmpstr, _TEMPSUBTYPE_NAMES[i], TEMPSUBTYPE_STR_MAX_LEN))
+    if (len == strnlen(MEOS_TEMPSUBTYPE_NAMES[i], TEMPSUBTYPE_STR_MAXLEN) &&
+      ! pg_strncasecmp(tmpstr, MEOS_TEMPSUBTYPE_NAMES[i], TEMPSUBTYPE_STR_MAXLEN))
     {
       *subtype = i;
       pfree(tmpstr);
@@ -337,7 +342,7 @@ tempsubtype_from_string(const char *str, int16 *subtype)
   return false;
 }
 
-#if DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Ensure that the subtype of a temporal value is valid
  * @note The function is used for the dispatch functions for temporal types
@@ -362,9 +367,7 @@ temptype_subtype_all(tempSubtype subtype)
     return true;
   return false;
 }
-#endif /* DEBUG_BUILD */
-
-
+#endif
 
 /*****************************************************************************/
 
@@ -374,7 +377,7 @@ temptype_subtype_all(tempSubtype subtype)
 const char *
 meosoper_name(meosOper oper)
 {
-  return _MEOSOPER_NAMES[oper];
+  return MEOS_OPER_NAMES[oper];
 }
 
 /**
@@ -384,10 +387,10 @@ meosoper_name(meosOper oper)
 meosOper
 meosoper_from_string(const char *str)
 {
-  int n = sizeof(_MEOSOPER_NAMES) / sizeof(char *);
+  int n = sizeof(MEOS_OPER_NAMES) / sizeof(char *);
   for (int i = 0; i < n; i++)
   {
-    if (strcmp(_MEOSOPER_NAMES[i], str) == 0)
+    if (strcmp(MEOS_OPER_NAMES[i], str) == 0)
       return i;
   }
   return UNKNOWN_OP;
@@ -402,7 +405,7 @@ meosoper_from_string(const char *str)
 const char *
 interptype_name(interpType interp)
 {
-  return _INTERPTYPE_NAMES[interp];
+  return MEOS_INTERPTYPE_NAMES[interp];
 }
 
 /**
@@ -411,11 +414,11 @@ interptype_name(interpType interp)
 interpType
 interptype_from_string(const char *str)
 {
-  int n = sizeof(_INTERPTYPE_NAMES) / sizeof(char *);
+  int n = sizeof(MEOS_INTERPTYPE_NAMES) / sizeof(char *);
   for (int i = 0; i < n; i++)
   {
-    if (pg_strncasecmp(str, _INTERPTYPE_NAMES[i],
-      INTERP_STR_MAX_LEN) == 0)
+    if (pg_strncasecmp(str, MEOS_INTERPTYPE_NAMES[i],
+      INTERP_STR_MAXLEN) == 0)
       return i;
   }
   /* Error */
@@ -434,11 +437,11 @@ interptype_from_string(const char *str)
 meosType
 temptype_basetype(meosType type)
 {
-  int n = sizeof(_TEMPTYPE_CATALOG) / sizeof(temptype_catalog_struct);
+  int n = sizeof(MEOS_TEMPTYPE_CATALOG) / sizeof(temptype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_TEMPTYPE_CATALOG[i].temptype == type)
-      return _TEMPTYPE_CATALOG[i].basetype;
+    if (MEOS_TEMPTYPE_CATALOG[i].temptype == type)
+      return MEOS_TEMPTYPE_CATALOG[i].basetype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -456,11 +459,11 @@ temptype_basetype(meosType type)
 meosType
 settype_basetype(meosType type)
 {
-  int n = sizeof(_SETTYPE_CATALOG) / sizeof(settype_catalog_struct);
+  int n = sizeof(MEOS_SETTYPE_CATALOG) / sizeof(settype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_SETTYPE_CATALOG[i].settype == type)
-      return _SETTYPE_CATALOG[i].basetype;
+    if (MEOS_SETTYPE_CATALOG[i].settype == type)
+      return MEOS_SETTYPE_CATALOG[i].basetype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -474,11 +477,11 @@ settype_basetype(meosType type)
 meosType
 basetype_settype(meosType type)
 {
-  int n = sizeof(_SETTYPE_CATALOG) / sizeof(settype_catalog_struct);
+  int n = sizeof(MEOS_SETTYPE_CATALOG) / sizeof(settype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_SETTYPE_CATALOG[i].basetype == type)
-      return _SETTYPE_CATALOG[i].settype;
+    if (MEOS_SETTYPE_CATALOG[i].basetype == type)
+      return MEOS_SETTYPE_CATALOG[i].settype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -492,11 +495,11 @@ basetype_settype(meosType type)
 meosType
 spantype_basetype(meosType type)
 {
-  int n = sizeof(_SPANTYPE_CATALOG) / sizeof(spantype_catalog_struct);
+  int n = sizeof(MEOS_SPANTYPE_CATALOG) / sizeof(spantype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_SPANTYPE_CATALOG[i].spantype == type)
-      return _SPANTYPE_CATALOG[i].basetype;
+    if (MEOS_SPANTYPE_CATALOG[i].spantype == type)
+      return MEOS_SPANTYPE_CATALOG[i].basetype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -510,11 +513,11 @@ spantype_basetype(meosType type)
 meosType
 spansettype_spantype(meosType type)
 {
-  int n = sizeof(_SPANSETTYPE_CATALOG) / sizeof(spansettype_catalog_struct);
+  int n = sizeof(MEOS_SPANSETTYPE_CATALOG) / sizeof(spansettype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_SPANSETTYPE_CATALOG[i].spansettype == type)
-      return _SPANSETTYPE_CATALOG[i].spantype;
+    if (MEOS_SPANSETTYPE_CATALOG[i].spansettype == type)
+      return MEOS_SPANSETTYPE_CATALOG[i].spantype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -528,11 +531,11 @@ spansettype_spantype(meosType type)
 meosType
 basetype_spantype(meosType type)
 {
-  int n = sizeof(_SPANTYPE_CATALOG) / sizeof(spantype_catalog_struct);
+  int n = sizeof(MEOS_SPANTYPE_CATALOG) / sizeof(spantype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_SPANTYPE_CATALOG[i].basetype == type)
-      return _SPANTYPE_CATALOG[i].spantype;
+    if (MEOS_SPANTYPE_CATALOG[i].basetype == type)
+      return MEOS_SPANTYPE_CATALOG[i].spantype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -546,11 +549,11 @@ basetype_spantype(meosType type)
 meosType
 spantype_spansettype(meosType type)
 {
-  int n = sizeof(_SPANSETTYPE_CATALOG) / sizeof(spansettype_catalog_struct);
+  int n = sizeof(MEOS_SPANSETTYPE_CATALOG) / sizeof(spansettype_catalog_struct);
   for (int i = 0; i < n; i++)
   {
-    if (_SPANSETTYPE_CATALOG[i].spantype == type)
-      return _SPANSETTYPE_CATALOG[i].spansettype;
+    if (MEOS_SPANSETTYPE_CATALOG[i].spantype == type)
+      return MEOS_SPANSETTYPE_CATALOG[i].spansettype;
   }
   /* We only arrive here on error */
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
@@ -560,21 +563,7 @@ spantype_spansettype(meosType type)
 
 /*****************************************************************************/
 
-#if 0 /* not used */
-/**
- * @brief Determine whether the type is an internal MobilityDB type
- */
-bool
-meostype_internal(meosType type)
-{
-  if (type == T_DOUBLE2 || type == T_DOUBLE3 || type == T_DOUBLE4 ||
-      type == T_TDOUBLE2 || type == T_TDOUBLE3 || type == T_TDOUBLE4)
-    return true;
-  return false;
-}
-#endif /* not used */
-
-#ifdef DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Return true if the type is a base type of one of the template types,
  * that is, @p Set, @p Span, @p SpanSet, and @p Temporal
@@ -587,8 +576,8 @@ meos_basetype(meosType type)
     type == T_TEXT || type == T_DATE || type == T_TIMESTAMPTZ ||
     /* The doubleX are internal types used for temporal aggregation */
     type == T_DOUBLE2 || type == T_DOUBLE3 || type == T_DOUBLE4 ||
-    type == T_GEOMETRY || type == T_GEOGRAPHY || type == T_NPOINT
-    )
+    type == T_GEOMETRY || type == T_GEOGRAPHY || type == T_NPOINT ||
+    type == T_POSE)
     return true;
   return false;
 }
@@ -614,7 +603,11 @@ bool
 basetype_varlength(meosType type)
 {
   assert(meos_basetype(type));
-  if (type == T_TEXT || type == T_GEOMETRY || type == T_GEOGRAPHY)
+  if (type == T_TEXT || type == T_GEOMETRY || type == T_GEOGRAPHY
+#if POSE
+    || type == T_POSE
+#endif
+    )
     return true;
   return false;
 }
@@ -642,13 +635,17 @@ basetype_length(meosType type)
 #if NPOINT
   if (type == T_NPOINT)
     return sizeof(Npoint);
+#endif
+#if POSE
+  if (type == T_POSE)
+    return -1;
 #endif
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
     "Unknown base type: %s", meostype_name(type));
   return SHRT_MAX;
 }
 
-#ifdef DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Return true if the type is an alphanumeric base type
  * @note This function is only used in the asserts
@@ -680,7 +677,11 @@ geo_basetype(meosType type)
 bool
 spatial_basetype(meosType type)
 {
-  if (type == T_GEOMETRY || type == T_GEOGRAPHY || type == T_NPOINT)
+  if (type == T_GEOMETRY || type == T_GEOGRAPHY || type == T_NPOINT
+#if POSE
+    || type == T_POSE
+#endif
+    )
     return true;
   return false;
 }
@@ -702,7 +703,7 @@ time_type(meosType type)
 
 /*****************************************************************************/
 
-#ifdef DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Return true if the type is a base type of a set type
  * @note This function is only used in the asserts
@@ -750,13 +751,11 @@ numset_type(meosType type)
 bool
 ensure_numset_type(meosType type)
 {
-  if (! numset_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The set value must be a number or a date set");
-    return false;
-  }
-  return true;
+  if (numset_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The set value must be a number or a date set");
+  return false;
 }
 
 /**
@@ -770,23 +769,6 @@ timeset_type(meosType type)
   return false;
 }
 
-#if 0 /* not used */
-/**
- * @brief Ensure that the type is a number set type
- */
-bool
-ensure_timeset_type(meosType type)
-{
-  if (! timeset_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The set value must be a time set");
-    return false;
-  }
-  return true;
-}
-#endif /* not used */
-
 /**
  * @brief Return true if the type is a set type with a span as a bounding box
  */
@@ -805,13 +787,11 @@ set_spantype(meosType type)
 bool
 ensure_set_spantype(meosType type)
 {
-  if (! set_spantype(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The set value must be a number or timestamp set");
-    return false;
-  }
-  return true;
+  if (set_spantype(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The set value must be a number or timestamp set");
+  return false;
 }
 
 /**
@@ -843,13 +823,11 @@ geoset_type(meosType type)
 bool
 ensure_geoset_type(meosType type)
 {
-  if (! geoset_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The set value must be a geo set");
-    return false;
-  }
-  return true;
+  if (geoset_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The set value must be a geo set");
+  return false;
 }
 
 /**
@@ -869,13 +847,11 @@ spatialset_type(meosType type)
 bool
 ensure_spatialset_type(meosType type)
 {
-  if (! spatialset_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The set value must be a spatial set");
-    return false;
-  }
-  return true;
+  if (spatialset_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The set value must be a spatial set");
+  return false;
 }
 
 /*****************************************************************************/
@@ -915,7 +891,7 @@ span_type(meosType type)
   return false;
 }
 
-#ifdef DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Return true if the type is a span type
  * @note This function is only used in the asserts
@@ -960,13 +936,11 @@ numspan_type(meosType type)
 bool
 ensure_numspan_type(meosType type)
 {
-  if (! numspan_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The span value must be a number span type");
-    return false;
-  }
-  return true;
+  if (numspan_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The span value must be a number span type");
+  return false;
 }
 
 /**
@@ -991,23 +965,6 @@ timespan_type(meosType type)
   return false;
 }
 
-#if 0 /* not used */
-/**
- * @brief Ensure that a span is a time span type
- */
-bool
-ensure_timespan_type(meosType type)
-{
-  if (! timespan_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The span value must be a time span type");
-    return false;
-  }
-  return true;
-}
-#endif /* not used */
-
 /*****************************************************************************/
 
 /**
@@ -1022,20 +979,6 @@ spanset_type(meosType type)
   return false;
 }
 
-#if 0 /* not used */
-/**
- * @brief Return true if the type is a number span type
- */
-bool
-numspanset_type(meosType type)
-{
-  if (type == T_INTSPANSET || type == T_BIGINTSPANSET ||
-      type == T_FLOATSPANSET)
-    return true;
-  return false;
-}
-#endif
-
 /**
  * @brief Return true if the type is a time span type
  */
@@ -1053,13 +996,11 @@ timespanset_type(meosType type)
 bool
 ensure_timespanset_type(meosType type)
 {
-  if (! timespanset_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The value must be a time span set type");
-    return false;
-  }
-  return true;
+  if (timespanset_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The value must be a time span set type");
+  return false;
 }
 
 /*****************************************************************************/
@@ -1077,13 +1018,16 @@ temporal_type(meosType type)
       type == T_TDOUBLE2 || type == T_TDOUBLE3 || type == T_TDOUBLE4
 #if NPOINT
     || type == T_TNPOINT
+#endif
+#if POSE
+    || type == T_TPOSE
 #endif
     )
     return true;
   return false;
 }
 
-#ifdef DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Return true if the type is a temporal base type
  * @note This function is only used in the asserts
@@ -1097,6 +1041,9 @@ temporal_basetype(meosType type)
     type == T_GEOMETRY || type == T_GEOGRAPHY
 #if NPOINT
     || type == T_NPOINT
+#endif
+#if POSE
+    || type == T_POSE
 #endif
     )
     return true;
@@ -1114,13 +1061,16 @@ temptype_continuous(meosType type)
       type == T_TDOUBLE4 || type == T_TGEOMPOINT || type == T_TGEOGPOINT
 #if NPOINT
     || type == T_TNPOINT
+#endif
+#if POSE
+    || type == T_TPOSE
 #endif
     )
     return true;
   return false;
 }
 
-#ifdef DEBUG_BUILD
+#ifndef NDEBUG
 /**
  * @brief Return true if the type is a temporal alphanumeric type
  * @note This function is only used in the asserts
@@ -1164,13 +1114,11 @@ tnumber_type(meosType type)
 bool
 ensure_tnumber_type(meosType type)
 {
-  if (! tnumber_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The temporal value must be a temporal number");
-    return false;
-  }
-  return true;
+  if (tnumber_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The temporal value must be a temporal number");
+  return false;
 }
 
 /**
@@ -1190,13 +1138,11 @@ tnumber_basetype(meosType type)
 bool
 ensure_tnumber_basetype(meosType type)
 {
-  if (! tnumber_basetype(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The temporal value must be a base value of temporal number");
-    return false;
-  }
-  return true;
+  if (tnumber_basetype(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The temporal value must be a base value of temporal number");
+  return false;
 }
 
 
@@ -1237,6 +1183,9 @@ tspatial_type(meosType type)
   if (type == T_TGEOMPOINT || type == T_TGEOGPOINT
 #if NPOINT
       || type == T_TNPOINT
+#endif
+#if POSE
+      || type == T_TPOSE
 #endif
       )
     return true;
@@ -1249,13 +1198,11 @@ tspatial_type(meosType type)
 bool
 ensure_tspatial_type(meosType type)
 {
-  if (! tspatial_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The temporal value must be a temporal point type");
-    return false;
-  }
-  return true;
+  if (tspatial_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The temporal value must be a temporal point type");
+  return false;
 }
 
 
@@ -1270,6 +1217,9 @@ tspatial_basetype(meosType type)
   if (type == T_GEOMETRY || type == T_GEOGRAPHY
 #if NPOINT
     || type == T_NPOINT
+#endif
+#if POSE
+    || type == T_POSE
 #endif
     )
     return true;
@@ -1293,13 +1243,11 @@ tgeo_type(meosType type)
 bool
 ensure_tgeo_type(meosType type)
 {
-  if (! tgeo_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The temporal value must be a temporal point type");
-    return false;
-  }
-  return true;
+  if (tgeo_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The temporal value must be a temporal point type");
+  return false;
 }
 
 /**
@@ -1309,13 +1257,11 @@ ensure_tgeo_type(meosType type)
 bool
 ensure_tnumber_tgeo_type(meosType type)
 {
-  if (! tnumber_type(type) && ! tgeo_type(type))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The temporal value must be a temporal number or a temporal point type");
-    return false;
-  }
-  return true;
+  if (tnumber_type(type) || tgeo_type(type))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The temporal value must be a temporal number or a temporal point type");
+  return false;
 }
 
 /*****************************************************************************/
