@@ -45,14 +45,12 @@
 #include <utils/datetime.h>
 #include <utils/float.h>
 #include "utils/formatting.h"
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <common/hashfn.h>
-#else
-  #include <access/hash.h>
-#endif
+#include <common/hashfn.h>
 #if POSTGRESQL_VERSION_NUMBER >= 160000
   #include "varatt.h"
 #endif
+
+
 /* PostGIS */
 #include <liblwgeom_internal.h> /* for OUT_DOUBLE_BUFFER_SIZE */
 
@@ -80,10 +78,8 @@
 
 /* Definition in numutils.c */
 extern int32 pg_strtoint32(const char *s);
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  extern int pg_ultoa_n(uint32 value, char *a);
-  extern int pg_ulltoa_n(uint64 l, char *a);
-#endif /* POSTGRESQL_VERSION_NUMBER >= 130000 */
+extern int pg_ultoa_n(uint32 value, char *a);
+extern int pg_ulltoa_n(uint64 l, char *a);
 
 /* To avoid including varlena.h */
 extern int varstr_cmp(const char *arg1, int len1, const char *arg2, int len2,
@@ -234,6 +230,8 @@ bool_out(bool b)
  * Functions adapted from int.c
  *****************************************************************************/
 
+#define MAXINT4LEN 12
+
 /**
  * @brief Return an int4 from a string
  * @note PostgreSQL function: @p int4in(PG_FUNCTION_ARGS)
@@ -244,7 +242,6 @@ int4_in(const char *str)
   return pg_strtoint32(str);
 }
 
-#if POSTGRESQL_VERSION_NUMBER >= 130000
 /*
  * pg_ltoa: converts a signed 32-bit integer to its string representation and
  * returns strlen(a).
@@ -271,7 +268,6 @@ mobdb_ltoa(int32 value, char *a)
   a[len] = '\0';
   return len;
 }
-#endif /* POSTGRESQL_VERSION_NUMBER >= 130000 */
 
 /**
  * @brief Return a string from an int4
@@ -280,12 +276,8 @@ mobdb_ltoa(int32 value, char *a)
 char *
 int4_out(int32 val)
 {
-  char *result = palloc(12);  /* sign, 10 digits, '\0' */
-#if POSTGRESQL_VERSION_NUMBER >= 130000
+  char *result = palloc(MAXINT4LEN);  /* sign, 10 digits, '\0' */
   mobdb_ltoa(val, result);
-#else
-  sprintf(result, "%d", val);
-#endif
   return result;
 }
 
@@ -313,7 +305,6 @@ int8_in(const char *str)
   return result;
 }
 
-#if POSTGRESQL_VERSION_NUMBER >= 130000
 /*
  * pg_lltoa: converts a signed 64-bit integer to its string representation and
  * returns strlen(a).
@@ -340,7 +331,6 @@ mobdb_lltoa(int64 value, char *a)
   a[len] = '\0';
   return len;
 }
-#endif /* POSTGRESQL_VERSION_NUMBER >= 130000 */
 
 /**
  * @brief Return a string from an @p int8
@@ -350,7 +340,6 @@ char *
 int8_out(int64 val)
 {
   char *result;
-#if POSTGRESQL_VERSION_NUMBER >= 130000
   char buf[MAXINT8LEN + 1];
   int len = mobdb_lltoa(val, buf) + 1;
   /*
@@ -359,10 +348,6 @@ int8_out(int64 val)
    */
   result = palloc(len);
   memcpy(result, buf, len);
-#else
-  result = palloc(MAXINT8LEN + 1);
-  sprintf(result, "%ld", val);
-#endif
   return result;
 }
 
@@ -795,7 +780,7 @@ pg_date_out(DateADT d)
 }
 #endif /* MEOS */
 
-#if MEOS || POSTGRESQL_VERSION_NUMBER < 130000
+#if MEOS
 /*
  * Promote date to timestamp with time zone.
  *
@@ -880,7 +865,7 @@ date2timestamptz_opt_overflow(DateADT dateVal, int *overflow)
   }
   return result;
 }
-#endif /* MEOS || POSTGRESQL_VERSION_NUMBER < 130000 */
+#endif /* MEOS */
 
 /**
  * @ingroup meos_pg_types
@@ -967,6 +952,108 @@ minus_date_date(DateADT d1, DateADT d2)
   return result;
 }
 
+/*****************************************************************************/
+
+/*
+ * Promote date to timestamp.
+ *
+ * On successful conversion, *overflow is set to zero if it's not NULL.
+ *
+ * If the date is finite but out of the valid range for timestamp, then:
+ * if overflow is NULL, we throw an out-of-range error.
+ * if overflow is not NULL, we store +1 or -1 there to indicate the sign
+ * of the overflow, and return the appropriate timestamp infinity.
+ *
+ * Note: *overflow = -1 is actually not possible currently, since both
+ * datatypes have the same lower bound, Julian day zero.
+ */
+Timestamp
+date2timestamp_opt_overflow(DateADT dateVal, int *overflow)
+{
+  Timestamp  result;
+
+  if (overflow)
+    *overflow = 0;
+
+  if (DATE_IS_NOBEGIN(dateVal))
+    TIMESTAMP_NOBEGIN(result);
+  else if (DATE_IS_NOEND(dateVal))
+    TIMESTAMP_NOEND(result);
+  else
+  {
+    /*
+     * Since dates have the same minimum values as timestamps, only upper
+     * boundary need be checked for overflow.
+     */
+    if (dateVal >= (TIMESTAMP_END_JULIAN - POSTGRES_EPOCH_JDATE))
+    {
+      if (overflow)
+      {
+        *overflow = 1;
+        TIMESTAMP_NOEND(result);
+        return result;
+      }
+      else
+      {
+        meos_error(ERROR, MEOS_ERR_VALUE_OUT_OF_RANGE,
+          "date out of range for timestamp");
+      }
+    }
+
+    /* date is days since 2000, timestamp is microseconds since same... */
+    result = dateVal * USECS_PER_DAY;
+  }
+
+  return result;
+}
+
+/*
+ * Promote date to timestamp, throwing error for overflow.
+ */
+static TimestampTz
+date2timestamp(DateADT dateVal)
+{
+  return date2timestamp_opt_overflow(dateVal, NULL);
+}
+
+/* date_timestamp()
+ * Convert date to timestamp data type.
+ */
+Timestamp
+date_to_timestamp(DateADT dateVal)
+{
+  Timestamp result;
+  result = date2timestamp(dateVal);
+  return result;
+}
+
+/* timestamp_date()
+ * Convert timestamp to date data type.
+ */
+DateADT
+timestamp_to_date(Timestamp timestamp)
+{
+  DateADT result;
+  struct pg_tm tt,
+         *tm = &tt;
+  fsec_t    fsec;
+
+  if (TIMESTAMP_IS_NOBEGIN(timestamp))
+    DATE_NOBEGIN(result);
+  else if (TIMESTAMP_IS_NOEND(timestamp))
+    DATE_NOEND(result);
+  else
+  {
+    if (timestamp2tm(timestamp, NULL, tm, &fsec, NULL, NULL) != 0)
+      meos_error(ERROR, MEOS_ERR_VALUE_OUT_OF_RANGE,
+        "timestamp out of range");
+
+    result = date2j(tm->tm_year, tm->tm_mon, tm->tm_mday) - POSTGRES_EPOCH_JDATE;
+  }
+
+  return result;
+}
+
 /*****************************************************************************
  *   Time ADT
  *****************************************************************************/
@@ -1178,7 +1265,7 @@ MEOSAdjustTimestampForTypmod(Timestamp *time, int32 typmod)
  * @param[in] str String
  * @param[in] typmod Precision
  * @param[in] withtz True when using timezone
- * @result On error return DT_NOEND
+ * @return On error return DT_NOEND
  * @note The function returns a TimestampTz that must be cast to a Timestamp
  * when calling the function with the last argument to false
  */
@@ -1847,7 +1934,8 @@ Interval *
 add_interval_interval(const Interval *interv1, const Interval *interv2)
 {
   /* Ensure validity of the arguments */
-  if (! ensure_not_null((void *) interv1) || ! ensure_not_null((void *) interv2))
+  if (! ensure_not_null((void *) interv1) ||
+      ! ensure_not_null((void *) interv2))
     return NULL;
 
   Interval *result = palloc(sizeof(Interval));
@@ -2388,83 +2476,6 @@ datum_initcap(Datum value)
  * Functions adapted from hashfn.h and hashfn.c
  *****************************************************************************/
 
-#if POSTGRESQL_VERSION_NUMBER < 130000
-
-/* Rotate a uint32 value left by k bits - note multiple evaluation! */
-#define rot(x,k) (((x)<<(k)) | ((x)>>(32-(k))))
-
-#define mix(a,b,c) \
-{ \
-  a -= c;  a ^= rot(c, 4);  c += b; \
-  b -= a;  b ^= rot(a, 6);  a += c; \
-  c -= b;  c ^= rot(b, 8);  b += a; \
-  a -= c;  a ^= rot(c,16);  c += b; \
-  b -= a;  b ^= rot(a,19);  a += c; \
-  c -= b;  c ^= rot(b, 4);  b += a; \
-}
-
-#define final(a,b,c) \
-{ \
-  c ^= b; c -= rot(b,14); \
-  a ^= c; a -= rot(c,11); \
-  b ^= a; b -= rot(a,25); \
-  c ^= b; c -= rot(b,16); \
-  a ^= c; a -= rot(c, 4); \
-  b ^= a; b -= rot(a,14); \
-  c ^= b; c -= rot(b,24); \
-}
-
-/*
- * hash_bytes_uint32() -- hash a 32-bit value to a 32-bit value
- *
- * This has the same result as
- *    hash_bytes(&k, sizeof(uint32))
- * but is faster and doesn't force the caller to store k into memory.
- */
-uint32
-hash_bytes_uint32(uint32 k)
-{
-  uint32    a,
-        b,
-        c;
-
-  a = b = c = 0x9e3779b9 + (uint32) sizeof(uint32) + 3923095;
-  a += k;
-
-  final(a, b, c);
-
-  /* report the result */
-  return c;
-}
-
-/*
- * hash_bytes_uint32_extended() -- hash 32-bit value to 64-bit value, with seed
- *
- * Like hash_bytes_uint32, this is a convenience function.
- */
-uint64
-hash_bytes_uint32_extended(uint32 k, uint64 seed)
-{
-  uint32 a, b, c;
-  a = b = c = 0x9e3779b9 + (uint32) sizeof(uint32) + 3923095;
-
-  if (seed != 0)
-  {
-    a += (uint32) (seed >> 32);
-    b += (uint32) seed;
-    mix(a, b, c);
-  }
-
-  a += k;
-
-  final(a, b, c);
-
-  /* report the result */
-  return ((uint64) b << 32) | c;
-}
-
-#endif /* POSTGRESQL_VERSION_NUMBER < 130000 */
-
 /**
  * @brief Get the 32-bit hash value of an int64 value.
  * @note PostgreSQL function: @p hashint8(PG_FUNCTION_ARGS)
