@@ -69,13 +69,11 @@
 bool
 ensure_set_isof_type(const Set *s, meosType settype)
 {
-  if (s->settype != settype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The set must be of type %s", meostype_name(settype));
-    return false;
-  }
-  return true;
+  if (s->settype == settype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The set must be of type %s", meostype_name(settype));
+  return false;
 }
 
 #if MEOS
@@ -85,14 +83,12 @@ ensure_set_isof_type(const Set *s, meosType settype)
 bool
 ensure_set_isof_basetype(const Set *s, meosType basetype)
 {
-  if (s->basetype != basetype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed set and base types: %s and %s",
-      meostype_name(s->settype), meostype_name(basetype));
-    return false;
-  }
-  return true;
+  if (s->basetype == basetype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed set and base types: %s and %s",
+    meostype_name(s->settype), meostype_name(basetype));
+  return false;
 }
 #endif /* MEOS */
 
@@ -103,14 +99,12 @@ ensure_set_isof_basetype(const Set *s, meosType basetype)
 bool
 ensure_same_set_type(const Set *s1, const Set *s2)
 {
-  if (s1->settype != s2->settype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed set types: %s and %s",
-      meostype_name(s1->settype), meostype_name(s2->settype));
-    return false;
-  }
-  return true;
+  if (s1->settype == s2->settype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed set types: %s and %s",
+    meostype_name(s1->settype), meostype_name(s2->settype));
+  return false;
 }
 
 /*****************************************************************************
@@ -136,7 +130,7 @@ ensure_same_set_type(const Set *s1, const Set *s2)
  * @param[in] s Set
  * @param[in] d Value
  * @param[out] loc Location
- * @result Return true if the value is contained in the set
+ * @return Return true if the value is contained in the set
  */
 bool
 set_find_value(const Set *s, Datum d, int *loc)
@@ -163,35 +157,6 @@ set_find_value(const Set *s, Datum d, int *loc)
   return false;
 }
 
-#if 0 /* not used */
-/**
- * @brief Return the location of a value in a ranked set (which is unordered)
- * using sequential search
- * @param[in] s Set
- * @param[in] d Value
- * @param[out] loc Location of the value if found
- * @result Return true if the value is contained in the vecctor
- * @note Contrary to function `set_find_value`, if the value is not found the
- * returned location is always 0.
- */
-bool
-rset_find_value(const Set *s, Datum d, int *loc)
-{
-  assert(s); assert(loc);
-  for (int i = 0; i < s->count; i++)
-  {
-    Datum d1 = SET_VAL_N(s, i);
-    if (datum_eq(d, d1, s->basetype))
-    {
-      *loc = i;
-      return true;
-    }
-  }
-  *loc = 0;
-  return false;
-}
-#endif /* not used */
-
 /*****************************************************************************
  * Input/output functions in string format
  *****************************************************************************/
@@ -358,14 +323,15 @@ set_out_fn(const Set *s, int maxdd, outfunc value_out)
 
   /* Get the SRID if it is a geo set  */
   int32 srid;
-  char str1[20];
+  char str1[18];
   str1[0] = '\0';
   outfunc value_out1 = value_out;
   if (geoset_type(s->settype) && value_out == ewkt_out)
   {
     srid = geoset_srid(s);
     if (srid > 0)
-      sprintf(str1, "SRID=%d;", srid);
+      /* SRID_MAXIMUM is defined by PostGIS as 999999 */
+      snprintf(str1, sizeof(str1), "SRID=%d;", srid);
     /* Since the SRID is output at the begining it is not output for the
      * elements */
     value_out1 = wkt_out;
@@ -561,8 +527,8 @@ set_bbox_size(meosType settype)
   if (spatialset_type(settype))
     return sizeof(STBox);
   meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
-    "Unknown set type when determining the size of the bounding box: %d",
-    settype);
+    "Unknown set type when determining the size of the bounding box: %s",
+    meostype_name(settype));
   return SIZE_MAX;
 }
 
@@ -587,7 +553,8 @@ valuearr_compute_bbox(const Datum *values, meosType basetype, int count,
 #endif
   else
     meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
-      "Unknown set type for computing the bounding box: %d", basetype);
+      "Unknown set type for computing the bounding box: %s",
+      meostype_name(basetype));
   return;
 }
 
@@ -669,11 +636,12 @@ SET_VAL_N(const Set *s, int index)
  * @param[in] count Number of elements in the array
  * @param[in] maxcount Maximum number of elements in the array
  * @param[in] basetype Type of the values
- * @param[in] ordered True when the values are ordered and without duplicates
+ * @param[in] order True when the values should be ordered and duplicates
+ * should be removed
  */
 Set *
 set_make_exp(const Datum *values, int count, int maxcount, meosType basetype,
-  bool ordered)
+  bool order)
 {
   assert(values); assert(count > 0); assert(count <= maxcount);
   bool hasz = false;
@@ -701,7 +669,7 @@ set_make_exp(const Datum *values, int count, int maxcount, meosType basetype,
   /* Sort the values and remove duplicates */
   Datum *newvalues;
   int newcount;
-  if (! ordered && count > 1)
+  if (order && count > 1)
   {
   /* Sort the values and remove duplicates */
     newvalues = palloc(sizeof(Datum) * count);
@@ -761,7 +729,7 @@ set_make_exp(const Datum *values, int count, int maxcount, meosType basetype,
   Set *result = palloc0(memsize);
   SET_VARSIZE(result, memsize);
   MEOS_FLAGS_SET_BYVAL(result->flags, typbyval);
-  MEOS_FLAGS_SET_ORDERED(result->flags, ordered);
+  MEOS_FLAGS_SET_ORDERED(result->flags, ! order);
   if (geo_basetype(basetype))
   {
     MEOS_FLAGS_SET_X(result->flags, true);
@@ -801,28 +769,29 @@ set_make_exp(const Datum *values, int count, int maxcount, meosType basetype,
   if (bboxsize != 0)
     valuearr_compute_bbox(newvalues, basetype, newcount, SET_BBOX_PTR(result));
 
-  if (! ordered && count > 1)
+  if (order && count > 1)
     pfree(newvalues);
   return result;
 }
 
-#if MEOS
 /**
  * @ingroup meos_internal_setspan_constructor
  * @brief Return a set from an array of values
  * @param[in] values Array of values
  * @param[in] count Number of elements in the array
  * @param[in] basetype Type of the values
- * @param[in] ordered True when the values are ordered and without duplicates
+ * @param[in] order True when the values should be ordered and duplicates
+ * should be removed
  * @csqlfn #Set_constructor()
  */
 Set *
-set_make(const Datum *values, int count, meosType basetype, bool ordered)
+set_make(const Datum *values, int count, meosType basetype, bool order)
 {
   assert(values); assert(count > 0);
-  return set_make_exp(values, count, count, basetype, ordered);
+  return set_make_exp(values, count, count, basetype, order);
 }
 
+#if MEOS
 /**
  * @ingroup meos_setspan_constructor
  * @brief Return an integer set from an array of values
@@ -840,7 +809,7 @@ intset_make(const int *values, int count)
   Datum *datums = palloc(sizeof(Datum) * count);
   for (int i = 0; i < count; ++i)
     datums[i] = Int32GetDatum(values[i]);
-  return set_make_free(datums, count, T_INT4, ORDERED_NO);
+  return set_make_free(datums, count, T_INT4, ORDER);
 }
 
 /**
@@ -860,7 +829,7 @@ bigintset_make(const int64 *values, int count)
   Datum *datums = palloc(sizeof(Datum) * count);
   for (int i = 0; i < count; ++i)
     datums[i] = Int64GetDatum(values[i]);
-  return set_make_free(datums, count, T_INT8, ORDERED_NO);
+  return set_make_free(datums, count, T_INT8, ORDER);
 }
 
 /**
@@ -880,7 +849,7 @@ floatset_make(const double *values, int count)
   Datum *datums = palloc(sizeof(Datum) * count);
   for (int i = 0; i < count; ++i)
     datums[i] = Float8GetDatum(values[i]);
-  return set_make_free(datums, count, T_FLOAT8, ORDERED_NO);
+  return set_make_free(datums, count, T_FLOAT8, ORDER);
 }
 
 /**
@@ -900,7 +869,7 @@ textset_make(const text **values, int count)
   Datum *datums = palloc(sizeof(Datum) * count);
   for (int i = 0; i < count; ++i)
     datums[i] = PointerGetDatum(values[i]);
-  return set_make_free(datums, count, T_TEXT, ORDERED_NO);
+  return set_make_free(datums, count, T_TEXT, ORDER);
 }
 
 /**
@@ -920,7 +889,7 @@ dateset_make(const DateADT *values, int count)
   Datum *datums = palloc(sizeof(Datum) * count);
   for (int i = 0; i < count; ++i)
     datums[i] = DateADTGetDatum(values[i]);
-  return set_make_free(datums, count, T_DATE, ORDERED_NO);
+  return set_make_free(datums, count, T_DATE, ORDER);
 }
 
 /**
@@ -940,7 +909,7 @@ tstzset_make(const TimestampTz *values, int count)
   Datum *datums = palloc(sizeof(Datum) * count);
   for (int i = 0; i < count; ++i)
     datums[i] = TimestampTzGetDatum(values[i]);
-  return set_make_free(datums, count, T_TIMESTAMPTZ, ORDERED_NO);
+  return set_make_free(datums, count, T_TIMESTAMPTZ, ORDER);
 }
 
 /**
@@ -962,7 +931,7 @@ geoset_make(const GSERIALIZED **values, int count)
     datums[i] = PointerGetDatum(values[i]);
   meosType geotype = FLAGS_GET_GEODETIC(values[0]->gflags) ?
     T_GEOMETRY : T_GEOGRAPHY;
-  return set_make_free(datums, count, geotype, ORDERED_NO);
+  return set_make_free(datums, count, geotype, ORDER);
 }
 #endif /* MEOS */
 
@@ -973,16 +942,19 @@ geoset_make(const GSERIALIZED **values, int count)
  * @param[in] values Array of values
  * @param[in] count Number of elements in the array
  * @param[in] basetype Type of the values
- * @param[in] ordered True when the values are ordered and without duplicates
+ * @param[in] order True when the values should be ordered and duplicates
+ * should be removed
  */
 Set *
-set_make_free(Datum *values, int count, meosType basetype, bool ordered)
+set_make_free(Datum *values, int count, meosType basetype, bool order)
 {
   assert(values); assert(count >= 0);
   Set *result = NULL;
   if (count > 0)
-    result = set_make_exp(values, count, count, basetype, ordered);
-  pfree(values);
+  {
+    result = set_make_exp(values, count, count, basetype, order);
+    pfree(values);
+  }
   return result;
 }
 
@@ -1030,7 +1002,7 @@ set_copy(const Set *s)
 Set *
 value_to_set(Datum value, meosType basetype)
 {
-  return set_make_exp(&value, 1, 1, basetype, ORDERED);
+  return set_make_exp(&value, 1, 1, basetype, ORDER_NO);
 }
 
 #if MEOS
@@ -1044,7 +1016,7 @@ Set *
 int_to_set(int i)
 {
   Datum v = Int32GetDatum(i);
-  return set_make_exp(&v, 1, 1, T_INT4, ORDERED);
+  return set_make_exp(&v, 1, 1, T_INT4, ORDER_NO);
 }
 
 /**
@@ -1057,7 +1029,7 @@ Set *
 bigint_to_set(int64 i)
 {
   Datum v = Int64GetDatum(i);
-  return set_make_exp(&v, 1, 1, T_INT8, ORDERED);
+  return set_make_exp(&v, 1, 1, T_INT8, ORDER_NO);
 }
 
 /**
@@ -1070,7 +1042,7 @@ Set *
 float_to_set(double d)
 {
   Datum v = Float8GetDatum(d);
-  return set_make_exp(&v, 1, 1, T_FLOAT8, ORDERED);
+  return set_make_exp(&v, 1, 1, T_FLOAT8, ORDER_NO);
 }
 
 /**
@@ -1086,7 +1058,7 @@ text_to_set(text *txt)
   if (! ensure_not_null((void *) txt))
     return NULL;
   Datum v = PointerGetDatum(txt);
-  return set_make_exp(&v, 1, 1, T_TEXT, ORDERED);
+  return set_make_exp(&v, 1, 1, T_TEXT, ORDER_NO);
 }
 
 /**
@@ -1099,7 +1071,7 @@ Set *
 date_to_set(DateADT d)
 {
   Datum v = DateADTGetDatum(d);
-  return set_make_exp(&v, 1, 1, T_DATE, ORDERED);
+  return set_make_exp(&v, 1, 1, T_DATE, ORDER_NO);
 }
 
 /**
@@ -1112,7 +1084,7 @@ Set *
 timestamptz_to_set(TimestampTz t)
 {
   Datum v = TimestampTzGetDatum(t);
-  return set_make_exp(&v, 1, 1, T_TIMESTAMPTZ, ORDERED);
+  return set_make_exp(&v, 1, 1, T_TIMESTAMPTZ, ORDER_NO);
 }
 
 /**
@@ -1129,7 +1101,7 @@ geo_to_set(GSERIALIZED *gs)
     return NULL;
   Datum v = PointerGetDatum(gs);
   meosType geotype = FLAGS_GET_GEODETIC(gs->gflags) ? T_GEOGRAPHY : T_GEOMETRY;
-  return set_make_exp(&v, 1, 1, geotype, ORDERED);
+  return set_make_exp(&v, 1, 1, geotype, ORDER_NO);
 }
 #endif /* MEOS */
 
@@ -1152,7 +1124,7 @@ intset_floatset(const Set *s)
   for (int i = 0; i < s->count; i++)
     values[i] = Float8GetDatum((double) DatumGetInt32(SET_VAL_N(s, i)));
   /* All distinct integers will yield distinct floats */
-  return set_make_free(values, s->count, T_FLOAT8, ORDERED);
+  return set_make_free(values, s->count, T_FLOAT8, ORDER_NO);
 }
 
 #if MEOS
@@ -1189,7 +1161,7 @@ floatset_intset(const Set *s)
   for (int i = 0; i < s->count; i++)
     values[i] = Int32GetDatum((int) DatumGetFloat8(SET_VAL_N(s, i)));
   /* Two distinct floats can yield the same integer */
-  return set_make_free(values, s->count, T_INT4, ORDERED_NO);
+  return set_make_free(values, s->count, T_INT4, ORDER);
 }
 
 #if MEOS
@@ -1227,7 +1199,7 @@ dateset_tstzset(const Set *s)
     values[i] = TimestampTzGetDatum(date_to_timestamptz(DatumGetDateADT(
       SET_VAL_N(s, i))));
   /* All distinct dates will yield distinct timestamptz */
-  return set_make_free(values, s->count, T_TIMESTAMPTZ, ORDERED);
+  return set_make_free(values, s->count, T_TIMESTAMPTZ, ORDER_NO);
 }
 
 #if MEOS
@@ -1265,7 +1237,7 @@ tstzset_dateset(const Set *s)
     values[i] = DateADTGetDatum(timestamptz_to_date(DatumGetTimestampTz(
       SET_VAL_N(s, i))));
   /* Two distinct timestamptz can yield the same date */
-  return set_make_free(values, s->count, T_DATE, ORDERED_NO);
+  return set_make_free(values, s->count, T_DATE, ORDER);
 }
 
 #if MEOS
@@ -1582,7 +1554,7 @@ geoset_end_value(const Set *s)
  * @param[in] s Set
  * @param[in] n Number
  * @param[out] result Value
- * @result Return true if the value is found
+ * @return Return true if the value is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1605,7 +1577,7 @@ set_value_n(const Set *s, int n, Datum *result)
  * @param[in] s Integer set
  * @param[in] n Number
  * @param[out] result Value
- * @result Return true if the value is found
+ * @return Return true if the value is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1627,7 +1599,7 @@ intset_value_n(const Set *s, int n, int *result)
  * @param[in] s Integer set
  * @param[in] n Number
  * @param[out] result Value
- * @result Return true if the value is found
+ * @return Return true if the value is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1648,7 +1620,7 @@ bigintset_value_n(const Set *s, int n, int64 *result)
  * @param[in] s Float set
  * @param[in] n Number
  * @param[out] result Value
- * @result Return true if the value is found
+ * @return Return true if the value is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1670,7 +1642,7 @@ floatset_value_n(const Set *s, int n, double *result)
  * @param[in] s Text set
  * @param[in] n Number
  * @param[out] result Value
- * @result Return true if the value is found
+ * @return Return true if the value is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1691,7 +1663,7 @@ textset_value_n(const Set *s, int n, text **result)
  * @param[in] s Date set
  * @param[in] n Number
  * @param[out] result Date
- * @result Return true if the date is found
+ * @return Return true if the date is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1713,7 +1685,7 @@ dateset_value_n(const Set *s, int n, DateADT *result)
  * @param[in] s Timestamptz set
  * @param[in] n Number
  * @param[out] result Timestamptz
- * @result Return true if the timestamptz is found
+ * @return Return true if the timestamptz is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1735,7 +1707,7 @@ tstzset_value_n(const Set *s, int n, TimestampTz *result)
  * @param[in] s Geo set
  * @param[in] n Number
  * @param[out] result Value
- * @result Return true if the value is found
+ * @return Return true if the value is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Set_value_n()
  */
@@ -1942,17 +1914,53 @@ Set *
 set_compact(const Set *s)
 {
   assert(s);
-  /* Collect the values which may be UNORDERED */
+  /* Collect the values which may be not ordered */
   Datum *values = palloc(sizeof(Datum) * s->count);
   for (int i = 0; i < s->count; i++)
     values[i] = SET_VAL_N(s, i);
 
-  Set *result = set_make_exp(values, s->count, s->count, s->basetype, ORDERED);
+  Set *result = set_make_exp(values, s->count, s->count, s->basetype, ORDER_NO);
   pfree(values);
   return result;
 }
 #endif /* MEOS */
 
+/**
+ * @ingroup meos_internal_setspan_transf
+ * @brief Return a float set rounded down to the nearest integer
+ * @csqlfn #Floatset_floor()
+ */
+Set *
+floatset_floor(const Set *s)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s) || ! ensure_set_isof_type(s, T_FLOATSET))
+    return NULL;
+
+  Datum *values = palloc(sizeof(Datum) * s->count);
+  for (int i = 0; i < s->count; i++)
+    values[i] = datum_floor(SET_VAL_N(s, i));
+  return set_make_exp(values, s->count, s->count, T_FLOAT8, ORDER);
+}
+
+/**
+ * @ingroup meos_internal_setspan_transf
+ * @brief Return a float set rounded up to the nearest integer
+ * @csqlfn #Floatset_ceil()
+ */
+Set *
+floatset_ceil(const Set *s)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s) || ! ensure_set_isof_type(s, T_FLOATSET))
+    return NULL;
+
+  Datum *values = palloc(sizeof(Datum) * s->count);
+  for (int i = 0; i < s->count; i++)
+    values[i] = datum_ceil(SET_VAL_N(s, i));
+  return set_make_exp(values, s->count, s->count, T_FLOAT8, ORDER);
+}
+
 /**
  * @ingroup meos_internal_setspan_transf
  * @brief Return a float set with the values converted to degrees
@@ -2037,7 +2045,7 @@ textset_lower(const Set *s)
   Datum *values = palloc(sizeof(Datum) * s->count);
   for (int i = 0; i < s->count; i++)
     values[i] = datum_lower(SET_VAL_N(s, i));
-  return set_make_free(values, s->count, T_TEXT, ORDERED);
+  return set_make_free(values, s->count, T_TEXT, ORDER_NO);
 }
 
 /**
@@ -2056,7 +2064,7 @@ textset_upper(const Set *s)
   Datum *values = palloc(sizeof(Datum) * s->count);
   for (int i = 0; i < s->count; i++)
     values[i] = datum_upper(SET_VAL_N(s, i));
-  return set_make_free(values, s->count, T_TEXT, ORDERED);
+  return set_make_free(values, s->count, T_TEXT, ORDER_NO);
 }
 
 /**
@@ -2075,7 +2083,7 @@ textset_initcap(const Set *s)
   Datum *values = palloc(sizeof(Datum) * s->count);
   for (int i = 0; i < s->count; i++)
     values[i] = datum_initcap(SET_VAL_N(s, i));
-  return set_make_free(values, s->count, T_TEXT, ORDERED);
+  return set_make_free(values, s->count, T_TEXT, ORDER_NO);
 }
 
 /**
@@ -2093,7 +2101,7 @@ textcat_textset_text_int(const Set *s, const text *txt, bool invert)
     values[i] = invert ?
       datum_textcat(PointerGetDatum(txt), SET_VAL_N(s, i)) :
       datum_textcat(SET_VAL_N(s, i), PointerGetDatum(txt));
-  return set_make_free(values, s->count, T_TEXT, ORDERED);
+  return set_make_free(values, s->count, T_TEXT, ORDER_NO);
 }
 
 #if MEOS
@@ -2358,7 +2366,7 @@ set_unnest_state_next(SetUnnestState *state)
 {
   if (! state || state->done)
     return;
-  /* Move to the next bucket */
+  /* Move to the next bin */
   state->i++;
   if (state->i == state->count)
     state->done = true;
