@@ -167,7 +167,7 @@ setop_set_set(const Set *s1, const Set *s2, SetOper op)
     while (j < s2->count)
       values[nvals++] = SET_VAL_N(s2, j++);
   }
-  return set_make_free(values, nvals, basetype, ORDERED);
+  return set_make_free(values, nvals, basetype, ORDER_NO);
 }
 
 /*****************************************************************************
@@ -1541,7 +1541,7 @@ union_set_value(const Set *s, Datum value)
   }
   if (! found)
     values[nvals++] = value;
-  return set_make_free(values, nvals, s->basetype, ORDERED);
+  return set_make_free(values, nvals, s->basetype, ORDER_NO);
 }
 
 /**
@@ -2252,7 +2252,7 @@ minus_set_value(const Set *s, Datum value)
     if (datum_ne(value, value1, s->basetype))
       values[nvals++] = value1;
   }
-  return set_make_free(values, nvals, s->basetype, ORDERED);
+  return set_make_free(values, nvals, s->basetype, ORDER_NO);
 }
 
 #if MEOS
@@ -2417,7 +2417,7 @@ distance_set_value(const Set *s, Datum value)
  * @brief Return the distance between a set and an integer
  * @param[in] s Set
  * @param[in] i Value
- * @result On error return -1
+ * @return On error return -1
  * @csqlfn #Distance_set_value()
  */
 int
@@ -2434,7 +2434,7 @@ distance_set_int(const Set *s, int i)
  * @brief Return the distance between a set and a big integer
  * @param[in] s Set
  * @param[in] i Value
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_value()
  */
 int64
@@ -2451,7 +2451,7 @@ distance_set_bigint(const Set *s, int64 i)
  * @brief Return the distance between a set and a float
  * @param[in] s Set
  * @param[in] d Value
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_value()
  */
 double
@@ -2468,7 +2468,7 @@ distance_set_float(const Set *s, double d)
  * @brief Return the distance in days between a set and a date
  * @param[in] s Set
  * @param[in] d Value
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_value()
  */
 int
@@ -2486,7 +2486,7 @@ distance_set_date(const Set *s, DateADT d)
  * double
  * @param[in] s Set
  * @param[in] t Value
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_value()
  */
 double
@@ -2519,7 +2519,7 @@ dist_set_set(const Set *s1, const Set *s2)
  * @ingroup meos_internal_setspan_dist
  * @brief Return the distance between two sets
  * @param[in] s1,s2 Sets
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_set()
  */
 Datum
@@ -2534,7 +2534,7 @@ distance_set_set(const Set *s1, const Set *s2)
  * @ingroup meos_setspan_dist
  * @brief Return the distance between two integer sets
  * @param[in] s1,s2 Sets
- * @result On error return -1
+ * @return On error return -1
  * @csqlfn #Distance_set_set()
  */
 int
@@ -2552,7 +2552,7 @@ distance_intset_intset(const Set *s1, const Set *s2)
  * @ingroup meos_setspan_dist
  * @brief Return the distance between two big integer sets
  * @param[in] s1,s2 Sets
- * @result On error return -1
+ * @return On error return -1
  * @csqlfn #Distance_set_set()
  */
 int64
@@ -2570,7 +2570,7 @@ distance_bigintset_bigintset(const Set *s1, const Set *s2)
  * @ingroup meos_setspan_dist
  * @brief Return the distance between two float sets
  * @param[in] s1,s2 Sets
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_set()
  */
 double
@@ -2588,7 +2588,7 @@ distance_floatset_floatset(const Set *s1, const Set *s2)
  * @ingroup meos_setspan_dist
  * @brief Return the distance in days between two date sets
  * @param[in] s1,s2 Sets
- * @result On error return -1
+ * @return On error return -1
  * @csqlfn #Distance_set_set()
  */
 int
@@ -2606,7 +2606,7 @@ distance_dateset_dateset(const Set *s1, const Set *s2)
  * @ingroup meos_setspan_dist
  * @brief Return the distance in seconds between two timestamptz sets
  * @param[in] s1,s2 Sets
- * @result On error return -1.0
+ * @return On error return -1.0
  * @csqlfn #Distance_set_set()
  */
 double
