@@ -51,8 +51,6 @@
 #else
   #include <utils/memutils.h>
 #endif /* MEOS */
-/* GSL */
-#include <gsl/gsl_rng.h>
 /* MEOS */
 #include <meos.h>
 #include <meos_internal.h>
@@ -106,10 +104,6 @@ ensure_same_skiplist_subtype(SkipList *state, uint8 subtype)
  * Functions manipulating skip lists
  *****************************************************************************/
 
-/* Global variable for skip lists which require the gsl random generator */
-
-static gsl_rng *_AGGREGATION_RNG = NULL;
-
 #ifdef NO_FFSL
 static int
 ffsl(long int i)
@@ -127,9 +121,7 @@ ffsl(long int i)
 static long int
 gsl_random48()
 {
-  if(! _AGGREGATION_RNG)
-    _AGGREGATION_RNG = gsl_rng_alloc(gsl_rng_ranlxd1);
-  return gsl_rng_get(_AGGREGATION_RNG);
+  return gsl_rng_get(gsl_get_aggregation_rng());
 }
 
 /**
@@ -336,19 +328,6 @@ skiplist_headval(SkipList *list)
   return list->elems[list->elems[0].next[0]].value;
 }
 
-#if 0 /* not used */
-void *
-skiplist_tailval(SkipList *list)
-{
-  /* Despite the look, this is pretty much O(1) */
-  SkipListElem *e = &list->elems[0];
-  int height = e->height;
-  while (e->next[height - 1] != list->tail)
-    e = &list->elems[e->next[height - 1]];
-  return e->value;
-}
-#endif /* not used */
-
 /**
  * @brief Constructs a skiplist from the array of values values
  * @param[in] values Array of values
@@ -576,11 +555,11 @@ skiplist_splice(SkipList *list, void **values, int count, datum_func2 func,
     int newcount = 0;
     void **newvalues;
     if (subtype == TINSTANT)
-      newvalues = (void **) tinstant_tagg((TInstant **) spliced,
-        spliced_count, (TInstant **) values, count, func, &newcount);
+      newvalues = (void **) tinstant_tagg((const TInstant **) spliced,
+        spliced_count, (const TInstant **) values, count, func, &newcount);
     else /* subtype == TSEQUENCE */
-      newvalues = (void **) tsequence_tagg((TSequence **) spliced,
-        spliced_count, (TSequence **) values, count, func, crossings,
+      newvalues = (void **) tsequence_tagg((const TSequence **) spliced,
+        spliced_count, (const TSequence **) values, count, func, crossings,
         &newcount);
 
     /* Delete the spliced-out values */
