@@ -41,11 +41,7 @@
 #include <limits.h>
 /* PostgreSQL */
 #include <utils/timestamp.h>
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <common/hashfn.h>
-#else
-  #include <access/hash.h>
-#endif
+#include <common/hashfn.h>
 /* MEOS */
 #include <meos.h>
 #include <meos_internal.h>
@@ -66,13 +62,11 @@
 bool
 ensure_span_isof_type(const Span *s, meosType spantype)
 {
-  if (s->spantype != spantype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The span must be of type %s", meostype_name(spantype));
-    return false;
-  }
-  return true;
+  if (s->spantype == spantype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The span must be of type %s", meostype_name(spantype));
+  return false;
 }
 
 /**
@@ -81,14 +75,12 @@ ensure_span_isof_type(const Span *s, meosType spantype)
 bool
 ensure_span_isof_basetype(const Span *s, meosType basetype)
 {
-  if (s->basetype != basetype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed span and base types: %s and %s",
-      meostype_name(s->spantype), meostype_name(basetype));
-    return false;
-  }
-  return true;
+  if (s->basetype == basetype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed span and base types: %s and %s",
+    meostype_name(s->spantype), meostype_name(basetype));
+  return false;
 }
 
 /**
@@ -97,14 +89,12 @@ ensure_span_isof_basetype(const Span *s, meosType basetype)
 bool
 ensure_same_span_type(const Span *s1, const Span *s2)
 {
-  if (s1->spantype != s2->spantype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed span types: %s and %s",
-      meostype_name(s1->spantype), meostype_name(s2->spantype));
-    return false;
-  }
-  return true;
+  if (s1->spantype == s2->spantype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed span types: %s and %s",
+    meostype_name(s1->spantype), meostype_name(s2->spantype));
+  return false;
 }
 
 /*****************************************************************************
@@ -304,16 +294,16 @@ span_decr_bound(Datum lower, meosType basetype)
  * The normalized spans are new spans that must be freed.
  * @param[in] spans Array of spans
  * @param[in] count Number of elements in the input array
- * @param[in] ordered True if the spans are ordered
+ * @param[in] order True if the spans should be ordered
  * @param[out] newcount Number of elements in the output array
  * @pre @p count is greater than 0
  */
 Span *
-spanarr_normalize(Span *spans, int count, bool ordered, int *newcount)
+spanarr_normalize(Span *spans, int count, bool order, int *newcount)
 {
   assert(spans); assert(count > 0); assert(newcount);
   /* Sort the spans if they are not ordered */
-  if (! ordered)
+  if (order)
     spanarr_sort(spans, count);
   int nspans = 0;
   Span *result = palloc(sizeof(Span) * count);
@@ -477,8 +467,9 @@ span_out(const Span *s, int maxdd)
   char *upper = unquote(basetype_out(s->upper, s->basetype, maxdd));
   char open = s->lower_inc ? (char) '[' : (char) '(';
   char close = s->upper_inc ? (char) ']' : (char) ')';
-  char *result = palloc(strlen(lower) + strlen(upper) + 5);
-  sprintf(result, "%c%s, %s%c", open, lower, upper, close);
+  size_t size = strlen(lower) + strlen(upper) + 5;
+  char *result = palloc(size);
+  snprintf(result, size, "%c%s, %s%c", open, lower, upper, close);
   pfree(lower); pfree(upper);
   return result;
 }
@@ -882,18 +873,32 @@ timestamptz_to_span(TimestampTz t)
  * @ingroup meos_internal_setspan_conversion
  * @brief Return the last argument initialized to the bounding span of a set
  * @param[in] s Set
- * @param[in] sp Span
+ * @param[in] fromidx,toidx From and to indexes of the values used for the span
+ * bounds
+ * @param[in] result Span
  */
 void
-set_set_span(const Set *s, Span *sp)
+set_set_subspan(const Set *s, int fromidx, int toidx, Span *result)
 {
-  assert(s); assert(sp);
+  assert(s); assert(result);
   meosType spantype = basetype_spantype(s->basetype);
-  span_set(SET_VAL_N(s, MINIDX), SET_VAL_N(s, s->MAXIDX), true, true,
-    s->basetype, spantype, sp);
+  span_set(SET_VAL_N(s, fromidx), SET_VAL_N(s, toidx), true, true,
+    s->basetype, spantype, result);
   return;
 }
 
+/**
+ * @ingroup meos_internal_setspan_conversion
+ * @brief Return the last argument initialized to the bounding span of a set
+ * @param[in] s Set
+ * @param[in] result Span
+ */
+void
+set_set_span(const Set *s, Span *result)
+{
+  return set_set_subspan(s, 0, s->count - 1, result);
+}
+
 /**
  * @ingroup meos_internal_setspan_conversion
  * @brief Return the bounding span of a set
@@ -1416,6 +1421,61 @@ tstzspan_duration(const Span *s)
  * Transformation functions
  *****************************************************************************/
 
+/**
+ * @brief Round down a span to the nearest integer
+ */
+void
+floatspan_floor_ceil_iter(Span *s, datum_func1 func)
+{
+  assert(s);
+  Datum lower = func(s->lower);
+  Datum upper = func(s->upper);
+  bool lower_inc = s->lower_inc;
+  bool upper_inc = s->upper_inc;
+  if (datum_eq(lower, upper, s->basetype))
+  {
+    lower_inc = upper_inc = true;
+  }
+  span_set(lower, upper, lower_inc, upper_inc, s->basetype, s->spantype, s);
+  return;
+}
+
+/**
+ * @ingroup meos_internal_setspan_transf
+ * @brief Return a float span rounded down to the nearest integer
+ * @csqlfn #Floatspan_floor()
+ */
+Span *
+floatspan_floor(const Span *s)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s) || ! ensure_span_isof_type(s, T_FLOATSPAN))
+    return NULL;
+
+  Span *result = span_cp(s);
+  floatspan_floor_ceil_iter(result, &datum_floor);
+  return result;
+}
+
+/**
+ * @ingroup meos_internal_setspan_transf
+ * @brief Return a float span rounded up to the nearest integer
+ * @csqlfn #Floatspan_ceil()
+ */
+Span *
+floatspan_ceil(const Span *s)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s) || ! ensure_span_isof_type(s, T_FLOATSPAN))
+    return NULL;
+
+  Span *result = span_cp(s);
+  floatspan_floor_ceil_iter(result, &datum_ceil);
+  return result;
+}
+
+/*****************************************************************************/
+
 /**
  * @ingroup meos_internal_setspan_transf
  * @brief Return the second span expanded with the first one
@@ -1800,6 +1860,115 @@ tstzspan_shift_scale(const Span *s, const Interval *shift,
   return result;
 }
 
+/*****************************************************************************
+ * Spans function
+ *****************************************************************************/
+
+/**
+ * @ingroup meos_setspan_bbox
+ * @brief Return an array of spans from the values of a set
+ * @param[in] s Set
+ * @return On error return @p NULL
+ * @csqlfn #Set_spans()
+ */
+Span *
+set_spans(const Set *s)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s))
+    return NULL;
+
+  /* Output the composing spans */
+  Span *result = palloc(sizeof(Span) * s->count);
+  for (int i = 0; i < s->count; i++)
+    set_set_subspan(s, i, i, &result[i]);
+  return result;
+}
+
+/**
+ * @ingroup meos_setspan_bbox
+ * @brief Return an array of N spans from the values of a set
+ * @param[in] s Set
+ * @param[in] span_count Number of spans
+ * @param[out] count Number of elements in the output array
+ * @return On error return @p NULL
+ * @csqlfn #Set_split_n_spans()
+ */
+Span *
+set_split_n_spans(const Set *s, int span_count, int *count)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s) || ! ensure_not_null((void *) count) ||
+      ! ensure_numset_type(s->settype) || ! ensure_positive(span_count))
+    return NULL;
+
+  Span *result = palloc(sizeof(Span) * s->count);
+
+  /* Output the composing spans */
+  if (s->count <= span_count)
+  {
+    for (int i = 0; i < s->count; i++)
+      set_set_subspan(s, i, i, &result[i]);
+    *count = s->count;
+    return result;
+  }
+
+  /* Merge consecutive values to reach the maximum number of span */
+  /* Minimum number of values merged together in an output span */
+  int size = s->count / span_count;
+  /* Number of output spans that result from merging (size + 1) values */
+  int remainder = s->count % span_count;
+  int i = 0; /* Loop variable for input values */
+  for (int k = 0; k < span_count; k++)
+  {
+    int j = i + size;
+    if (k < remainder)
+      j++;
+    set_set_subspan(s, i, j - 1, &result[k]);
+    i = j;
+  }
+  assert(i == s->count);
+  *count = span_count;
+  return result;
+}
+
+/**
+ * @ingroup meos_setspan_bbox
+ * @brief Return an array of spans from a set obtained by merging consecutive
+ * elements
+ * @param[in] s Set
+ * @param[in] elems_per_span Number of elements merge into an ouput span
+ * @param[out] count Number of elements in the output array
+ * @return On error return @p NULL
+ * @csqlfn #Set_split_each_n_spans()
+ */
+Span *
+set_split_each_n_spans(const Set *s, int32 elems_per_span, int *count)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) s) || ! ensure_not_null((void *) count) ||
+      ! ensure_numset_type(s->settype) || ! ensure_positive(elems_per_span))
+    return NULL;
+
+  int nspans = ceil((double) s->count / (double) elems_per_span);
+  Span *result = palloc(sizeof(Span) * nspans);
+  int k = 0;
+  for (int i = 0; i < s->count; ++i)
+  {
+    if (i % elems_per_span == 0)
+      value_set_span(SET_VAL_N(s, i), s->basetype, &result[k++]);
+    else
+    {
+      Span span;
+      value_set_span(SET_VAL_N(s, i), s->basetype, &span);
+      span_expand(&span, &result[k - 1]);
+    }
+  }
+  assert(k == nspans);
+  *count = k;
+  return result;
+}
+
 /*****************************************************************************
  * Comparison functions for defining B-tree indexes
  *****************************************************************************/
@@ -1852,7 +2021,7 @@ span_ne(const Span *s1, const Span *s2)
  * @ingroup meos_internal_setspan_comp
  * @brief Return -1, 0, or 1 depending on whether the first span is less than,
  * equal, or greater than the second one
- * @param[in] s1,s2 Sets
+ * @param[in] s1,s2 Spans
  */
 int
 span_cmp_int(const Span *s1, const Span *s2)
