@@ -63,13 +63,11 @@
 bool
 ensure_spanset_isof_type(const SpanSet *ss, meosType spansettype)
 {
-  if (ss->spansettype != spansettype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "The span set value must be of type %s", meostype_name(spansettype));
-    return false;
-  }
-  return true;
+  if (ss->spansettype == spansettype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "The span set value must be of type %s", meostype_name(spansettype));
+  return false;
 }
 
 /**
@@ -78,13 +76,11 @@ ensure_spanset_isof_type(const SpanSet *ss, meosType spansettype)
 bool
 ensure_spanset_isof_basetype(const SpanSet *ss, meosType basetype)
 {
-  if (ss->basetype != basetype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed span set and base types");
-    return false;
-  }
-  return true;
+  if (ss->basetype == basetype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed span set and base types");
+  return false;
 }
 
 /**
@@ -93,13 +89,11 @@ ensure_spanset_isof_basetype(const SpanSet *ss, meosType basetype)
 bool
 ensure_same_spanset_type(const SpanSet *ss1, const SpanSet *ss2)
 {
-  if (ss1->spansettype != ss2->spansettype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed span set types");
-    return false;
-  }
-  return true;
+  if (ss1->spansettype == ss2->spansettype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed span set types");
+  return false;
 }
 
 /**
@@ -108,13 +102,11 @@ ensure_same_spanset_type(const SpanSet *ss1, const SpanSet *ss2)
 bool
 ensure_same_spanset_span_type(const SpanSet *ss, const Span *s)
 {
-  if (ss->spantype != s->spantype)
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
-      "Operation on mixed span set and span types");
-    return false;
-  }
-  return true;
+  if (ss->spantype == s->spantype)
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_TYPE,
+    "Operation on mixed span set and span types");
+  return false;
 }
 
 /*****************************************************************************
@@ -141,7 +133,7 @@ ensure_same_spanset_span_type(const SpanSet *ss, const Span *s)
  * @param[in] ss Span set
  * @param[in] v Value
  * @param[out] loc Location
- * @result Return true if the value is contained in the span set
+ * @return Return true if the value is contained in the span set
  */
 bool
 spanset_find_value(const SpanSet *ss, Datum v, int *loc)
@@ -419,15 +411,15 @@ tstzspanset_out(const SpanSet *ss)
  * @param[in] count Number of elements in the array
  * @param[in] maxcount Maximum number of elements in the array
  * @param[in] normalize True when the resulting value should be normalized
- * @param[in] ordered True when the input spans are ordered
+ * @param[in] order True when the input spans should should be ordered
  */
 SpanSet *
 spanset_make_exp(Span *spans, int count, int maxcount, bool normalize,
-  bool ordered)
+  bool order)
 {
   assert(spans); assert(count > 0); assert(count <= maxcount);
   /* Test the validity of the spans */
-  if (ordered)
+  if (! order)
   {
     for (int i = 0; i < count - 1; i++)
     {
@@ -450,7 +442,7 @@ spanset_make_exp(Span *spans, int count, int maxcount, bool normalize,
   int newcount = count;
   if (normalize && count > 1)
     /* Sort the values and remove duplicates */
-    newspans = spanarr_normalize(spans, count, ordered, &newcount);
+    newspans = spanarr_normalize(spans, count, order, &newcount);
 
   /* The first element span is already declared in the struct */
   size_t memsize = DOUBLE_PAD(sizeof(SpanSet)) +
@@ -483,16 +475,16 @@ spanset_make_exp(Span *spans, int count, int maxcount, bool normalize,
  * @param[in] spans Array of spans
  * @param[in] count Number of elements in the array
  * @param[in] normalize True if the resulting value should be normalized
- * @param[in] ordered True if the input spans are ordered
+ * @param[in] order True if the input spans should be ordered
  * @csqlfn #Spanset_constructor()
  */
 SpanSet *
-spanset_make(Span *spans, int count, bool normalize, bool ordered)
+spanset_make(Span *spans, int count, bool normalize, bool order)
 {
   /* Ensure validity of the arguments */
   if (! ensure_not_null((void *) spans) || ! ensure_positive(count))
     return NULL;
-  return spanset_make_exp(spans, count, count, normalize, ordered);
+  return spanset_make_exp(spans, count, count, normalize, order);
 }
 #endif /* MEOS */
 
@@ -503,16 +495,16 @@ spanset_make(Span *spans, int count, bool normalize, bool ordered)
  * @param[in] spans Array of spans
  * @param[in] count Number of elements in the array
  * @param[in] normalize True if the resulting value should be normalized.
- * @param[in] ordered True if the input spans are ordered
+ * @param[in] order True if the input spans should be ordered
  * @see #spanset_make
  */
 SpanSet *
-spanset_make_free(Span *spans, int count, bool normalize, bool ordered)
+spanset_make_free(Span *spans, int count, bool normalize, bool order)
 {
   assert(spans); assert(count >= 0);
   SpanSet *result = NULL;
   if (count > 0)
-    result = spanset_make_exp(spans, count, count, normalize, ordered);
+    result = spanset_make_exp(spans, count, count, normalize, order);
   pfree(spans);
   return result;
 }
@@ -564,7 +556,7 @@ value_to_spanset(Datum value, meosType basetype)
   meosType spantype = basetype_spantype(basetype);
   Span s;
   span_set(value, value, true, true, basetype, spantype, &s);
-  return spanset_make_exp(&s, 1, 1, NORMALIZE_NO, ORDERED);
+  return spanset_make_exp(&s, 1, 1, NORMALIZE_NO, ORDER_NO);
 }
 
 #if MEOS
@@ -646,7 +638,7 @@ set_spanset(const Set *s)
     Datum value = SET_VAL_N(s, i);
     span_set(value, value, true, true, s->basetype, spantype, &spans[i]);
   }
-  return spanset_make_free(spans, s->count, NORMALIZE, ORDERED);
+  return spanset_make_free(spans, s->count, NORMALIZE, ORDER_NO);
 }
 
 #if MEOS
@@ -676,7 +668,7 @@ SpanSet *
 span_spanset(const Span *s)
 {
   assert(s);
-  return spanset_make_exp((Span *) s, 1, 1, NORMALIZE_NO, ORDERED);
+  return spanset_make_exp((Span *) s, 1, 1, NORMALIZE_NO, ORDER_NO);
 }
 
 #if MEOS
@@ -714,7 +706,7 @@ intspanset_floatspanset(const SpanSet *ss)
   Span *spans = palloc(sizeof(Span) * ss->count);
   for (int i = 0; i < ss->count; i++)
     intspan_set_floatspan(SPANSET_SP_N(ss, i), &spans[i]);
-  return spanset_make_free(spans, ss->count, NORMALIZE, ORDERED);
+  return spanset_make_free(spans, ss->count, NORMALIZE, ORDER_NO);
 }
 
 #if MEOS
@@ -750,7 +742,7 @@ floatspanset_intspanset(const SpanSet *ss)
   Span *spans = palloc(sizeof(Span) * ss->count);
   for (int i = 0; i < ss->count; i++)
     floatspan_set_intspan(SPANSET_SP_N(ss, i), &spans[i]);
-  return spanset_make_free(spans, ss->count, NORMALIZE, ORDERED);
+  return spanset_make_free(spans, ss->count, NORMALIZE, ORDER_NO);
 }
 
 #if MEOS
@@ -786,7 +778,7 @@ datespanset_tstzspanset(const SpanSet *ss)
   Span *spans = palloc(sizeof(Span) * ss->count);
   for (int i = 0; i < ss->count; i++)
     datespan_set_tstzspan(SPANSET_SP_N(ss, i), &spans[i]);
-  return spanset_make_free(spans, ss->count, NORMALIZE, ORDERED);
+  return spanset_make_free(spans, ss->count, NORMALIZE, ORDER_NO);
 }
 
 #if MEOS
@@ -822,7 +814,7 @@ tstzspanset_datespanset(const SpanSet *ss)
   Span *spans = palloc(sizeof(Span) * ss->count);
   for (int i = 0; i < ss->count; i++)
     tstzspan_set_datespan(SPANSET_SP_N(ss, i), &spans[i]);
-  return spanset_make_free(spans, ss->count, NORMALIZE, ORDERED_NO);
+  return spanset_make_free(spans, ss->count, NORMALIZE, ORDER);
 }
 
 #if MEOS
@@ -859,6 +851,7 @@ spanset_mem_size(const SpanSet *ss)
   assert(ss);
   return (int) VARSIZE(DatumGetPointer(ss));
 }
+#endif /* MEOS */
 
 /**
  * @ingroup meos_setspan_accessor
@@ -874,7 +867,6 @@ spanset_span(const SpanSet *ss)
     return NULL;
   return span_cp(&ss->span);
 }
-#endif /* MEOS */
 
 /**
  * @ingroup meos_internal_setspan_accessor
@@ -1278,7 +1270,7 @@ datespanset_end_date(const SpanSet *ss)
  * @param[in] ss Span set
  * @param[in] n Number
  * @param[out] result Date
- * @result Return true if the date is found
+ * @return Return true if the date is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Datespanset_date_n()
  */
@@ -1323,7 +1315,7 @@ datespanset_dates(const SpanSet *ss)
     dates[ndates++] = s->lower;
     dates[ndates++] = s->upper;
   }
-  return set_make_free(dates, ndates, T_DATE, ORDERED);
+  return set_make_free(dates, ndates, T_DATE, ORDER_NO);
 }
 
 /**
@@ -1414,7 +1406,7 @@ tstzspanset_end_timestamptz(const SpanSet *ss)
  * @param[in] ss Span set
  * @param[in] n Number
  * @param[out] result Timestamptz
- * @result Return true if the timestamptz is found
+ * @return Return true if the timestamptz is found
  * @note It is assumed that n is 1-based
  * @csqlfn #Tstzspanset_timestamptz_n()
  */
@@ -1497,7 +1489,7 @@ tstzspanset_timestamps(const SpanSet *ss)
     if (times[ntimes - 1] != s->upper)
       times[ntimes++] = s->upper;
   }
-  return set_make_free(times, ntimes, T_TIMESTAMPTZ, ORDERED);
+  return set_make_free(times, ntimes, T_TIMESTAMPTZ, ORDER_NO);
 }
 
 /**
@@ -1589,13 +1581,12 @@ spanset_sps(const SpanSet *ss)
 #if MEOS
 /**
  * @ingroup meos_setspan_accessor
- * @brief Return an array copies of the spans of a span set
+ * @brief Return a C array with copies of the spans of a span set
  * @param[in] ss Span set
  * @return On error return @p NULL
- * @csqlfn #Spanset_spans()
  */
 Span **
-spanset_spans(const SpanSet *ss)
+spanset_spanarr(const SpanSet *ss)
 {
   /* Ensure validity of the arguments */
   if (! ensure_not_null((void *) ss))
@@ -1624,12 +1615,54 @@ spanset_compact(const SpanSet *ss)
   assert(ss);
   /* Create the final value reusing the array of spans in the span set */
   return spanset_make_exp((Span *) &ss->elems, ss->count, ss->count,
-    NORMALIZE, ORDERED_NO);
+    NORMALIZE, ORDER);
 }
 #endif /* MEOS */
 
 /*****************************************************************************/
 
+/**
+ * @ingroup meos_internal_setspan_transf
+ * @brief Return a float span set rounded down to the nearest integer
+ * @csqlfn #Floatspanset_floor()
+ */
+SpanSet *
+floatspanset_floor(const SpanSet *ss)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) ss) ||
+      ! ensure_spanset_isof_type(ss, T_FLOATSPANSET))
+    return NULL;
+
+  Span *spans = palloc(sizeof(Span) * ss->count);
+  memcpy(spans, ss->elems, sizeof(Span) * ss->count);
+  for (int i = 0; i < ss->count; i++)
+    floatspan_floor_ceil_iter(&spans[i], &datum_floor);
+  return spanset_make_free(spans, ss->count, NORMALIZE, ORDER_NO);
+}
+
+/**
+ * @ingroup meos_internal_setspan_transf
+ * @brief Return a float span set rounded up to the nearest integer
+ * @csqlfn #Floatset_ceil()
+ */
+SpanSet *
+floatspanset_ceil(const SpanSet *ss)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) ss) ||
+      ! ensure_spanset_isof_type(ss, T_FLOATSPANSET))
+    return NULL;
+
+  Span *spans = palloc(sizeof(Span) * ss->count);
+  memcpy(spans, ss->elems, sizeof(Span) * ss->count);
+  for (int i = 0; i < ss->count; i++)
+    floatspan_floor_ceil_iter(&spans[i], &datum_ceil);
+  return spanset_make_free(spans, ss->count, NORMALIZE, ORDER_NO);
+}
+
+/*****************************************************************************/
+
 /**
  * @ingroup meos_internal_setspan_transf
  * @brief Return a number set shifted and/or scaled by two intervals
@@ -1651,19 +1684,26 @@ numspanset_shift_scale(const SpanSet *ss, Datum shift, Datum width,
     return NULL;
 
   /* Copy the input span set to the output span set */
-  SpanSet *result = spanset_cp(ss);
+  SpanSet *copy = spanset_cp(ss);
 
   /* Shift and/or scale the bounding span */
   Datum delta;
   double scale;
-  numspan_shift_scale1(&result->span, shift, width, hasshift, haswidth,
+  numspan_shift_scale1(&copy->span, shift, width, hasshift, haswidth,
     &delta, &scale);
-  Datum origin = result->span.lower;
+  Datum origin = copy->span.lower;
 
   /* Shift and/or scale the span set */
   for (int i = 0; i < ss->count; i++)
-    numspan_delta_scale_iter(&result->elems[i], origin, delta, hasshift,
+    numspan_delta_scale_iter(&copy->elems[i], origin, delta, hasshift,
       scale);
+
+  /* Normalization is required after scaling */
+  Span *spans = palloc(sizeof(Span) * ss->count);
+  for (int i = 0; i < ss->count; i++)
+    memcpy(&spans[i], &copy->elems[i], sizeof(Span));
+  SpanSet *result = spanset_make_exp(spans, ss->count, ss->count, true, true);
+  pfree(copy); pfree(spans);
   return result;
 }
 
@@ -1790,6 +1830,159 @@ tstzspanset_shift_scale(const SpanSet *ss, const Interval *shift,
   return result;
 }
 
+/*****************************************************************************
+ * Spans function
+ *****************************************************************************/
+
+/**
+ * @ingroup meos_internal_setspan_comp
+ * @brief Return -1, 0, or 1 depending on whether the size of the first
+ * span is less than, equal, or greater than the second one
+ * @param[in] s1,s2 Spans
+ */
+int
+span_cmp_size(const Span *s1, const Span *s2)
+{
+  assert(s1); assert(s2); assert(s1->spantype == s2->spantype);
+  int result;
+  if (numspan_type(s1->spantype))
+  {
+    Datum d1 = distance_value_value(s1->upper, s1->lower, s1->basetype);
+    Datum d2 = distance_value_value(s2->upper, s2->lower, s2->basetype);
+    result = datum_cmp(d1, d2, s1->basetype);
+  }
+  else /* timespan_type(s1->spantype) */
+  {
+    Interval *dur1 = (s1->spantype == T_DATESPAN) ?
+      datespan_duration(s1) : tstzspan_duration(s1);
+    Interval *dur2 = (s2->spantype == T_DATESPAN) ?
+      datespan_duration(s2) : tstzspan_duration(s2);
+    result = pg_interval_cmp(dur1, dur2);
+    pfree(dur1); pfree(dur2);
+  }
+  return result;
+}
+
+/**
+ * @brief Sort function for comparying spans based on their size
+ */
+void
+spanarr_sort_size(Span *spans, int count)
+{
+  qsort(spans, (size_t) count, sizeof(Span),
+    (qsort_comparator) &span_cmp_size);
+  return;
+}
+
+/**
+ * @ingroup meos_setspan_bbox
+ * @brief Return the array of spans of a spanset
+ * @param[in] ss Span set
+ * @return On error return @p NULL
+ * @csqlfn #Spanset_spans()
+ */
+Span *
+spanset_spans(const SpanSet *ss)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) ss))
+    return NULL;
+
+  Span *result = palloc(sizeof(Span) * ss->count);
+  /* Output the composing spans */
+  for (int i = 0; i < ss->count; i++)
+    memcpy(&result[i], SPANSET_SP_N(ss, i), sizeof(Span));
+  return result;
+}
+
+/**
+ * @ingroup meos_setspan_bbox
+ * @brief Return an array of N spans from the composing spans of a spanset
+ * @param[in] ss Span set
+ * @param[in] span_count Number of spans
+ * @param[out] count Number of elements in the output array
+ * @return If the number of spans of the spanset is <= `span_count`, the result
+ * contains one span per composing span. On error return @p NULL
+ * @return On error return @p NULL
+ * @csqlfn #Spanset_split_n_spans()
+ */
+Span *
+spanset_split_n_spans(const SpanSet *ss, int span_count, int *count)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) ss) || ! ensure_not_null((void *) count) ||
+      ! ensure_positive(span_count))
+    return NULL;
+
+  /* Output the composing spans */
+  if (ss->count <= span_count)
+  {
+    *count = ss->count;
+    return spanset_spans(ss);
+  }
+
+  /* Merge consecutive sequences having the smallest gap */
+  Span *result = palloc(sizeof(Span) * span_count);
+  SpanSet *minus = minus_span_spanset(&ss->span, ss);
+  Span *holes = palloc(sizeof(Span) * minus->count);
+  for (int i = 0; i < minus->count; i++)
+    memcpy(&holes[i], SPANSET_SP_N(minus, i), sizeof(Span));
+  /* Sort the holes in increasing size */
+  spanarr_sort_size(holes, minus->count);
+  /* Number of holes in the original spanset that will be filled */
+  int nfills = minus->count - span_count + 1;
+  /* Sort the holes to fill the original spanset in increasing value/time */
+  spanarr_sort(holes, nfills);
+  SpanSet *tofill = spanset_make_exp(holes, nfills, nfills, NORMALIZE_NO,
+    ORDER_NO);
+  /* Resulting spanset with the holes filed */
+  SpanSet *res = union_spanset_spanset(ss, tofill);
+  assert(res->count == span_count);
+  /* Construct the resulting array of spans */
+  for (int i = 0; i < res->count; i++)
+    memcpy(&result[i], SPANSET_SP_N(res, i), sizeof(Span));
+  /* Clean-up and return */
+  pfree(minus); pfree(holes); pfree(tofill); pfree(res);
+  *count = span_count;
+  return result;
+}
+
+/**
+ * @ingroup meos_setspan_bbox
+ * @brief Return an array of N spans from a spanset obtained by merging
+ * consecutive composing spans 
+ * @param[in] ss Spanset
+ * @param[in] elems_per_span Number of spans merged into an ouput span
+ * @param[out] count Number of elements in the output array
+ * @return On error return @p NULL
+ * @csqlfn #Spanset_split_each_n_spans()
+ */
+Span *
+spanset_split_each_n_spans(const SpanSet *ss, int32 elems_per_span, int *count)
+{
+  /* Ensure validity of the arguments */
+  if (! ensure_not_null((void *) ss) || ! ensure_not_null((void *) count) ||
+      ! ensure_positive(elems_per_span))
+    return NULL;
+
+  int nspans = ceil((double) ss->count / (double) elems_per_span);
+  Span *result = palloc(sizeof(Span) * nspans);
+  int k = 0;
+  for (int i = 0; i < ss->count; ++i)
+  {
+    if (i % elems_per_span == 0)
+      result[k++] = *SPANSET_SP_N(ss, i);
+    else
+    {
+      Span span = *SPANSET_SP_N(ss, i);
+      span_expand(&span, &result[k - 1]);
+    }
+  }
+  assert(k == nspans);
+  *count = k;
+  return result;
+}
+
 /*****************************************************************************
  * Comparison functions for defining B-tree indexes
  *****************************************************************************/
