@@ -52,7 +52,7 @@
 #include "general/type_util.h"
 
 /** Buffer size for input and output of TBox values */
-#define MAXTBOXLEN    128
+#define TBOX_MAXLEN    128
 
 /*****************************************************************************
  * Parameter tests
@@ -65,13 +65,11 @@ bool
 ensure_has_X_tbox(const TBox *box)
 {
   assert(box);
-  if (! MEOS_FLAGS_GET_X(box->flags))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_VALUE,
-      "The box must have value dimension");
-    return false;
-  }
-  return true;
+  if (MEOS_FLAGS_GET_X(box->flags))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_VALUE,
+    "The box must have value dimension");
+  return false;
 }
 
 /**
@@ -81,13 +79,11 @@ bool
 ensure_has_T_tbox(const TBox *box)
 {
   assert(box);
-  if (! MEOS_FLAGS_GET_T(box->flags))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_VALUE,
-      "The box must have time dimension");
-    return false;
-  }
-  return true;
+  if (MEOS_FLAGS_GET_T(box->flags))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_VALUE,
+    "The box must have time dimension");
+  return false;
 }
 
 /**
@@ -96,14 +92,12 @@ ensure_has_T_tbox(const TBox *box)
 bool
 ensure_same_dimensionality_tbox(const TBox *box1, const TBox *box2)
 {
-  if (MEOS_FLAGS_GET_X(box1->flags) != MEOS_FLAGS_GET_X(box2->flags) ||
-    MEOS_FLAGS_GET_T(box1->flags) != MEOS_FLAGS_GET_T(box2->flags))
-  {
-    meos_error(ERROR, MEOS_ERR_INVALID_ARG_VALUE,
-      "The boxes must be of the same dimensionality");
-    return false;
-  }
-  return true;
+  if (MEOS_FLAGS_GET_X(box1->flags) == MEOS_FLAGS_GET_X(box2->flags) &&
+      MEOS_FLAGS_GET_T(box1->flags) == MEOS_FLAGS_GET_T(box2->flags))
+    return true;
+  meos_error(ERROR, MEOS_ERR_INVALID_ARG_VALUE,
+    "The boxes must be of the same dimensionality");
+  return false;
 }
 
 /*****************************************************************************
@@ -148,7 +142,7 @@ tbox_out(const TBox *box, int maxdd)
   if (! ensure_not_null((void *) box) || ! ensure_not_negative(maxdd))
     return NULL;
 
-  static size_t size = MAXTBOXLEN + 1;
+  static size_t size = TBOX_MAXLEN + 1;
   char *result = palloc(size);
   char *span = NULL, *period = NULL;
   bool hasx = MEOS_FLAGS_GET_X(box->flags);
@@ -1060,18 +1054,17 @@ tbox_tmax_inc(const TBox *box, bool *result)
  * @param[in] box Temporal box
  * @param[in] shift Value to shift the value span
  * @param[in] width Width of the result
- * @param[in] basetype Type of the values
  * @param[in] hasshift True when the shift argument is given
  * @param[in] haswidth True when the width argument is given
  */
 TBox *
 tbox_shift_scale_value(const TBox *box, Datum shift, Datum width,
-  meosType basetype, bool hasshift, bool haswidth)
+  bool hasshift, bool haswidth)
 {
   assert(box);
   /* Ensure validity of the arguments */
   if (! ensure_has_X_tbox(box) || ! ensure_one_true(hasshift, haswidth) ||
-      ! ensure_span_isof_basetype(&box->span, basetype) ||
+      ! ensure_span_isof_basetype(&box->span, box->span.basetype) ||
       (haswidth && ! ensure_positive_datum(width, box->span.basetype)))
     return NULL;
 
@@ -1108,7 +1101,7 @@ tbox_shift_scale_int(const TBox *box, int shift, int width, bool hasshift,
     return NULL;
 
   return tbox_shift_scale_value(box, Int32GetDatum(shift),
-    Int32GetDatum(width), T_INT4, hasshift, haswidth);
+    Int32GetDatum(width), hasshift, haswidth);
 }
 
 /**
@@ -1131,7 +1124,7 @@ tbox_shift_scale_float(const TBox *box, double shift, double width,
     return NULL;
 
   return tbox_shift_scale_value(box, Float8GetDatum(shift),
-    Float8GetDatum(width), T_FLOAT8, hasshift, haswidth);
+    Float8GetDatum(width), hasshift, haswidth);
 }
 
 #endif /* MEOS */
