@@ -61,10 +61,10 @@
 
 /**
  * @ingroup meos_setspan_transf
- * @brief Return a timestamptz with the precision set to a time bucket
+ * @brief Return a timestamptz with the precision set to a time bin
  * @param[in] t Time value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 TimestampTz
 timestamptz_tprecision(TimestampTz t, const Interval *duration,
@@ -74,15 +74,15 @@ timestamptz_tprecision(TimestampTz t, const Interval *duration,
   if (! ensure_not_null((void *) duration) ||
       ! ensure_valid_duration(duration))
     return DT_NOEND;
-  return timestamptz_bucket(t, duration, torigin);
+  return timestamptz_get_bin(t, duration, torigin);
 }
 
 /**
  * @ingroup meos_setspan_transf
- * @brief Return a timestamptz set with the precision set to a time bucket
+ * @brief Return a timestamptz set with the precision set to a time bin
  * @param[in] s Timestamptz set
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 Set *
 tstzset_tprecision(const Set *s, const Interval *duration, TimestampTz torigin)
@@ -96,16 +96,16 @@ tstzset_tprecision(const Set *s, const Interval *duration, TimestampTz torigin)
   Datum *values = palloc(sizeof(Datum) * s->count);
   /* Loop for each value */
   for (int i = 0; i < s->count; i++)
-    values[i] = timestamptz_bucket(SET_VAL_N(s, i), duration, torigin);
-  return set_make_free(values, s->count, T_TIMESTAMPTZ, ORDERED_NO);
+    values[i] = timestamptz_get_bin(SET_VAL_N(s, i), duration, torigin);
+  return set_make_free(values, s->count, T_TIMESTAMPTZ, ORDER);
 }
 
 /**
  * @ingroup meos_setspan_transf
- * @brief Return a timestamptz span with the precision set to a time bucket
+ * @brief Return a timestamptz span with the precision set to a time bin
  * @param[in] s Time value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 Span *
 tstzspan_tprecision(const Span *s, const Interval *duration,
@@ -120,20 +120,20 @@ tstzspan_tprecision(const Span *s, const Interval *duration,
   int64 tunits = interval_units(duration);
   TimestampTz lower = DatumGetTimestampTz(s->lower);
   TimestampTz upper = DatumGetTimestampTz(s->upper);
-  TimestampTz lower_bucket = timestamptz_bucket(lower, duration, torigin);
-  /* We need to add tunits to obtain the end timestamptz of the last bucket */
-  TimestampTz upper_bucket = timestamptz_bucket(upper, duration, torigin) +
+  TimestampTz lower_bin = timestamptz_get_bin(lower, duration, torigin);
+  /* We need to add tunits to obtain the end timestamptz of the last bin */
+  TimestampTz upper_bin = timestamptz_get_bin(upper, duration, torigin) +
     tunits;
-  return span_make(TimestampTzGetDatum(lower_bucket),
-    TimestampTzGetDatum(upper_bucket), true, false, T_TIMESTAMPTZ);
+  return span_make(TimestampTzGetDatum(lower_bin),
+    TimestampTzGetDatum(upper_bin), true, false, T_TIMESTAMPTZ);
 }
 
 /**
  * @ingroup meos_setspan_transf
- * @brief Return a timestamptz span set with the precision set to a time bucket
+ * @brief Return a timestamptz span set with the precision set to a time bin
  * @param[in] ss Time value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 SpanSet *
 tstzspanset_tprecision(const SpanSet *ss, const Interval *duration,
@@ -148,17 +148,17 @@ tstzspanset_tprecision(const SpanSet *ss, const Interval *duration,
   int64 tunits = interval_units(duration);
   TimestampTz lower = DatumGetTimestampTz(ss->span.lower);
   TimestampTz upper = DatumGetTimestampTz(ss->span.upper);
-  TimestampTz lower_bucket = timestamptz_bucket(lower, duration, torigin);
-  /* We need to add tunits to obtain the end timestamptz of the last bucket */
-  TimestampTz upper_bucket = timestamptz_bucket(upper, duration, torigin) +
+  TimestampTz lower_bin = timestamptz_get_bin(lower, duration, torigin);
+  /* We need to add tunits to obtain the end timestamptz of the last bin */
+  TimestampTz upper_bin = timestamptz_get_bin(upper, duration, torigin) +
     tunits;
-  /* Number of buckets */
-  int count = (int) (((int64) upper_bucket - (int64) lower_bucket) / tunits);
+  /* Number of bins */
+  int count = (int) (((int64) upper_bin - (int64) lower_bin) / tunits);
   Span *spans = palloc(sizeof(Span) * count);
-  lower = lower_bucket;
-  upper = lower_bucket + tunits;
+  lower = lower_bin;
+  upper = lower_bin + tunits;
   int nspans = 0;
-  /* Loop for each bucket */
+  /* Loop for each bin */
   for (int i = 0; i < count; i++)
   {
     Span s;
@@ -169,7 +169,7 @@ tstzspanset_tprecision(const SpanSet *ss, const Interval *duration,
     lower += tunits;
     upper += tunits;
   }
-  return spanset_make_free(spans, nspans, NORMALIZE, ORDERED);
+  return spanset_make_free(spans, nspans, NORMALIZE, ORDER_NO);
 }
 
 /*****************************************************************************
@@ -177,57 +177,55 @@ tstzspanset_tprecision(const SpanSet *ss, const Interval *duration,
  *****************************************************************************/
 
 /**
- * @brief Return a temporal instant with the precision set to a time bucket
+ * @brief Return a temporal instant with the precision set to a time bin
  * @param[in] inst Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 TInstant *
 tinstant_tprecision(const TInstant *inst, const Interval *duration,
   TimestampTz torigin)
 {
-  assert(inst); assert(duration);
-  assert(valid_duration(duration));
-  TimestampTz lower = timestamptz_bucket(inst->t, duration, torigin);
+  assert(inst); assert(duration); assert(valid_duration(duration));
+  TimestampTz lower = timestamptz_get_bin(inst->t, duration, torigin);
   Datum value = tinstant_val(inst);
   return tinstant_make(value, inst->temptype, lower);
 }
 
 /**
- * @brief Return a temporal sequence with the precision set to a time bucket
+ * @brief Return a temporal sequence with the precision set to a time bin
  * @param[in] seq Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 TSequence *
 tsequence_tprecision(const TSequence *seq, const Interval *duration,
   TimestampTz torigin)
 {
-  assert(seq); assert(duration);
+  assert(seq); assert(duration); assert(valid_duration(duration));
   assert(seq->temptype == T_TINT || seq->temptype == T_TFLOAT ||
     seq->temptype == T_TGEOMPOINT || seq->temptype == T_TGEOGPOINT );
-  assert(valid_duration(duration));
 
   int64 tunits = interval_units(duration);
   TimestampTz lower = DatumGetTimestampTz(seq->period.lower);
   TimestampTz upper = DatumGetTimestampTz(seq->period.upper);
-  TimestampTz lower_bucket = timestamptz_bucket(lower, duration, torigin);
-  /* We need to add tunits to obtain the end timestamp of the last bucket */
-  TimestampTz upper_bucket = timestamptz_bucket(upper, duration, torigin) +
+  TimestampTz lower_bin = timestamptz_get_bin(lower, duration, torigin);
+  /* We need to add tunits to obtain the end timestamp of the last bin */
+  TimestampTz upper_bin = timestamptz_get_bin(upper, duration, torigin) +
     tunits;
-  /* Number of buckets */
-  int count = (int) (((int64) upper_bucket - (int64) lower_bucket) / tunits);
+  /* Number of bins */
+  int count = (int) (((int64) upper_bin - (int64) lower_bin) / tunits);
   TInstant **ininsts = palloc(sizeof(TInstant *) * seq->count);
   TInstant **outinsts = palloc(sizeof(TInstant *) * count);
-  lower = lower_bucket;
-  upper = lower_bucket + tunits;
+  lower = lower_bin;
+  upper = lower_bin + tunits;
   interpType interp = MEOS_FLAGS_GET_INTERP(seq->flags);
   meosType temptype_out = (seq->temptype == T_TINT) ? T_TFLOAT : seq->temptype;
   /* Determine whether we are computing the twAvg or the twCentroid */
   bool twavg = tnumber_type(seq->temptype);
-  /* New instants computing the value at the beginning/end of the bucket */
+  /* New instants computing the value at the beginning/end of the bin */
   TInstant *start = NULL, *end = NULL;
-  /* Sequence for computing the twAvg/twCentroid of each bucket */
+  /* Sequence for computing the twAvg/twCentroid of each bin */
   TSequence *seq1;
   Datum value;
   int i = 0;   /* Instant of the input sequence being processed */
@@ -239,33 +237,33 @@ tsequence_tprecision(const TSequence *seq, const Interval *duration,
     /* Get the next instant */
     TInstant *inst = (TInstant *) TSEQUENCE_INST_N(seq, i);
     int cmp = timestamptz_cmp_internal(inst->t, upper);
-    /* If the instant is in the current bucket consume it */
+    /* If the instant is in the current bin consume it */
     if (cmp <= 0)
     {
       ininsts[k++] = inst;
       i++;
     }
-    /* If we have reached the end of the bucket */
+    /* If we have reached the end of the bin */
     if (cmp >= 0)
     {
       assert(k > 0);
-      /* Compute the value at the end of the bucket if we do not have it */
+      /* Compute the value at the end of the bin if we do not have it */
       if (interp != DISCRETE &&
           timestamptz_cmp_internal(ininsts[k - 1]->t, upper) < 0)
       {
         tsequence_value_at_timestamptz(seq, upper, false, &value);
-        ininsts[k++] = end = tinstant_make(value, seq->temptype, upper);
+        ininsts[k++] = end = tinstant_make_free(value, seq->temptype, upper);
       }
       seq1 = tsequence_make((const TInstant **) ininsts, k, true, true, interp,
         NORMALIZE);
-      /* Compute the twAvg/twCentroid for the bucket */
+      /* Compute the twAvg/twCentroid for the bin */
       value = twavg ? Float8GetDatum(tnumberseq_twavg(seq1)) :
         PointerGetDatum(tpointseq_twcentroid(seq1));
       outinsts[l++] = tinstant_make(value, temptype_out, lower);
       pfree(seq1);
       if (! twavg)
         pfree(DatumGetPointer(value));
-      /* Free the instant at the beginning of the bucket if it was generated */
+      /* Free the instant at the beginning of the bin if it was generated */
       if (start)
       {
         pfree(start); start = NULL;
@@ -276,8 +274,8 @@ tsequence_tprecision(const TSequence *seq, const Interval *duration,
       }
       if (interp != DISCRETE)
       {
-        /* The instant at the end of the current bucket is the start of the next
-         * one excepted when the last bucket is empty */
+        /* The instant at the end of the current bin is the start of the next
+         * one excepted when the last bin is empty */
         if (i < seq->count || seq->period.upper_inc)
         {
           ininsts[0] = ininsts[k - 1];
@@ -290,7 +288,7 @@ tsequence_tprecision(const TSequence *seq, const Interval *duration,
       upper += tunits;
     }
   }
-  /* Compute the twAvg/twCentroid of the last bucket */
+  /* Compute the twAvg/twCentroid of the last bin */
   if (k > 0)
   {
     seq1 = tsequence_make((const TInstant **) ininsts, k, true, true, interp,
@@ -300,6 +298,7 @@ tsequence_tprecision(const TSequence *seq, const Interval *duration,
     outinsts[l++] = tinstant_make(value, temptype_out, lower);
     if (! twavg)
       pfree(DatumGetPointer(value));
+    pfree(seq1);
   }
   /* The lower and upper bounds are both true since the tprecision operation
    * amounts to a granularity change */
@@ -312,40 +311,39 @@ tsequence_tprecision(const TSequence *seq, const Interval *duration,
 }
 
 /**
- * @brief Return a temporal sequence set with the precision set to a time bucket
+ * @brief Return a temporal sequence set with the precision set to a time bin
  * @param[in] ss Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 TSequenceSet *
 tsequenceset_tprecision(const TSequenceSet *ss, const Interval *duration,
   TimestampTz torigin)
 {
-  assert(ss); assert(duration);
+  assert(ss); assert(duration); assert(valid_duration(duration));
   assert(ss->temptype == T_TINT || ss->temptype == T_TFLOAT ||
     ss->temptype == T_TGEOMPOINT || ss->temptype == T_TGEOGPOINT );
-  assert(valid_duration(duration));
 
   int64 tunits = interval_units(duration);
   TimestampTz lower = DatumGetTimestampTz(ss->period.lower);
   TimestampTz upper = DatumGetTimestampTz(ss->period.upper);
-  TimestampTz lower_bucket = timestamptz_bucket(lower, duration, torigin);
-  /* We need to add tunits to obtain the end timestamp of the last bucket */
-  TimestampTz upper_bucket = timestamptz_bucket(upper, duration, torigin) +
+  TimestampTz lower_bin = timestamptz_get_bin(lower, duration, torigin);
+  /* We need to add tunits to obtain the end timestamp of the last bin */
+  TimestampTz upper_bin = timestamptz_get_bin(upper, duration, torigin) +
     tunits;
-  /* Number of buckets */
-  int count = (int) (((int64) upper_bucket - (int64) lower_bucket) / tunits);
+  /* Number of bins */
+  int count = (int) (((int64) upper_bin - (int64) lower_bin) / tunits);
   TInstant **instants = palloc(sizeof(TInstant *) * count);
   TSequence **sequences = palloc(sizeof(TSequence *) * count);
-  lower = lower_bucket;
-  upper = lower_bucket + tunits;
+  lower = lower_bin;
+  upper = lower_bin + tunits;
   interpType interp = MEOS_FLAGS_GET_INTERP(ss->flags);
   meosType temptype_out = (ss->temptype == T_TINT) ? T_TFLOAT : ss->temptype;
   /* Determine whether we are computing the twAvg or the twCentroid */
   bool twavg = tnumber_type(ss->temptype);
   int ninsts = 0;
   int nseqs = 0;
-  /* Loop for each bucket */
+  /* Loop for each bin */
   for (int i = 0; i < count; i++)
   {
     Span p;
@@ -393,10 +391,10 @@ tsequenceset_tprecision(const TSequenceSet *ss, const Interval *duration,
 
 /**
  * @ingroup meos_temporal_analytics_reduction
- * @brief Return a temporal value with the precision set to period buckets
+ * @brief Return a temporal value with the precision set to time bins
  * @param[in] temp Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  * @csqlfn #Temporal_tprecision()
  */
 Temporal *
@@ -428,18 +426,17 @@ temporal_tprecision(const Temporal *temp, const Interval *duration,
  *****************************************************************************/
 
 /**
- * @brief Return a temporal value sampled at period buckets
+ * @brief Return a temporal value sampled at time bins
  * @param[in] inst Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 TInstant *
 tinstant_tsample(const TInstant *inst, const Interval *duration,
   TimestampTz torigin)
 {
-  assert(inst); assert(duration);
-  assert(valid_duration(duration));
-  TimestampTz lower = timestamptz_bucket(inst->t, duration, torigin);
+  assert(inst); assert(duration); assert(valid_duration(duration));
+  TimestampTz lower = timestamptz_get_bin(inst->t, duration, torigin);
   if (timestamp_cmp_internal(lower, inst->t) == 0)
     return tinstant_copy(inst);
   return NULL;
@@ -447,36 +444,36 @@ tinstant_tsample(const TInstant *inst, const Interval *duration,
 
 
 /**
- * @brief Return a temporal value sampled according to period buckets
+ * @brief Return a temporal value sampled according to time bins
  * @param[in] seq Temporal value
- * @param[in] lower_bucket,upper_bucket First and last buckets
+ * @param[in] lower_bin,upper_bin First and last bins
  * @param[in] tunits Time size of the tiles in PostgreSQL time units
  * @param[out] result Output array of temporal instants
  * @note The result is an temporal sequence with discrete interpolation
  */
 int
-tsequence_tsample_iter(const TSequence *seq, TimestampTz lower_bucket,
-  TimestampTz upper_bucket, int64 tunits, TInstant **result)
+tsequence_tsample_iter(const TSequence *seq, TimestampTz lower_bin,
+  TimestampTz upper_bin, int64 tunits, TInstant **result)
 {
   interpType interp = MEOS_FLAGS_GET_INTERP(seq->flags);
   const TInstant *start = TSEQUENCE_INST_N(seq, 0);
-  TimestampTz lower = lower_bucket;
+  TimestampTz lower = lower_bin;
   int i; /* Current segment of the sequence */
   int ninsts = 0; /* Number of instants of the result */
   int cmp1;
   if (interp == DISCRETE)
   {
     i = 0; /* Current instant of the sequence */
-    while (i < seq->count && lower < upper_bucket)
+    while (i < seq->count && lower < upper_bin)
     {
       cmp1 = timestamptz_cmp_internal(start->t, lower);
-      /* If the instant is equal to the lower bound of the bucket */
+      /* If the instant is equal to the lower bound of the bin */
       if (cmp1 == 0)
       {
         result[ninsts++] = tinstant_copy(start);
         lower += tunits;
       }
-      /* Advance the bucket if it is after the instant */
+      /* Advance the bin if it is after the instant */
       else if (cmp1 > 0)
       {
         int times = ceil((double) (start->t - lower) / tunits);
@@ -499,24 +496,24 @@ tsequence_tsample_iter(const TSequence *seq, TimestampTz lower_bucket,
     const TInstant *end = TSEQUENCE_INST_N(seq, 1);
     bool lower_inc = seq->period.lower_inc;
     i = 1; /* Current segment of the sequence */
-    while (i < seq->count && lower < upper_bucket)
+    while (i < seq->count && lower < upper_bin)
     {
       bool upper_inc = (i == seq->count - 1) ? seq->period.upper_inc : false;
       cmp1 = timestamptz_cmp_internal(start->t, lower);
       int cmp2 = timestamptz_cmp_internal(lower, end->t);
-      /* If the segment contains the lower bound of the bucket */
+      /* If the segment contains the lower bound of the bin */
       if ((cmp1 < 0 || (cmp1 == 0 && lower_inc)) &&
           (cmp2 < 0 || (cmp2 == 0 && upper_inc)))
       {
         Datum value = tsegment_value_at_timestamptz(start, end, interp, lower);
         result[ninsts++] = tinstant_make(value, seq->temptype, lower);
-        /* Advance the bucket */
+        /* Advance the bin */
         lower += tunits;
       }
-      /* Advance the bucket if it is after the start of the segment */
+      /* Advance the bin if it is after the start of the segment */
       else if (cmp1 >= 0)
         lower += tunits;
-      /* Advance the segment if it is after the lower bound of the bucket */
+      /* Advance the segment if it is after the lower bound of the bin */
       else if (cmp2 >= 0)
       {
         /* If there are no more segments */
@@ -531,77 +528,120 @@ tsequence_tsample_iter(const TSequence *seq, TimestampTz lower_bucket,
 }
 
 /**
- * @brief Return a temporal value sampled according to period buckets
+ * @brief Return a temporal value sampled according to time bins
  * @param[in] seq Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
- * @note The result is an temporal sequence with discrete interpolation
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
+ * @param[in] interp Interpolation
  */
 TSequence *
 tsequence_tsample(const TSequence *seq, const Interval *duration,
-  TimestampTz torigin)
+  TimestampTz torigin, interpType interp)
 {
-  assert(seq); assert(duration);
-  assert(valid_duration(duration));
+  assert(seq); assert(duration); assert(valid_duration(duration));
+
   int64 tunits = interval_units(duration);
   TimestampTz lower = DatumGetTimestampTz(seq->period.lower);
   TimestampTz upper = DatumGetTimestampTz(seq->period.upper);
-  TimestampTz lower_bucket = timestamptz_bucket(lower, duration, torigin);
-  /* We need to add tunits to obtain the end timestamp of the last bucket */
-  TimestampTz upper_bucket = timestamptz_bucket(upper, duration, torigin) +
+  TimestampTz lower_bin = timestamptz_get_bin(lower, duration, torigin);
+  /* We need to add tunits to obtain the end timestamp of the last bin */
+  TimestampTz upper_bin = timestamptz_get_bin(upper, duration, torigin) +
     tunits;
-  /* Number of buckets */
-  int count = (int) (((int64) upper_bucket - (int64) lower_bucket) / tunits) + 1;
+  /* Number of bins */
+  int count = (int) (((int64) upper_bin - (int64) lower_bin) / tunits) + 1;
   TInstant **instants = palloc(sizeof(TInstant *) * count);
-  int ninsts = tsequence_tsample_iter(seq, lower_bucket, upper_bucket, tunits,
+  int ninsts = tsequence_tsample_iter(seq, lower_bin, upper_bin, tunits,
     &instants[0]);
-  return tsequence_make_free(instants, ninsts, true, true, DISCRETE,
-    NORMALIZE_NO);
+  return tsequence_make_free(instants, ninsts, true, true, interp, NORMALIZE);
 }
 
 /**
- * @brief Return a temporal value sampled according to period buckets
+ * @brief Return a temporal value sampled according to time bins
  * @param[in] ss Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
  */
 TSequence *
-tsequenceset_tsample(const TSequenceSet *ss, const Interval *duration,
+tsequenceset_disc_tsample(const TSequenceSet *ss, const Interval *duration,
   TimestampTz torigin)
 {
   assert(ss); assert(duration); assert(valid_duration(duration));
+
   int64 tunits = interval_units(duration);
   TimestampTz lower = tsequenceset_start_timestamptz(ss);
   TimestampTz upper = tsequenceset_end_timestamptz(ss);
-  TimestampTz lower_bucket = timestamptz_bucket(lower, duration, torigin);
-  /* We need to add tunits to obtain the end timestamp of the last bucket */
-  TimestampTz upper_bucket = timestamptz_bucket(upper, duration, torigin) +
+  TimestampTz lower_bin = timestamptz_get_bin(lower, duration, torigin);
+  /* We need to add tunits to obtain the end timestamp of the last bin */
+  TimestampTz upper_bin = timestamptz_get_bin(upper, duration, torigin) +
     tunits;
-  /* Number of buckets */
-  int count = (int) (((int64) upper_bucket - (int64) lower_bucket) / tunits) + 1;
+  /* Number of bins */
+  int count = (int) (((int64) upper_bin - (int64) lower_bin) / tunits) + 1;
   TInstant **instants = palloc(sizeof(TInstant *) * count);
   /* Loop for each segment */
   int ninsts = 0;
   for (int i = 0; i < ss->count; i++)
   {
-    ninsts += tsequence_tsample_iter(TSEQUENCESET_SEQ_N(ss, i), lower_bucket,
-      upper_bucket, tunits, &instants[ninsts]);
+    ninsts += tsequence_tsample_iter(TSEQUENCESET_SEQ_N(ss, i), lower_bin,
+      upper_bin, tunits, &instants[ninsts]);
   }
   return tsequence_make_free(instants, ninsts, true, true, DISCRETE,
-    NORMALIZE_NO);
+    NORMALIZE);
+}
+
+/**
+ * @brief Return a temporal value sampled according to time bins
+ * @param[in] ss Temporal value
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
+ * @param[in] interp Interpolation
+ */
+TSequenceSet *
+tsequenceset_cont_tsample(const TSequenceSet *ss, const Interval *duration,
+  TimestampTz torigin, interpType interp)
+{
+  assert(ss); assert(duration); assert(valid_duration(duration));
+  assert(interp != DISCRETE);
+
+  TSequence **sequences = palloc(sizeof(TSequence *) * ss->count);
+  int nseqs = 0;
+  for (int i = 0; i < ss->count; i++)
+  {
+    TSequence *seq = tsequence_tsample(TSEQUENCESET_SEQ_N(ss, i), duration,
+      torigin, interp);
+    if (seq)
+      sequences[nseqs++] = seq;
+  }
+  return tsequenceset_make_free(sequences, nseqs, NORMALIZE);
+}
+
+/**
+ * @brief Return a temporal value sampled according to time bins
+ * @param[in] ss Temporal value
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
+ * @param[in] interp Interpolation
+ */
+Temporal *
+tsequenceset_tsample(const TSequenceSet *ss, const Interval *duration,
+  TimestampTz torigin, interpType interp)
+{
+  return (interp == DISCRETE) ?
+    (Temporal *) tsequenceset_disc_tsample(ss, duration, torigin) :
+    (Temporal *) tsequenceset_cont_tsample(ss, duration, torigin, interp);
 }
 
 /**
  * @ingroup meos_temporal_analytics_reduction
- * @brief Return a temporal value sampled according to period buckets
+ * @brief Return a temporal value sampled according to time bins
  * @param[in] temp Temporal value
- * @param[in] duration Size of the time buckets
- * @param[in] torigin Time origin of the buckets
+ * @param[in] duration Size of the time bins
+ * @param[in] torigin Time origin of the bins
+ * @param[in] interp Interpolation
  * @csqlfn #Temporal_tsample()
  */
 Temporal *
 temporal_tsample(const Temporal *temp, const Interval *duration,
-  TimestampTz torigin)
+  TimestampTz torigin, interpType interp)
 {
   /* Ensure validity of the arguments */
   if (! ensure_not_null((void *) temp) ||
@@ -617,10 +657,10 @@ temporal_tsample(const Temporal *temp, const Interval *duration,
         torigin);
     case TSEQUENCE:
       return (Temporal *) tsequence_tsample((TSequence *) temp, duration,
-        torigin);
+        torigin, interp);
     default: /* TSEQUENCESET */
       return (Temporal *) tsequenceset_tsample((TSequenceSet *) temp,
-        duration, torigin);
+        duration, torigin, interp);
   }
 }
 
@@ -765,7 +805,7 @@ temporal_frechet_distance(const Temporal *temp1, const Temporal *temp2)
  * @ingroup meos_temporal_analytics_similarity
  * @brief Return the Dynamic Time Warp distance between two temporal values
  * @param[in] temp1,temp2 Temporal values
- * @result On error return @p DBL_MAX
+ * @return On error return @p DBL_MAX
  * @csqlfn #Temporal_dyntimewarp_distance()
  */
 double
@@ -1297,8 +1337,7 @@ temporal_simplify_min_tdelta(const Temporal *temp, const Interval *mint)
     case TINSTANT:
       return temporal_cp(temp);
     case TSEQUENCE:
-      return ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ?
-        temporal_cp(temp) :
+      return ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ? temporal_cp(temp) :
         (Temporal *) tsequence_simplify_min_tdelta((TSequence *) temp, mint);
     default: /* TSEQUENCESET */
       return (Temporal *) tsequenceset_simplify_min_tdelta((TSequenceSet *) temp,
@@ -1575,7 +1614,7 @@ tsequence_simplify_max_dist(const TSequence *seq, double dist, bool syncdist,
       continue;
     }
   }
-  if (instants[ninsts - 1] != cur)
+  if (ninsts > 0 && instants[ninsts - 1] != cur)
     instants[ninsts++] = cur;
   TSequence *result = tsequence_make(instants, ninsts,
     (ninsts == 1) ? true : seq->period.lower_inc,
@@ -1633,8 +1672,7 @@ temporal_simplify_max_dist(const Temporal *temp, double dist, bool syncdist)
     case TINSTANT:
       return temporal_cp(temp);
     case TSEQUENCE:
-      return ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ?
-        temporal_cp(temp) :
+      return ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ? temporal_cp(temp) :
         (Temporal *) tsequence_simplify_max_dist((TSequence *) temp, dist,
           syncdist, 2);
     default: /* TSEQUENCESET */
@@ -1786,8 +1824,7 @@ temporal_simplify_dp(const Temporal *temp, double dist, bool syncdist)
     case TINSTANT:
       return temporal_cp(temp);
     case TSEQUENCE:
-      return ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ?
-        temporal_cp(temp) :
+      return ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ? temporal_cp(temp) :
         (Temporal *) tsequence_simplify_dp((TSequence *) temp, dist, syncdist, 2);
     default: /* TSEQUENCESET */
       return (Temporal *) tsequenceset_simplify_dp((TSequenceSet *) temp, dist,
