@@ -130,7 +130,7 @@ tsequence_merge(const TSequence *seq1, const TSequence *seq2)
  * may be a period. For this reason two passes are necessary.
  * @param[in] sequences Array of temporal sequences
  * @param[in] count Number of elements in the array
- * @result Result value that can be either a temporal instant or a temporal
+ * @return Result value that can be either a temporal instant or a temporal
  * discrete sequence
  */
 Temporal *
@@ -160,7 +160,6 @@ tdiscseq_merge_array(const TSequence **sequences, int count)
  * @param[in] sequences Array of values
  * @param[in] count Number of elements in the array
  * @param[out] totalcount Number of elements in the resulting array
- * @result Array of merged sequences
  * @note The values in the array may overlap on a single instant.
  */
 static TSequence **
@@ -369,8 +368,8 @@ temporal_convert_same_subtype(const Temporal *temp1, const Temporal *temp2,
  * @ingroup meos_temporal_modif
  * @brief Merge two temporal values
  * @param[in] temp1,temp2 Temporal values
- * @result Return NULL if both arguments are NULL
- * If one argument is null the other argument is output.
+ * @return Return @p NULL if both arguments are @p NULL.
+ * If one argument is null, return the other argument.
  * @csqlfn #Temporal_merge()
  */
 Temporal *
@@ -424,10 +423,9 @@ temporal_merge(const Temporal *temp1, const Temporal *temp2)
  * @param[in] count Number of values in the array
  * @param[in] subtype common subtype
  * @param[in] interp Interpolation
- * @result  Array of output values
  */
 static Temporal **
-temporalarr_convert_subtype(Temporal **temparr, int count, uint8 subtype,
+temporalarr_convert_subtype(const Temporal **temparr, int count, uint8 subtype,
   interpType interp)
 {
   assert(temparr);
@@ -462,7 +460,7 @@ temporalarr_convert_subtype(Temporal **temparr, int count, uint8 subtype,
  * @csqlfn #Temporal_merge_array()
  */
 Temporal *
-temporal_merge_array(Temporal **temparr, int count)
+temporal_merge_array(const Temporal **temparr, int count)
 {
   /* Ensure validity of the arguments */
   if( ! ensure_not_null((void *) temparr) || ! ensure_positive(count))
@@ -502,7 +500,7 @@ temporal_merge_array(Temporal **temparr, int count)
   if (convert)
     newtemps = temporalarr_convert_subtype(temparr, count, subtype, interp);
   else
-    newtemps = temparr;
+    newtemps = (Temporal **) temparr;
 
   Temporal *result;
   assert(temptype_subtype(subtype));
@@ -1519,6 +1517,13 @@ temporal_delete_tstzspanset(const Temporal *temp, const SpanSet *ss,
  * @param[in] maxt Maximum time interval for defining a gap
  * @param[in] expand True when reserving space for additional instants
  * @csqlfn #Temporal_append_tinstant()
+ * @return When the sequence passed as first argument has space for adding the
+ * instant, the function returns the updated sequence. Otherwise, a NEW 
+ * sequence is returned and the input sequence is freed.
+ * @note Always use the function to overwrite the existing sequence as in: 
+ * @code
+ * seq = tsequence_append_tinstant(seq, inst, ...);
+ * @endcode
  */
 Temporal *
 tsequence_append_tinstant(TSequence *seq, const TInstant *inst, double maxdist,
@@ -1595,7 +1600,7 @@ tsequence_append_tinstant(TSequence *seq, const TInstant *inst, double maxdist,
       Interval *duration = minus_timestamptz_timestamptz(inst->t, last->t);
       if (pg_interval_cmp(duration, maxt) > 0)
         split = true;
-      // CANNOT pfree(duration);
+      pfree(duration);
     }
     /* If split => result is a sequence set */
     if (split)
@@ -1706,7 +1711,7 @@ tsequence_append_tinstant(TSequence *seq, const TInstant *inst, double maxdist,
  * @csqlfn #Temporal_append_tsequence()
  */
 Temporal *
-tsequence_append_tsequence(TSequence *seq1, const TSequence *seq2,
+tsequence_append_tsequence(const TSequence *seq1, const TSequence *seq2,
   bool expand __attribute__((unused)))
 {
   assert(seq1); assert(seq2);
@@ -1782,6 +1787,13 @@ tsequence_append_tsequence(TSequence *seq1, const TSequence *seq2,
  * @param[in] maxt Maximum time interval for defining a gap
  * @param[in] expand True when reserving space for additional instants
  * @csqlfn #Temporal_append_tinstant()
+ * @return When the sequence set passed as first argument has space for adding
+ * the instant, the  function returns the sequence set. Otherwise, a NEW
+ * sequence set is returned and the input sequence set is freed.
+ * @note Always use the function to overwrite the existing sequence set as in: 
+ * @code
+ * ss = tsequenceset_append_tinstant(ss, inst, ...);
+ * @endcode
  */
 TSequenceSet *
 tsequenceset_append_tinstant(TSequenceSet *ss, const TInstant *inst,
@@ -2021,10 +2033,17 @@ tsequenceset_append_tsequence(TSequenceSet *ss, const TSequence *seq,
  * @param[in] maxt Maximum time interval for defining a gap
  * @param[in] expand True when reserving space for additional instants
  * @csqlfn #Temporal_append_tinstant()
+ * @return When the temporal value passed as first argument has space for 
+ * adding the instant, the function returns the temporal value. Otherwise,
+ * a NEW temporal value is returned and the input value is freed.
+ * @note Always use the function to overwrite the existing temporal value as in: 
+ * @code
+ * temp = temporal_append_tinstant(temp, inst, ...);
+ * @endcode
  */
 Temporal *
 temporal_append_tinstant(Temporal *temp, const TInstant *inst, double maxdist,
-  Interval *maxt, bool expand)
+  const Interval *maxt, bool expand)
 {
   /* Validity tests */
   if (! ensure_not_null((void *) temp) || ! ensure_not_null((void *) inst) ||
@@ -2089,14 +2108,14 @@ temporal_append_tsequence(Temporal *temp, const TSequence *seq, bool expand)
   {
     case TINSTANT:
     {
-      TSequence *seq1 = tinstant_to_tsequence((TInstant *) temp, interp2);
+      TSequence *seq1 = tinstant_to_tsequence((const TInstant *) temp, interp2);
       Temporal *result = (Temporal *) tsequence_append_tsequence(
-        (TSequence *) seq1, (TSequence *) seq, expand);
+        (const TSequence *) seq1, seq, expand);
       pfree(seq1);
       return result;
     }
     case TSEQUENCE:
-      return (Temporal *) tsequence_append_tsequence((TSequence *) temp, seq,
+      return (Temporal *) tsequence_append_tsequence((const TSequence *) temp, seq,
         expand);
     default: /* TSEQUENCESET */
       return (Temporal *) tsequenceset_append_tsequence((TSequenceSet *) temp,
