@@ -39,11 +39,7 @@
 /* PostgreSQL */
 #include <postgres.h>
 #include <utils/timestamp.h>
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <common/hashfn.h>
-#else
-  #include <access/hash.h>
-#endif
+#include <common/hashfn.h>
 #if POSTGRESQL_VERSION_NUMBER >= 160000
   #include "varatt.h"
 #endif
@@ -246,8 +242,9 @@ tinstant_to_string(const TInstant *inst, int maxdd, outfunc value_out)
   char *t = pg_timestamptz_out(inst->t);
   meosType basetype = temptype_basetype(inst->temptype);
   char *value = value_out(tinstant_val(inst), basetype, maxdd);
-  char *result = palloc(strlen(value) + strlen(t) + 2);
-  sprintf(result, "%s@%s", value, t);
+  size_t size = strlen(value) + strlen(t) + 2;
+  char *result = palloc(size);
+  snprintf(result, size, "%s@%s", value, t);
   pfree(t); pfree(value);
   return result;
 }
