@@ -150,14 +150,13 @@ tnumber_div_tp_at_timestamptz(const TInstant *start1, const TInstant *end1,
  * @brief Generic arithmetic operator on a temporal number and a number
  * @param[in] temp Temporal number
  * @param[in] value Number
- * @param[in] basetype Type of the value
  * @param[in] oper Enumeration that states the arithmetic operator
  * @param[in] func Arithmetic function
  * @param[in] invert True if the base value is the first argument of the
  * function
  */
 Temporal *
-arithop_tnumber_number(const Temporal *temp, Datum value, TArithmetic oper, 
+arithop_tnumber_number(const Temporal *temp, Datum value, TArithmetic oper,
   Datum (*func)(Datum, Datum, meosType), bool invert)
 {
   assert(tnumber_type(temp->temptype));
@@ -367,11 +366,12 @@ TSequenceSet *
 tnumberseqset_abs(const TSequenceSet *ss)
 {
   assert(ss); assert(tnumber_type(ss->temptype));
+  bool linear = MEOS_FLAGS_LINEAR_INTERP(ss->flags);
   TSequence **sequences = palloc(sizeof(TSequence *) * ss->count);
   for (int i = 0; i < ss->count; i++)
   {
     const TSequence *seq = TSEQUENCESET_SEQ_N(ss, i);
-    sequences[i] = MEOS_FLAGS_LINEAR_INTERP(ss->flags) ?
+    sequences[i] = linear ?
       tnumberseq_linear_abs(seq) : tnumberseq_iter_abs(seq);
   }
   return tsequenceset_make_free(sequences, ss->count, NORMALIZE);
