@@ -84,7 +84,7 @@
  * @param[in] ss Temporal sequence set
  * @param[in] t Timestamp
  * @param[out] loc Location
- * @result Return true if the timestamp is contained in the temporal sequence
+ * @return Return true if the timestamp is contained in the temporal sequence
  * set.
  */
 bool
@@ -121,7 +121,7 @@ tsequenceset_find_timestamptz(const TSequenceSet *ss, TimestampTz t, int *loc)
  * @param[in] sequences Array of temporal sequences
  * @param[in] count Number of elements in the input array
  * @param[out] newcount Number of elements in the output array
- * @result Array of normalized temporal sequences values
+ * @return Array of normalized temporal sequences values
  * @pre Each sequence in the input array is normalized.
  * When merging sequences, the test whether the value is the same
  * at the common instant should be ensured by the calling function.
@@ -447,11 +447,11 @@ tsequenceset_make_free(TSequence **sequences, int count, bool normalize)
  * @param[in] maxdist Maximum distance to split the temporal sequence
  * @param[in] maxt Maximum time interval to split the temporal sequence
  * @param[out] nsplits Number of splits
- * @result Array of indices at which the temporal sequence is split
+ * @return Array of indices at which the temporal sequence is split
  */
 static int *
 ensure_valid_tinstarr_gaps(const TInstant **instants, int count, bool merge,
-  double maxdist, Interval *maxt, int *nsplits)
+  double maxdist, const Interval *maxt, int *nsplits)
 {
   meosType basetype = temptype_basetype(instants[0]->temptype);
   /* Ensure that zero-fill is done */
@@ -486,7 +486,7 @@ ensure_valid_tinstarr_gaps(const TInstant **instants, int count, bool merge,
         instants[i - 1]->t);
       if (pg_interval_cmp(duration, maxt) > 0)
         split = true;
-      // CANNOT pfree(duration);
+      pfree(duration);
     }
     if (split)
       result[k++] = i;
@@ -504,7 +504,7 @@ ensure_valid_tinstarr_gaps(const TInstant **instants, int count, bool merge,
 static int *
 tsequenceset_make_gaps_valid(const TInstant **instants, int count,
   bool lower_inc, bool upper_inc, interpType interp, double maxdist,
-  Interval *maxt, int *nsplits)
+  const Interval *maxt, int *nsplits)
 {
   assert(interp != DISCRETE);
   if (! ensure_valid_tinstarr_common(instants, count, lower_inc, upper_inc,
@@ -528,7 +528,7 @@ tsequenceset_make_gaps_valid(const TInstant **instants, int count,
  */
 TSequenceSet *
 tsequenceset_make_gaps(const TInstant **instants, int count, interpType interp,
-  Interval *maxt, double maxdist)
+  const Interval *maxt, double maxdist)
 {
   /* Ensure validity of the arguments */
   if (! ensure_not_null((void *) instants) || ! ensure_positive(count))
@@ -542,6 +542,8 @@ tsequenceset_make_gaps(const TInstant **instants, int count, interpType interp,
   {
     seq = tsequence_make_exp((const TInstant **) instants, count, count, true,
       true, interp, NORMALIZE);
+    if (! seq)
+      return NULL;
     result = tsequenceset_make_exp((const TSequence **) &seq, 1, 1,
       NORMALIZE_NO);
     pfree(seq);
@@ -768,7 +770,7 @@ tpointseqset_from_base_tstzspanset(const GSERIALIZED *gs, const SpanSet *ss,
  * sequence set
  * @param[in] ss Temporal sequence set
  * @param[out] count Number of elements in the output array
- * @result Array of Datums
+ * @return Array of Datums
  * @csqlfn #Temporal_valueset()
  */
 Datum *
@@ -816,7 +818,7 @@ tnumberseqset_valuespans(const TSequenceSet *ss)
       TBox *box = TSEQUENCE_BBOX_PTR(TSEQUENCESET_SEQ_N(ss, i));
       memcpy(&spans[i], &box->span, sizeof(Span));
     }
-    return spanset_make_free(spans, ss->count, NORMALIZE, ORDERED_NO);
+    return spanset_make_free(spans, ss->count, NORMALIZE, ORDER);
   }
 
   /* Temporal sequence number with discrete or step interpolation */
@@ -826,7 +828,7 @@ tnumberseqset_valuespans(const TSequenceSet *ss)
   spans = palloc(sizeof(Span) * count);
   for (i = 0; i < count; i++)
     span_set(values[i], values[i], true, true, basetype, spantype, &spans[i]);
-  SpanSet *result = spanset_make_free(spans, count, NORMALIZE, ORDERED_NO);
+  SpanSet *result = spanset_make_free(spans, count, NORMALIZE, ORDER);
   pfree(values);
   return result;
 }
@@ -956,6 +958,57 @@ tsequenceset_max_val(const TSequenceSet *ss)
   return result;
 }
 
+/**
+ * @ingroup meos_internal_temporal_accessor
+ * @brief Return in the last argument a copy of the n-th value of a temporal
+ * sequence set
+ * @param[in] ss Temporal sequence set
+ * @param[in] n Number
+ * @param[out] result Value
+ * @csqlfn #Temporal_value_n()
+ */
+bool
+tsequenceset_value_n(const TSequenceSet *ss, int n, Datum *result)
+{
+  assert(ss);
+  assert(n >= 1 && n <= ss->totalcount);
+  if (n == 1)
+  {
+    *result = tinstant_value(TSEQUENCE_INST_N(TSEQUENCESET_SEQ_N(ss, 0), 0));
+    return true;
+  }
+
+  /* Continue the search 0-based */
+  n--;
+  const TInstant *prev = NULL, *next = NULL; /* make compiler quiet */
+  bool first = true, found = false;
+  int i = 0, count = 0, prevcount = 0;
+  while (i < ss->count)
+  {
+    const TSequence *seq = TSEQUENCESET_SEQ_N(ss, i);
+    count += seq->count;
+    if (! first && tinstant_eq(prev, TSEQUENCE_INST_N(seq, 0)))
+    {
+        prevcount --;
+        count --;
+    }
+    if (prevcount <= n && n < count)
+    {
+      next = TSEQUENCE_INST_N(seq, n - prevcount);
+      found = true;
+      break;
+    }
+    prevcount = count;
+    prev = TSEQUENCE_INST_N(seq, seq->count - 1);
+    first = false;
+    i++;
+  }
+  if (! found)
+    return false;
+  *result = tinstant_value(next);
+  return true;
+}
+
 /**
  * @ingroup meos_internal_temporal_accessor
  * @brief Return the time frame a temporal sequence set as a timestamptz span
@@ -970,7 +1023,7 @@ tsequenceset_time(const TSequenceSet *ss)
   Span *periods = palloc(sizeof(Span) * ss->count);
   for (int i = 0; i < ss->count; i++)
     periods[i] = (TSEQUENCESET_SEQ_N(ss, i))->period;
-  return spanset_make_free(periods, ss->count, NORMALIZE_NO, ORDERED);
+  return spanset_make_free(periods, ss->count, NORMALIZE_NO, ORDER_NO);
 }
 
 /**
@@ -1296,7 +1349,7 @@ tsequenceset_timestamps(const TSequenceSet *ss, int *count)
  * @param[in] t Timestamp
  * @param[in] strict True if exclusive bounds are taken into account
  * @param[out] result Base value
- * @result Return true if the timestamp is contained in the temporal sequence set
+ * @return Return true if the timestamp is contained in the temporal sequence set
  * @pre A bounding box test has been done before by the calling function
  * @csqlfn #Temporal_value_at_timestamptz()
  */
@@ -1789,7 +1842,7 @@ tsequenceset_shift_scale_time(const TSequenceSet *ss, const Interval *shift,
  * @param[in] ss,seq Input values
  * @param[in] mode Enumeration for either intersect or synchronize
  * @param[out] inter1, inter2 Output values
- * @result Return false if the input values do not overlap on time
+ * @return Return false if the input values do not overlap on time
  */
 bool
 synchronize_tsequenceset_tsequence(const TSequenceSet *ss, const TSequence *seq,
@@ -1837,7 +1890,7 @@ synchronize_tsequenceset_tsequence(const TSequenceSet *ss, const TSequence *seq,
  * @param[in] ss1,ss2 Input values
  * @param[in] mode Intersection or synchronization (with or without adding crossings)
  * @param[out] inter1, inter2 Output values
- * @result Return false if the input values do not overlap on time
+ * @return Return false if the input values do not overlap on time
  */
 bool
 synchronize_tsequenceset_tsequenceset(const TSequenceSet *ss1,
@@ -1894,7 +1947,7 @@ synchronize_tsequenceset_tsequenceset(const TSequenceSet *ss1,
  * @brief Temporally intersect two temporal values
  * @param[in] ss,inst Input values
  * @param[out] inter1, inter2 Output values
- * @result Return false if the input values do not overlap on time
+ * @return Return false if the input values do not overlap on time
  */
 bool
 intersection_tsequenceset_tinstant(const TSequenceSet *ss, const TInstant *inst,
@@ -1917,7 +1970,7 @@ intersection_tsequenceset_tinstant(const TSequenceSet *ss, const TInstant *inst,
  * @brief Temporally intersect two temporal values
  * @param[in] inst,ss Input values
  * @param[out] inter1, inter2 Output values
- * @result Return false if the input values do not overlap on time
+ * @return Return false if the input values do not overlap on time
  */
 bool
 intersection_tinstant_tsequenceset(const TInstant *inst, const TSequenceSet *ss,
@@ -1930,7 +1983,7 @@ intersection_tinstant_tsequenceset(const TInstant *inst, const TSequenceSet *ss,
  * @brief Temporally intersect two temporal values
  * @param[in] ss,seq Input values
  * @param[out] inter1, inter2 Output values
- * @result Return false if the input values do not overlap on time
+ * @return Return false if the input values do not overlap on time
  */
 bool
 intersection_tsequenceset_tdiscseq(const TSequenceSet *ss,
@@ -1984,7 +2037,7 @@ intersection_tsequenceset_tdiscseq(const TSequenceSet *ss,
  * @brief Temporally intersect two temporal values
  * @param[in] seq,ss Input values
  * @param[out] inter1,inter2 Output values
- * @result Return false if the input values do not overlap on time
+ * @return Return false if the input values do not overlap on time
  */
 bool
 intersection_tdiscseq_tsequenceset(const TSequence *seq,
@@ -1998,7 +2051,7 @@ intersection_tdiscseq_tsequenceset(const TSequence *seq,
  * @param[in] seq,ss Input values
  * @param[in] mode Enumeration for either intersect or synchronize
  * @param[out] inter1, inter2 Output values
- * @result Return false if the input values do not overlap on times
+ * @return Return false if the input values do not overlap on times
  */
 bool
 intersection_tsequence_tsequenceset(const TSequence *seq, const TSequenceSet *ss,
@@ -2130,10 +2183,10 @@ tsequenceset_to_string(const TSequenceSet *ss, int maxdd, outfunc value_out)
 
   char **strings = palloc(sizeof(char *) * ss->count);
   size_t outlen = 0;
-  char prefix[20];
+  char prefix[13];
   if (MEOS_FLAGS_GET_CONTINUOUS(ss->flags) &&
       ! MEOS_FLAGS_LINEAR_INTERP(ss->flags))
-    sprintf(prefix, "Interp=Step;");
+    snprintf(prefix, sizeof(prefix), "Interp=Step;");
   else
     prefix[0] = '\0';
   for (int i = 0; i < ss->count; i++)
@@ -2215,7 +2268,7 @@ tnumberseqset_twavg(const TSequenceSet *ss)
   {
     result = 0;
     for (int i = 0; i < ss->count; i++)
-      result += tnumbercontseq_twavg(TSEQUENCESET_SEQ_N(ss, i));
+      result += tnumberseq_cont_twavg(TSEQUENCESET_SEQ_N(ss, i));
     return result / ss->count;
   }
   else
