@@ -119,7 +119,7 @@ findMemberByName(json_object *poObj, const char *pszName)
 
 /**
  * @brief Return a single point from its MF-JSON coordinates
- * @details In this case the coordinate array is a single array of cordinations 
+ * @details In this case the coordinate array is a single array of cordinations
  * such as `"coordinates":[1,1]`.
  */
 static Datum
@@ -242,7 +242,8 @@ parse_mfjson_values(json_object *mfjson, meosType temptype, int *count)
         break;
       default: /* Error! */
         meos_error(ERROR, MEOS_ERR_MFJSON_INPUT,
-          "Unknown temporal type in MFJSON string: %d", temptype);
+          "Unknown temporal type in MFJSON string: %s",
+          meostype_name(temptype));
         return NULL;
     }
   }
@@ -801,7 +802,7 @@ temporal_from_mfjson(const char *mfjson, meosType temptype)
   if (jstok->err != json_tokener_success)
   {
     char err[256];
-    snprintf(err, 256, "%s (at offset %d)",
+    snprintf(err, sizeof(err), "%s (at offset %d)",
       json_tokener_error_desc(jstok->err), jstok->char_offset);
     json_tokener_free(jstok);
     json_object_put(poObj);
@@ -1035,16 +1036,16 @@ wkb_parse_state_check(wkb_parse_state *s, size_t next)
 /**
  * @brief Read a byte and advance the parse state forward
  */
-char
+uint8_t
 byte_from_wkb_state(wkb_parse_state *s)
 {
-  char char_value = 0;
+  uint8_t byte_value = 0;
   /* Does the data we want to read exist? */
   wkb_parse_state_check(s, MEOS_WKB_BYTE_SIZE);
   /* Get the data */
-  char_value = s->pos[0];
+  byte_value = s->pos[0];
   s->pos += MEOS_WKB_BYTE_SIZE;
-  return char_value;
+  return byte_value;
 }
 
 /**
@@ -1291,7 +1292,8 @@ basevalue_from_wkb_state(wkb_parse_state *s)
 #endif /* NPOINT */
     default: /* Error! */
       meos_error(ERROR, MEOS_ERR_WKB_INPUT,
-        "Unknown base type in WKB string: %d", s->basetype);
+        "Unknown base type in WKB string: %s",
+        meostype_name(s->basetype));
       return 0;
   }
 }
@@ -1396,7 +1398,7 @@ spanset_from_wkb_state(wkb_parse_state *s)
   /* Read and create the span set */
   for (int i = 0; i < count; i++)
     span_from_wkb_state_iter(s, &spans[i]);
-  return spanset_make_free(spans, count, NORMALIZE, ORDERED);
+  return spanset_make_free(spans, count, NORMALIZE, ORDER_NO);
 }
 
 /*****************************************************************************/
@@ -1450,7 +1452,7 @@ set_from_wkb_state(wkb_parse_state *s)
   /* Read and create the set */
   for (int i = 0; i < count; i++)
     values[i] = basevalue_from_wkb_state(s);
-  return set_make_free(values, count, s->basetype, ORDERED);
+  return set_make_free(values, count, s->basetype, ORDER_NO);
 }
 
 /*****************************************************************************/
@@ -1607,7 +1609,7 @@ temporal_flags_from_wkb_state(wkb_parse_state *s, uint8_t wkb_flags)
 
 /**
  * @brief Return a temporal instant from its WKB representation
- * @details The function reads the base type value and the timestamp and 
+ * @details The function reads the base type value and the timestamp and
  * advances the parse state forward appropriately. It starts reading it just
  * after the endian byte, the temporal type (an @p int16), and the temporal
  * flags byte.
@@ -1739,7 +1741,7 @@ datum_from_wkb(const uint8_t *wkb, size_t size, meosType type)
   s.wkb = s.pos = wkb;
   s.wkb_size = size;
   /* Fail when handed incorrect starting byte */
-  char wkb_little_endian = byte_from_wkb_state(&s);
+  uint8_t wkb_little_endian = byte_from_wkb_state(&s);
   if (wkb_little_endian != 1 && wkb_little_endian != 0)
   {
     meos_error(ERROR, MEOS_ERR_WKB_INPUT,
@@ -1775,7 +1777,7 @@ datum_from_wkb(const uint8_t *wkb, size_t size, meosType type)
     return PointerGetDatum(temporal_from_wkb_state(&s));
   /* Error! */
   meos_error(ERROR, MEOS_ERR_WKB_INPUT,
-    "Unknown type in WKB string: %d", type);
+    "Unknown type in WKB string: %s", meostype_name(type));
   return 0;
 }
 
