@@ -311,127 +311,20 @@ box3d_to_lwgeom(BOX3D *box)
  * Functions adapted from lwgeom_functions_basic.c
  *****************************************************************************/
 
-/* The boundary function has changed its implementation in version 3.2.
- * This is the version in 3.2.3 */
-LWGEOM *
-lwgeom_boundary(LWGEOM *lwgeom)
+/**
+ * @brief find the "perimeter of a geometry"
+ *   perimeter(point) = 0
+ *   perimeter(line) = 0
+ *   perimeter(polygon) = sum of ring perimeters
+ *   uses euclidian 2d computation even if input is 3d
+ * @note PostGIS function: @p LWGEOM_perimeter2d_poly(PG_FUNCTION_ARGS)
+ */
+double
+geo_perimeter(const GSERIALIZED *geom)
 {
-  int32_t srid = lwgeom_get_srid(lwgeom);
-  uint8_t hasz = lwgeom_has_z(lwgeom);
-  uint8_t hasm = lwgeom_has_m(lwgeom);
-
-  switch (lwgeom->type)
-  {
-  case POINTTYPE:
-  case MULTIPOINTTYPE: {
-    return lwgeom_construct_empty(lwgeom->type, srid, hasz, hasm);
-  }
-  case LINETYPE:
-  case CIRCSTRINGTYPE: {
-    if (lwgeom_is_closed(lwgeom) || lwgeom_is_empty(lwgeom))
-      return (LWGEOM *)lwmpoint_construct_empty(srid, hasz, hasm);
-    else
-    {
-      LWLINE *lwline = (LWLINE *)lwgeom;
-      LWMPOINT *lwmpoint = lwmpoint_construct_empty(srid, hasz, hasm);
-      POINT4D pt;
-      getPoint4d_p(lwline->points, 0, &pt);
-      lwmpoint_add_lwpoint(lwmpoint, lwpoint_make(srid, hasz, hasm, &pt));
-      getPoint4d_p(lwline->points, lwline->points->npoints - 1, &pt);
-      lwmpoint_add_lwpoint(lwmpoint, lwpoint_make(srid, hasz, hasm, &pt));
-
-      return (LWGEOM *)lwmpoint;
-    }
-  }
-  case MULTILINETYPE:
-  case MULTICURVETYPE: {
-    LWMLINE *lwmline = (LWMLINE *)lwgeom;
-    POINT4D *out = lwalloc(sizeof(POINT4D) * lwmline->ngeoms * 2);
-    uint32_t n = 0;
-
-    for (uint32_t i = 0; i < lwmline->ngeoms; i++)
-    {
-      LWMPOINT *points = lwgeom_as_lwmpoint(lwgeom_boundary((LWGEOM *)lwmline->geoms[i]));
-      if (!points)
-        continue;
-
-      for (uint32_t k = 0; k < points->ngeoms; k++)
-      {
-        POINT4D pt = getPoint4d(points->geoms[k]->point, 0);
-
-        uint8_t seen = LW_FALSE;
-        for (uint32_t j = 0; j < n; j++)
-        {
-          if (memcmp(&(out[j]), &pt, sizeof(POINT4D)) == 0)
-          {
-            seen = LW_TRUE;
-            out[j] = out[--n];
-            break;
-          }
-        }
-        if (!seen)
-          out[n++] = pt;
-      }
-
-      lwgeom_free((LWGEOM *)points);
-    }
-
-    LWMPOINT *lwmpoint = lwmpoint_construct_empty(srid, hasz, hasm);
-
-    for (uint32_t i = 0; i < n; i++)
-      lwmpoint_add_lwpoint(lwmpoint, lwpoint_make(srid, hasz, hasm, &(out[i])));
-
-    lwfree(out);
-
-    return (LWGEOM *)lwmpoint;
-  }
-  case TRIANGLETYPE: {
-    LWTRIANGLE *lwtriangle = (LWTRIANGLE *)lwgeom;
-    POINTARRAY *points = ptarray_clone_deep(lwtriangle->points);
-    return (LWGEOM *)lwline_construct(srid, 0, points);
-  }
-  case POLYGONTYPE: {
-    LWPOLY *lwpoly = (LWPOLY *)lwgeom;
-
-    LWMLINE *lwmline = lwmline_construct_empty(srid, hasz, hasm);
-    for (uint32_t i = 0; i < lwpoly->nrings; i++)
-    {
-      POINTARRAY *ring = ptarray_clone_deep(lwpoly->rings[i]);
-      lwmline_add_lwline(lwmline, lwline_construct(srid, 0, ring));
-    }
-
-    /* Homogenize the multilinestring to hopefully get a single LINESTRING */
-    LWGEOM *lwout = lwgeom_homogenize((LWGEOM *)lwmline);
-    lwgeom_free((LWGEOM *)lwmline);
-    return lwout;
-  }
-  case CURVEPOLYTYPE: {
-    LWCURVEPOLY *lwcurvepoly = (LWCURVEPOLY *)lwgeom;
-    LWCOLLECTION *lwcol = lwcollection_construct_empty(MULTICURVETYPE, srid, hasz, hasm);
-
-    for (uint32_t i = 0; i < lwcurvepoly->nrings; i++)
-      lwcol = lwcollection_add_lwgeom(lwcol, lwgeom_clone_deep(lwcurvepoly->rings[i]));
-
-    return (LWGEOM *)lwcol;
-  }
-  case MULTIPOLYGONTYPE:
-  case COLLECTIONTYPE:
-  case TINTYPE: {
-    LWCOLLECTION *lwcol = (LWCOLLECTION *)lwgeom;
-    LWCOLLECTION *lwcol_boundary = lwcollection_construct_empty(COLLECTIONTYPE, srid, hasz, hasm);
-
-    for (uint32_t i = 0; i < lwcol->ngeoms; i++)
-      lwcollection_add_lwgeom(lwcol_boundary, lwgeom_boundary(lwcol->geoms[i]));
-
-    LWGEOM *lwout = lwgeom_homogenize((LWGEOM *)lwcol_boundary);
-    lwgeom_free((LWGEOM *)lwcol_boundary);
-
-    return lwout;
-  }
-  default:
-    lwerror("%s: unsupported geometry type: %s", __func__, lwtype_name(lwgeom->type));
-    return NULL;
-  }
+  LWGEOM *lwgeom = lwgeom_from_gserialized(geom);
+  double perimeter = lwgeom_perimeter_2d(lwgeom);
+  return perimeter;
 }
 
 /**
@@ -1124,33 +1017,6 @@ geometry_convex_hull(const GSERIALIZED *gs)
   return result;
 }
 
-/**
- * @brief Return true if the coordinates of the geometry are finite
- */
-int
-lwgeom_isfinite(const LWGEOM *lwgeom)
-{
-  LWPOINTITERATOR* it = lwpointiterator_create(lwgeom);
-  int hasz = lwgeom_has_z(lwgeom);
-  int hasm = lwgeom_has_m(lwgeom);
-
-  while (lwpointiterator_has_next(it))
-  {
-    POINT4D p;
-    lwpointiterator_next(it, &p);
-    int finite = isfinite(p.x) && isfinite(p.y) &&
-      (hasz ? isfinite(p.z) : 1) && (hasm ? isfinite(p.m) : 1);
-
-    if (!finite)
-    {
-      lwpointiterator_destroy(it);
-      return LW_FALSE;
-    }
-  }
-  lwpointiterator_destroy(it);
-  return LW_TRUE;
-}
-
 /**
  * @brief Return a @p POLYGON or a @p MULTIPOLYGON that represents all points
  * whose distance from a geometry/geography is less than or equal to a given
@@ -1356,13 +1222,137 @@ geometry_buffer(const GSERIALIZED *gs, double size, char *params)
  * Functions adapted from geography_measurement.c
  *****************************************************************************/
 
+/**
+ * @brief Returns double area in meters square
+ * @return On error return @p DBL_MAX
+ * @note PostGIS function: @p geography_area(PG_FUNCTION_ARGS)
+ */
+double
+pgis_geography_area(const GSERIALIZED *g, bool use_spheroid)
+{
+  LWGEOM *lwgeom = NULL;
+  GBOX gbox;
+  double area;
+  SPHEROID s;
+
+  /* Initialize spheroid */
+  /* We currently cannot use the next statement since it uses PostGIS cache */
+  // spheroid_init_from_srid(gserialized_get_srid(g), &s);
+  spheroid_init(&s, WGS84_MAJOR_AXIS, WGS84_MINOR_AXIS);
+
+  lwgeom = lwgeom_from_gserialized(g);
+
+  /* EMPTY things have no area */
+  if ( lwgeom_is_empty(lwgeom) )
+  {
+    lwgeom_free(lwgeom);
+    return 0.0;
+  }
+
+  if ( lwgeom->bbox )
+    gbox = *(lwgeom->bbox);
+  else
+    lwgeom_calculate_gbox_geodetic(lwgeom, &gbox);
+
+#ifndef PROJ_GEODESIC
+  /* Test for cases that are currently not handled by spheroid code */
+  if ( use_spheroid )
+  {
+    /* We can't circle the poles right now */
+    if ( FP_GTEQ(gbox.zmax,1.0) || FP_LTEQ(gbox.zmin,-1.0) )
+      use_spheroid = LW_FALSE;
+    /* We can't cross the equator right now */
+    if ( gbox.zmax > 0.0 && gbox.zmin < 0.0 )
+      use_spheroid = LW_FALSE;
+  }
+#endif /* ifndef PROJ_GEODESIC */
+
+  /* User requests spherical calculation, turn our spheroid into a sphere */
+  if ( ! use_spheroid )
+    s.a = s.b = s.radius;
+
+  /* Calculate the area */
+  if ( use_spheroid )
+    area = lwgeom_area_spheroid(lwgeom, &s);
+  else
+    area = lwgeom_area_sphere(lwgeom, &s);
+
+  /* Clean up */
+  lwgeom_free(lwgeom);
+
+  /* Something went wrong... */
+  if ( area < 0.0 )
+  {
+    meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
+      "lwgeom_area_spheroid returned length < 0.0");
+    return DBL_MAX;
+  }
+
+  return area;
+}
+
+/**
+ * @brief Returns double perimeter in meters for area features
+ * @return On error return @p DBL_MAX
+ * @note PostGIS function: @p geography_perimeter(PG_FUNCTION_ARGS)
+ */
+double
+pgis_geography_perimeter(const GSERIALIZED *g, bool use_spheroid)
+{
+  LWGEOM *lwgeom = NULL;
+  double length;
+  SPHEROID s;
+  int type;
+
+  /* Only return for area features. */
+  type = gserialized_get_type(g);
+  if ( ! (type == POLYGONTYPE || type == MULTIPOLYGONTYPE || type == COLLECTIONTYPE) )
+  {
+    return 0.0;
+  }
+
+  lwgeom = lwgeom_from_gserialized(g);
+
+  /* EMPTY things have no perimeter */
+  if ( lwgeom_is_empty(lwgeom) )
+  {
+    lwgeom_free(lwgeom);
+    return 0.0;
+  }
+
+  /* Initialize spheroid */
+  /* We currently cannot use the next statement since it uses PostGIS cache */
+  // spheroid_init_from_srid(gserialized_get_srid(g), &s);
+  spheroid_init(&s, WGS84_MAJOR_AXIS, WGS84_MINOR_AXIS);
+
+  /* User requests spherical calculation, turn our spheroid into a sphere */
+  if ( ! use_spheroid )
+    s.a = s.b = s.radius;
+
+  /* Calculate the length */
+  length = lwgeom_length_spheroid(lwgeom, &s);
+
+  /* Something went wrong... */
+  if ( length < 0.0 )
+  {
+    meos_error(ERROR, MEOS_ERR_INTERNAL_TYPE_ERROR,
+      "lwgeom_perimeter_spheroid returned length < 0.0");
+    return DBL_MAX;
+  }
+
+  /* Clean up, but not all the way to the point arrays */
+  lwgeom_free(lwgeom);
+
+  return length;
+}
+
 /**
  * @brief Return double length in meters
  * @return On error return @p DBL_MAX
  * @note PostGIS function: @p geography_length(PG_FUNCTION_ARGS)
  */
 double
-pgis_geography_length(GSERIALIZED *gs, bool use_spheroid)
+pgis_geography_length(const GSERIALIZED *gs, bool use_spheroid)
 {
   /* EMPTY things have no length */
   int32 geo_type = gserialized_get_type(gs);
@@ -1407,7 +1397,7 @@ pgis_geography_length(GSERIALIZED *gs, bool use_spheroid)
  * where we use the WGS84 spheroid
  */
 bool
-pgis_geography_dwithin(GSERIALIZED *gs1, GSERIALIZED *gs2, double tolerance,
+pgis_geography_dwithin(const GSERIALIZED *gs1, GSERIALIZED *gs2, double tolerance,
   bool use_spheroid)
 {
   assert(gserialized_get_srid(gs1) == gserialized_get_srid(gs2));
@@ -1841,7 +1831,9 @@ geo_as_text(const GSERIALIZED *gs, int precision)
     return NULL;
 
   LWGEOM *geom = lwgeom_from_gserialized(gs);
-  return lwgeom_to_wkt(geom, WKT_ISO, precision, NULL);
+  char *result = lwgeom_to_wkt(geom, WKT_ISO, precision, NULL);
+  lwgeom_free(geom);
+  return result;
 }
 
 /**
@@ -1862,7 +1854,9 @@ geo_as_ewkt(const GSERIALIZED *gs, int precision)
     return NULL;
 
   LWGEOM *geom = lwgeom_from_gserialized(gs);
-  return lwgeom_to_wkt(geom, WKT_EXTENDED, precision, NULL);
+  char *result = lwgeom_to_wkt(geom, WKT_EXTENDED, precision, NULL);
+  lwgeom_free(geom);
+  return result;
 }
 
 /**
@@ -1921,9 +1915,8 @@ geo_as_hexewkb(const GSERIALIZED *gs, const char *endian)
   }
   /* Create WKB hex string */
   LWGEOM *geom = lwgeom_from_gserialized(gs);
-  lwvarlena_t *hexwkb = lwgeom_to_hexwkb_varlena(geom, variant | WKB_EXTENDED);
-  char *result = strdup(VARDATA(hexwkb));
-  pfree(hexwkb);
+  char *result = lwgeom_to_hexwkb_buffer(geom, variant | WKB_EXTENDED);
+  lwgeom_free(geom);
   return result;
 }
 
@@ -1932,20 +1925,20 @@ geo_as_hexewkb(const GSERIALIZED *gs, const char *endian)
  * @brief Return a geometry/geography from its EWKB representation
  * @details This function parses EWKB (extended form) which also contains SRID
  * info.
- * @param[in] bytea_wkb WKB string
+ * @param[in] wkb WKB bytes
+ * @param[in] wkb_size Number of WKB bytes
  * @param[in] srid SRID
  * @note PostGIS function: @p LWGEOMFromEWKB(wkb, [SRID])
  * @note wkb is in *binary* not hex form
  */
 GSERIALIZED *
-geo_from_ewkb(const bytea *bytea_wkb, int32 srid)
+geo_from_ewkb(const uint8_t *wkb, size_t wkb_size, int32 srid)
 {
   /* Ensure validity of the arguments */
-  if (! ensure_not_null((void *) bytea_wkb))
+  if (! ensure_not_null((void *) wkb))
     return NULL;
 
-  uint8_t *wkb = (uint8_t *) VARDATA(bytea_wkb);
-  LWGEOM *geom = lwgeom_from_wkb(wkb, VARSIZE_ANY_EXHDR(bytea_wkb),
+  LWGEOM *geom = lwgeom_from_wkb(wkb, wkb_size,
     LW_PARSER_CHECK_ALL);
   if (!geom)
   {
@@ -1970,10 +1963,11 @@ geo_from_ewkb(const bytea *bytea_wkb, int32 srid)
  * geometry/geography
  * @param[in] gs Geometry/geography
  * @param[in] endian Endianness
+ * @param[in] size Size of result
  * @note PostGIS function: @p WKBFromLWGEOM(PG_FUNCTION_ARGS)
  */
-bytea *
-geo_as_ewkb(const GSERIALIZED *gs, char *endian)
+uint8_t *
+geo_as_ewkb(const GSERIALIZED *gs, const char *endian, size_t *size)
 {
   /* Ensure validity of the arguments */
   if (! ensure_not_null((void *) gs))
@@ -1993,9 +1987,12 @@ geo_as_ewkb(const GSERIALIZED *gs, char *endian)
   /* Create WKB hex string */
   LWGEOM *geom = lwgeom_from_gserialized(gs);
   lwvarlena_t *wkb = lwgeom_to_wkb_varlena(geom, variant | WKB_EXTENDED);
-  bytea *result = palloc(wkb->size - LWVARHDRSZ);
-  memcpy(result, wkb->data, wkb->size - LWVARHDRSZ);
+
+  size_t data_size = wkb->size - LWVARHDRSZ;
+  uint8_t *result = palloc(data_size);
+  memcpy(result, wkb->data, data_size);
   pfree(geom); pfree(wkb);
+  *size = data_size;
   return result;
 }
 
@@ -2046,7 +2043,7 @@ geo_from_geojson(const char *geojson)
  * @note PostGIS function: @p LWGEOM_asGeoJson(PG_FUNCTION_ARGS)
  */
 char *
-geo_as_geojson(const GSERIALIZED *gs, int option, int precision, char *srs)
+geo_as_geojson(const GSERIALIZED *gs, int option, int precision, const char *srs)
 {
   /* Ensure validity of the arguments */
   if (! ensure_not_null((void *) gs))
@@ -2111,7 +2108,7 @@ geo_same(const GSERIALIZED *gs1, const GSERIALIZED *gs2)
   LWGEOM *geom1 = lwgeom_from_gserialized(gs1);
   LWGEOM *geom2 = lwgeom_from_gserialized(gs2);
   char result = lwgeom_same(geom1, geom2);
-  pfree(geom1); pfree(geom2);
+  lwgeom_free(geom1); lwgeom_free(geom2);
   return (result == LW_TRUE);
 }
 
@@ -2266,70 +2263,6 @@ pgis_geography_from_binary(const char *wkb_bytea)
 }
 #endif /* MEOS */
 
-/*****************************************************************************/
-
-#if 0 /* not used  */
-/**
- * @brief Get a geography from a geometry
- * @note PostGIS function: @p geography_from_geometry(PG_FUNCTION_ARGS)
- */
-GSERIALIZED *
-gserialized_geog_from_geom(GSERIALIZED *geom)
-{
-  LWGEOM *lwgeom = lwgeom_from_gserialized(geom);
-  geography_valid_type(lwgeom_get_type(lwgeom));
-
-  /* Force default SRID */
-  if ( (int) lwgeom->srid <= 0 )
-  {
-    lwgeom->srid = SRID_DEFAULT;
-  }
-
-  /* Error on any SRID != default */
-  // Cannot test this in MobilityDB since we do not have access to PROJ
-  // srid_check_latlong(lwgeom->srid);
-
-  /* Force the geometry to have valid geodetic coordinate range. */
-  lwgeom_nudge_geodetic(lwgeom);
-  if ( lwgeom_force_geodetic(lwgeom) == LW_TRUE )
-  {
-    meos_error(NOTICE, MEOS_ERR_TEXT_INPUT,
-      "Coordinate values were coerced into range [-180 -90, 180 90] for GEOGRAPHY");
-    return NULL;
-  }
-
-  /* force recalculate of box by dropping */
-  lwgeom_drop_bbox(lwgeom);
-
-  lwgeom_set_geodetic(lwgeom, true);
-  /* We are trusting geography_serialize will add a box if needed */
-  GSERIALIZED *result = geo_serialize(lwgeom);
-  lwgeom_free(lwgeom);
-  return result;
-}
-
-/**
- * @brief Get a geometry from a geography
- * @note PostGIS function: @p geometry_from_geography(PG_FUNCTION_ARGS)
- */
-GSERIALIZED *
-gserialized_geom_from_geog(GSERIALIZED *geom)
-{
-  LWGEOM *lwgeom = lwgeom_from_gserialized(geom);
-  /* Recalculate the boxes after re-setting the geodetic bit */
-  lwgeom_set_geodetic(lwgeom, false);
-  lwgeom_refresh_bbox(lwgeom);
-  /* We want "geometry" to think all our "geography" has an SRID, and the
-     implied SRID is the default, so we fill that in if our SRID is actually unknown. */
-  if ( (int)lwgeom->srid <= 0 )
-    lwgeom->srid = SRID_DEFAULT;
-
-  GSERIALIZED *result = geo_serialize(lwgeom);
-  lwgeom_free(lwgeom);
-  return result;
-}
-#endif /* not used  */
-
 /*****************************************************************************
  * Functions adapted from lwgeom_functions_analytic.c
  *****************************************************************************/
