@@ -211,7 +211,7 @@ tinterrel_tpointseq_simple_geom(const TSequence *seq, Datum geom,
     return result;
   }
 
-  Datum traj = PointerGetDatum(tpointcontseq_trajectory(seq));
+  Datum traj = PointerGetDatum(tpointseq_trajectory(seq));
   Datum inter = geom_intersection2d(traj, geom);
   GSERIALIZED *gsinter = DatumGetGserializedP(inter);
   if (gserialized_is_empty(gsinter))
@@ -258,8 +258,7 @@ tinterrel_tpointseq_simple_geom(const TSequence *seq, Datum geom,
   else
   {
     /* It is necessary to sort the periods */
-    SpanSet *ps1 = spanset_make_exp(periods, npers, npers, NORMALIZE,
-      ORDERED_NO);
+    SpanSet *ps1 = spanset_make_exp(periods, npers, npers, NORMALIZE, ORDER);
     ss = minus_span_spanset(&seq->period, ps1);
     pfree(ps1);
   }
@@ -297,9 +296,12 @@ tinterrel_tpointseq_simple_geom(const TSequence *seq, Datum geom,
  * @param[out] count Number of elements in the output array
  */
 static TSequence **
-tinterrel_tpointcontseq_geom_iter(const TSequence *seq, Datum geom,
+tinterrel_tpointseq_cont_geom_iter(const TSequence *seq, Datum geom,
   const STBox *box, bool tinter, datum_func2 func, int *count)
 {
+  assert(seq); assert(box); assert(count); assert(tgeo_type(seq->temptype));
+  assert(MEOS_FLAGS_GET_INTERP(seq->flags) != DISCRETE);
+
   /* Instantaneous sequence */
   if (seq->count == 1)
   {
@@ -341,15 +343,17 @@ tinterrel_tpointcontseq_geom_iter(const TSequence *seq, Datum geom,
  * @param[in] tinter True when computing tintersects, false for tdisjoint
  */
 TSequenceSet *
-tinterrel_tpointcontseq_geom(const TSequence *seq, Datum geom,
+tinterrel_tpointseq_cont_geom(const TSequence *seq, Datum geom,
   const STBox *box, bool tinter, datum_func2 func)
 {
+  assert(seq); assert(box); assert(tgeo_type(seq->temptype));
+  assert(MEOS_FLAGS_GET_INTERP(seq->flags) != DISCRETE);
+
   /* Split the temporal point in an array of non self-intersecting
    * temporal points */
   int count;
-  TSequence **sequences = tinterrel_tpointcontseq_geom_iter(seq, geom, box,
+  TSequence **sequences = tinterrel_tpointseq_cont_geom_iter(seq, geom, box,
     tinter, func, &count);
-  /* We are sure that count > 0 since the geometry is not empty */
   return tsequenceset_make_free(sequences, count, NORMALIZE);
 }
 
@@ -367,7 +371,7 @@ tinterrel_tpointseqset_geom(const TSequenceSet *ss, Datum geom,
 {
   /* Singleton sequence set */
   if (ss->count == 1)
-    return tinterrel_tpointcontseq_geom(TSEQUENCESET_SEQ_N(ss, 0), geom, box,
+    return tinterrel_tpointseq_cont_geom(TSEQUENCESET_SEQ_N(ss, 0), geom, box,
       tinter, func);
 
   int totalcount;
@@ -390,7 +394,7 @@ tinterrel_tpointseqset_geom(const TSequenceSet *ss, Datum geom,
     totalcount = 0;
     for (int i = 0; i < ss->count; i++)
     {
-      sequences[i] = tinterrel_tpointcontseq_geom_iter(
+      sequences[i] = tinterrel_tpointseq_cont_geom_iter(
         TSEQUENCESET_SEQ_N(ss, i), geom, box, tinter, func, &countseqs[i]);
       totalcount += countseqs[i];
     }
@@ -420,7 +424,7 @@ tinterrel_tpoint_geo(const Temporal *temp, const GSERIALIZED *gs, bool tinter,
 
   /* Bounding box test */
   STBox box1, box2;
-  temporal_set_bbox(temp, &box1);
+  tspatial_set_stbox(temp, &box1);
   /* Non-empty geometries have a bounding box */
   geo_set_stbox(gs, &box2);
   if (! overlaps_stbox_stbox(&box1, &box2))
@@ -451,7 +455,7 @@ tinterrel_tpoint_geo(const Temporal *temp, const GSERIALIZED *gs, bool tinter,
       result = ! MEOS_FLAGS_LINEAR_INTERP(temp->flags) ?
         (Temporal *) tinterrel_tpointseq_discstep_geom((TSequence *) temp,
           PointerGetDatum(gs), tinter, func) :
-        (Temporal *) tinterrel_tpointcontseq_geom((TSequence *) temp,
+        (Temporal *) tinterrel_tpointseq_cont_geom((TSequence *) temp,
           PointerGetDatum(gs), &box2, tinter, func);
       break;
     default: /* TSEQUENCESET */
@@ -664,7 +668,7 @@ tgeompoint '[POINT(4 3)@2000-01-04, POINT(5 3)@2000-01-05]', 1)
  * @param[in] hasz True for 3D segments
  * @param[in] func Distance function (2D or 3D)
  * @param[out] t1,t2 Resulting timestamps
- * @result Number of timestamps in the result, between 0 and 2. In the case
+ * @return Number of timestamps in the result, between 0 and 2. In the case
  * of a single result both t1 and t2 are set to the unique timestamp
  */
 int
@@ -814,7 +818,7 @@ tdwithin_tpointsegm_tpointsegm(Datum sv1, Datum ev1, Datum sv2, Datum ev2,
 /**
  * @brief Construct the result of the tdwithin function of a segment from
  * the solutions of the quadratic equation found previously
- * @result Number of sequences of the result
+ * @return Number of sequences of the result
  */
 static int
 tdwithin_add_solutions(int solutions, TimestampTz lower, TimestampTz upper,
@@ -872,7 +876,7 @@ tdwithin_add_solutions(int solutions, TimestampTz lower, TimestampTz upper,
  * @param[in] func DWithin function (2D or 3D)
  * @param[out] result Array on which the pointers of the newly constructed
  * sequences are stored
- * @result Number of elements in the resulting array
+ * @return Number of elements in the resulting array
  * @pre The temporal points must be synchronized.
  */
 static int
@@ -968,7 +972,6 @@ tdwithin_tpointseq_tpointseq(const TSequence *seq1, const TSequence *seq2,
   TSequence **sequences = palloc(sizeof(TSequence *) * seq1->count * 4);
   int count = tdwithin_tpointseq_tpointseq_iter(seq1, seq2, Float8GetDatum(dist),
     func, sequences);
-  /* We are sure that count > 0 */
   return tsequenceset_make_free(sequences, count, NORMALIZE);
 }
 
@@ -1010,7 +1013,7 @@ tdwithin_tpointseqset_tpointseqset(const TSequenceSet *ss1,
  * @param[in] func DWithin function (2D or 3D)
  * @param[out] result Array on which the pointers of the newly constructed
  * sequences are stored
- * @result Number of elements in the resulting array
+ * @return Number of elements in the resulting array
  */
 static int
 tdwithin_tpointseq_point_iter(const TSequence *seq, Datum point, Datum dist,
