@@ -52,7 +52,7 @@
  * Maximum length of an ESPG string to lookup
  * Notice that SRID_MAXIMUM is defined by PostGIS as 999999
  */
-#define MAX_EPSG_STR 12 /* EPSG:999999 */
+#define MAX_AUTH_SRID_STR 12 /* EPSG:999999 */
 
 /*****************************************************************************
  * Functions for spatial reference systems
@@ -390,16 +390,49 @@ to_dec(POINT4D *pt)
 /**
  * @brief Return a structure with the information to perform a transformation
  * @param[in] srid_from,srid_to SRIDs
+ * @note We are avoiding to have a list of recognized SRIDs cached as done in
+ * PostGIS. We didn't find a way to get the authority name from an SRID.
+ * Given that all (but one) entries in PostGIS spatial_ref_sys table have
+ * either authority name equal to 'EPSG' or 'ESRI', we try finding the two
+ * combinations for the input and output SRIDs.
  */
 LWPROJ *
 lwproj_transform(int32 srid_from, int32 srid_to)
 {
-  char srid_from_str[MAX_EPSG_STR];
-  char srid_to_str[MAX_EPSG_STR];
-  int len = snprintf(srid_from_str, MAX_EPSG_STR, "EPSG:%d", srid_from);
-  srid_from_str[len] = '\0';
-  len = snprintf(srid_to_str, MAX_EPSG_STR, "EPSG:%d", srid_to);
-  srid_to_str[len] = '\0';
+  char srid_from_str[MAX_AUTH_SRID_STR];
+  char srid_to_str[MAX_AUTH_SRID_STR];
+  /* From SRID */
+  snprintf(srid_from_str, MAX_AUTH_SRID_STR, "EPSG:%d", srid_from);
+  PJ *pj1 = proj_create(proj_get_context(), srid_from_str);
+  if (! pj1)
+  {
+    snprintf(srid_from_str, MAX_AUTH_SRID_STR, "ESRI:%d", srid_from);
+    pj1 = proj_create(proj_get_context(), srid_from_str);
+    if (! pj1)
+    {
+      /* Error */
+      meos_error(ERROR, MEOS_ERR_INTERNAL_ERROR,
+        "Transform: Could not form projection from 'srid=%d'", srid_from);
+      return NULL;
+    }
+  }
+  proj_destroy(pj1);
+  /* To SRID */
+  snprintf(srid_to_str, MAX_AUTH_SRID_STR, "EPSG:%d", srid_to);
+  PJ *pj2 = proj_create(proj_get_context(), srid_to_str);
+  if (! pj2)
+  {
+    snprintf(srid_to_str, MAX_AUTH_SRID_STR, "ESRI:%d", srid_to);
+    pj2 = proj_create(proj_get_context(), srid_to_str);
+    if (! pj2)
+    {
+      /* Error */
+      meos_error(ERROR, MEOS_ERR_INTERNAL_ERROR,
+        "Transform: Could not form projection to 'srid=%d'", srid_to);
+      return NULL;
+    }
+  }
+  proj_destroy(pj2);
   LWPROJ *result = lwproj_from_str(srid_from_str, srid_to_str);
   if (result)
     return result;
@@ -417,14 +450,14 @@ lwproj_transform(int32 srid_from, int32 srid_to)
  * @param[in] is_forward True when the transformation is forward
  */
 static LWPROJ *
-lwproj_transform_pipeline(char *pipeline, bool is_forward)
+lwproj_transform_pipeline(const char *pipeline, bool is_forward)
 {
   assert(pipeline);
   LWPROJ *result = lwproj_from_str_pipeline(pipeline, is_forward);
   if (result)
     return result;
   /* Error */
-  PJ *pj_in = proj_create(PJ_DEFAULT_CTX, pipeline);
+  PJ *pj_in = proj_create(proj_get_context(), pipeline);
   if (! pj_in)
   {
     proj_errno_reset(NULL);
@@ -547,7 +580,7 @@ point_transform(const GSERIALIZED *gs, int32 srid_to)
  * @param[in] is_forward True when the transformation is forward
  */
 GSERIALIZED *
-point_transform_pipeline(const GSERIALIZED *gs, char *pipeline,
+point_transform_pipeline(const GSERIALIZED *gs, const char *pipeline,
   int32 srid_to, bool is_forward)
 {
   int32 srid_from;
@@ -634,7 +667,7 @@ geoset_transform(const Set *s, int32 srid_to)
  * @param[in] is_forward True when the transformation is forward
  */
 Set *
-geoset_transform_pipeline(const Set *s, char *pipeline, int32 srid_to,
+geoset_transform_pipeline(const Set *s, const char *pipeline, int32 srid_to,
   bool is_forward)
 {
   int32 srid_from;
@@ -771,7 +804,7 @@ stbox_transform(const STBox *box, int32 srid_to)
  * @param[in] is_forward True when the transformation is forward
  */
 STBox *
-stbox_transform_pipeline(const STBox *box, char *pipeline,
+stbox_transform_pipeline(const STBox *box, const char *pipeline,
   int32 srid_to, bool is_forward)
 {
   /* Ensure validity of the arguments */
@@ -800,7 +833,7 @@ stbox_transform_pipeline(const STBox *box, char *pipeline,
  * @param[in] pj Information about the transformation
  */
 static bool
-tpointinst_transf_pj(TInstant *inst, int32 srid_to, const LWPROJ *pj)
+tpointinst_transf_pj(const TInstant *inst, int32 srid_to, const LWPROJ *pj)
 {
   assert(inst); assert(pj); assert(tgeo_type(inst->temptype));
   GSERIALIZED *gs = DatumGetGserializedP(tinstant_val(inst));
@@ -938,7 +971,7 @@ tpoint_transform(const Temporal *temp, int32 srid_to)
  * @param[in] is_forward True when the transformation is forward
  */
 Temporal *
-tpoint_transform_pipeline(const Temporal *temp, char *pipeline,
+tpoint_transform_pipeline(const Temporal *temp, const char *pipeline,
   int32 srid_to, bool is_forward)
 {
   /* Ensure validity of the arguments */
