@@ -374,6 +374,69 @@ CREATE CAST (floatset AS floatspan) WITH FUNCTION span(floatset);
 CREATE CAST (dateset AS datespan) WITH FUNCTION span(dateset);
 CREATE CAST (tstzset AS tstzspan) WITH FUNCTION span(tstzset);
 
+CREATE FUNCTION spans(intset)
+  RETURNS intspan[]
+  AS 'MODULE_PATHNAME', 'Set_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION spans(bigintset)
+  RETURNS bigintspan[]
+  AS 'MODULE_PATHNAME', 'Set_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION spans(floatset)
+  RETURNS floatspan[]
+  AS 'MODULE_PATHNAME', 'Set_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION spans(dateset)
+  RETURNS datespan[]
+  AS 'MODULE_PATHNAME', 'Set_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION spans(tstzset)
+  RETURNS tstzspan[]
+  AS 'MODULE_PATHNAME', 'Set_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
+CREATE FUNCTION splitNSpans(intset, integer)
+  RETURNS intspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitNSpans(bigintset, integer)
+  RETURNS bigintspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitNSpans(floatset, integer)
+  RETURNS floatspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitNSpans(dateset, integer)
+  RETURNS datespan[]
+  AS 'MODULE_PATHNAME', 'Set_split_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitNSpans(tstzset, integer)
+  RETURNS tstzspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
+CREATE FUNCTION splitEachNSpans(intset, integer)
+  RETURNS intspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_each_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitEachNSpans(bigintset, integer)
+  RETURNS bigintspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_each_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitEachNSpans(floatset, integer)
+  RETURNS floatspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_each_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitEachNSpans(dateset, integer)
+  RETURNS datespan[]
+  AS 'MODULE_PATHNAME', 'Set_split_each_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION splitEachNSpans(tstzset, integer)
+  RETURNS tstzspan[]
+  AS 'MODULE_PATHNAME', 'Set_split_each_n_spans'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 CREATE FUNCTION intspan(floatspan)
   RETURNS intspan
   AS 'MODULE_PATHNAME', 'Floatspan_to_intspan'
@@ -402,6 +465,10 @@ CREATE FUNCTION span(int4range)
   RETURNS intspan
   AS 'MODULE_PATHNAME', 'Range_to_span'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION span(int8range)
+  RETURNS bigintspan
+  AS 'MODULE_PATHNAME', 'Range_to_span'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 CREATE FUNCTION span(daterange)
   RETURNS datespan
   AS 'MODULE_PATHNAME', 'Range_to_span'
@@ -410,10 +477,15 @@ CREATE FUNCTION span(tstzrange)
   RETURNS tstzspan
   AS 'MODULE_PATHNAME', 'Range_to_span'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 CREATE FUNCTION range(intspan)
   RETURNS int4range
   AS 'MODULE_PATHNAME', 'Span_to_range'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION range(bigintspan)
+  RETURNS int8range
+  AS 'MODULE_PATHNAME', 'Span_to_range'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 CREATE FUNCTION range(datespan)
   RETURNS daterange
   AS 'MODULE_PATHNAME', 'Span_to_range'
@@ -424,9 +496,11 @@ CREATE FUNCTION range(tstzspan)
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
 CREATE CAST (int4range AS intspan) WITH FUNCTION span(int4range);
+CREATE CAST (int8range AS bigintspan) WITH FUNCTION span(int8range);
 CREATE CAST (daterange AS datespan) WITH FUNCTION span(daterange);
 CREATE CAST (tstzrange AS tstzspan) WITH FUNCTION span(tstzrange);
 CREATE CAST (intspan AS int4range) WITH FUNCTION range(intspan);
+CREATE CAST (bigintspan AS int8range) WITH FUNCTION range(bigintspan);
 CREATE CAST (datespan AS daterange) WITH FUNCTION range(datespan);
 CREATE CAST (tstzspan AS tstzrange) WITH FUNCTION range(tstzspan);
 
@@ -607,6 +681,15 @@ CREATE FUNCTION shiftScale(tstzspan, interval, interval)
   AS 'MODULE_PATHNAME', 'Tstzspan_shift_scale'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
+CREATE FUNCTION floor(floatspan)
+  RETURNS floatspan
+  AS 'MODULE_PATHNAME', 'Floatspan_floor'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION ceil(floatspan)
+  RETURNS floatspan
+  AS 'MODULE_PATHNAME', 'Floatspan_ceil'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 CREATE FUNCTION round(floatspan, integer DEFAULT 0)
   RETURNS floatspan
   AS 'MODULE_PATHNAME', 'Floatspan_round'
