@@ -564,6 +564,23 @@ CREATE FUNCTION maxValue(ttext)
   AS 'MODULE_PATHNAME', 'Temporal_max_value'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
+CREATE FUNCTION valueN(tbool, integer)
+  RETURNS bool
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION valueN(tint, integer)
+  RETURNS integer
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION valueN(tfloat, integer)
+  RETURNS float
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION valueN(ttext, integer)
+  RETURNS text
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 CREATE FUNCTION minInstant(tint)
   RETURNS tint
   AS 'MODULE_PATHNAME', 'Temporal_min_instant'
@@ -1147,12 +1164,12 @@ CREATE FUNCTION tprecision(tfloat, duration interval,
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
 CREATE FUNCTION tsample(tint, duration interval,
-  origin timestamptz DEFAULT '2000-01-03')
+  origin timestamptz DEFAULT '2000-01-03', interp text DEFAULT 'discrete')
   RETURNS tint
   AS 'MODULE_PATHNAME', 'Temporal_tsample'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 CREATE FUNCTION tsample(tfloat, duration interval,
-  origin timestamptz DEFAULT '2000-01-03')
+  origin timestamptz DEFAULT '2000-01-03', interp text DEFAULT 'discrete')
   RETURNS tfloat
   AS 'MODULE_PATHNAME', 'Temporal_tsample'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
