@@ -299,6 +299,11 @@ CREATE FUNCTION endValue(tnpoint)
   AS 'MODULE_PATHNAME', 'Temporal_end_value'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
+CREATE FUNCTION valueN(tnpoint, int)
+  RETURNS npoint
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 CREATE FUNCTION duration(tnpoint, boundspan boolean DEFAULT FALSE)
   RETURNS interval
   AS 'MODULE_PATHNAME', 'Temporal_duration'
@@ -607,7 +612,7 @@ CREATE TYPE time_tnpoint AS (
   temp tnpoint
 );
 
-CREATE FUNCTION timeSplit(tnpoint, bucket_width interval,
+CREATE FUNCTION timeSplit(tnpoint, bin_width interval,
     origin timestamptz DEFAULT '2000-01-03')
   RETURNS setof time_tnpoint
   AS 'MODULE_PATHNAME', 'Temporal_time_split'
