@@ -335,6 +335,19 @@ CREATE FUNCTION TmaxInc(stbox)
   AS 'MODULE_PATHNAME', 'Stbox_tmax_inc'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
+CREATE FUNCTION area(stbox, spheroid bool DEFAULT true)
+  RETURNS float
+  AS 'MODULE_PATHNAME', 'Stbox_area'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION volume(stbox)
+  RETURNS float
+  AS 'MODULE_PATHNAME', 'Stbox_volume'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION perimeter(stbox, spheroid bool DEFAULT true)
+  RETURNS float
+  AS 'MODULE_PATHNAME', 'Stbox_perimeter'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 /*****************************************************************************
  * Transformation functions
  *****************************************************************************/
