@@ -363,6 +363,9 @@ CREATE FUNCTION getValue(tgeogpoint)
   AS 'MODULE_PATHNAME', 'Tinstant_value'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
+-- There is no getValues() function for temporal points,
+-- it is called trajectory() for temporal points
+
 CREATE FUNCTION getTimestamp(tgeompoint)
   RETURNS timestamptz
   AS 'MODULE_PATHNAME', 'Tinstant_timestamptz'
@@ -381,6 +384,15 @@ CREATE FUNCTION valueSet(tgeogpoint)
   AS 'MODULE_PATHNAME', 'Temporal_valueset'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
+CREATE FUNCTION valueN(tgeompoint, integer)
+  RETURNS geometry
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+CREATE FUNCTION valueN(tgeogpoint, integer)
+  RETURNS geography
+  AS 'MODULE_PATHNAME', 'Temporal_value_n'
+  LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
+
 -- time is a reserved word in SQL
 CREATE FUNCTION getTime(tgeompoint)
   RETURNS tstzspanset
@@ -623,12 +635,12 @@ CREATE FUNCTION tprecision(tgeogpoint, duration interval,
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 
 CREATE FUNCTION tsample(tgeompoint, duration interval,
-  origin timestamptz DEFAULT '2000-01-03')
+  origin timestamptz DEFAULT '2000-01-03', interp text DEFAULT 'discrete')
   RETURNS tgeompoint
   AS 'MODULE_PATHNAME', 'Temporal_tsample'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
 CREATE FUNCTION tsample(tgeogpoint, duration interval,
-  origin timestamptz DEFAULT '2000-01-03')
+  origin timestamptz DEFAULT '2000-01-03', interp text DEFAULT 'discrete')
   RETURNS tgeogpoint
   AS 'MODULE_PATHNAME', 'Temporal_tsample'
   LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
@@ -863,12 +875,12 @@ CREATE TYPE time_tgeogpoint AS (
   temp tgeogpoint
 );
 
-CREATE FUNCTION timeSplit(tgeompoint, bucket_width interval,
+CREATE FUNCTION timeSplit(tgeompoint, bin_width interval,
     origin timestamptz DEFAULT '2000-01-03')
   RETURNS setof time_tgeompoint
   AS 'MODULE_PATHNAME', 'Temporal_time_split'
   LANGUAGE C IMMUTABLE PARALLEL SAFE STRICT;
-CREATE FUNCTION timeSplit(tgeogpoint, bucket_width interval,
+CREATE FUNCTION timeSplit(tgeogpoint, bin_width interval,
     origin timestamptz DEFAULT '2000-01-03')
   RETURNS setof time_tgeogpoint
   AS 'MODULE_PATHNAME', 'Temporal_time_split'
