@@ -37,12 +37,8 @@
 
 /* PostgreSQL */
 #include <postgres.h>
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <access/heaptoast.h>
-  #include <access/detoast.h>
-#else
-  #include <access/tuptoaster.h>
-#endif
+#include <access/heaptoast.h>
+#include <access/detoast.h>
 #include <funcapi.h>
 #include <utils/timestamp.h>
 /* MEOS */
@@ -145,10 +141,10 @@ Set_constructor(PG_FUNCTION_ARGS)
   ArrayType *array = PG_GETARG_ARRAYTYPE_P(0);
   ensure_not_empty_array(array);
   meosType settype = oid_type(get_fn_expr_rettype(fcinfo->flinfo));
+  meosType basetype = settype_basetype(settype);
   int count;
   Datum *values = datumarr_extract(array, &count);
-  meosType basetype = settype_basetype(settype);
-  Set *result = set_make_free(values, count, basetype, ORDERED_NO);
+  Set *result = set_make_free(values, count, basetype, ORDER);
   PG_FREE_IF_COPY(array, 0);
   PG_RETURN_SET_P(result);
 }
@@ -455,6 +451,38 @@ Tstzset_shift_scale(PG_FUNCTION_ARGS)
   PG_RETURN_SET_P(result);
 }
 
+PGDLLEXPORT Datum Floatset_floor(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Floatset_floor);
+/**
+ * @ingroup mobilitydb_setspan_transf
+ * @brief Return a float set rounded down to the nearest integer
+ * @sqlfn floor()
+ */
+Datum
+Floatset_floor(PG_FUNCTION_ARGS)
+{
+  Set *s = PG_GETARG_SET_P(0);
+  Set *result = floatset_floor(s);
+  PG_FREE_IF_COPY(s, 0);
+  PG_RETURN_SET_P(result);
+}
+
+PGDLLEXPORT Datum Floatset_ceil(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Floatset_ceil);
+/**
+ * @ingroup mobilitydb_setspan_transf
+ * @brief Return a float set rounded up to the nearest integer
+ * @sqlfn ceil()
+ */
+Datum
+Floatset_ceil(PG_FUNCTION_ARGS)
+{
+  Set *s = PG_GETARG_SET_P(0);
+  Set *result = floatset_ceil(s);
+  PG_FREE_IF_COPY(s, 0);
+  PG_RETURN_SET_P(result);
+}
+
 PGDLLEXPORT Datum Floatset_round(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(Floatset_round);
 /**
@@ -606,7 +634,6 @@ Datum
 Set_unnest(PG_FUNCTION_ARGS)
 {
   FuncCallContext *funcctx;
-  SetUnnestState *state;
 
   /* If the function is being called for the first time */
   if (SRF_IS_FIRSTCALL())
@@ -626,8 +653,8 @@ Set_unnest(PG_FUNCTION_ARGS)
   /* Stuff done on every call of the function */
   funcctx = SRF_PERCALL_SETUP();
   /* Get state */
-  state = funcctx->user_fctx;
-  /* Stop when we've used up all buckets */
+  SetUnnestState *state = funcctx->user_fctx;
+  /* Stop when we've used up all bins */
   if (state->done)
   {
     /* Switch to memory context appropriate for multiple function calls */
