@@ -183,6 +183,72 @@ Set_to_span(PG_FUNCTION_ARGS)
   PG_RETURN_SPAN_P(result);
 }
 
+PGDLLEXPORT Datum Set_spans(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Set_spans);
+/**
+ * @ingroup mobilitydb_setspan_conversion
+ * @brief Return an array of spans from the elements of a set
+ * @sqlfn spans()
+ */
+Datum
+Set_spans(PG_FUNCTION_ARGS)
+{
+  Set *s = PG_GETARG_SET_P(0);
+  Span *spans = set_spans(s);
+  int count = s->count;
+  PG_FREE_IF_COPY(s, 0);
+  if (! spans)
+    PG_RETURN_NULL();
+  ArrayType *result = spanarr_to_array(spans, count);
+  pfree(spans);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
+PGDLLEXPORT Datum Set_split_n_spans(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Set_split_n_spans);
+/**
+ * @ingroup mobilitydb_setspan_conversion
+ * @brief Return an array of N spans from the elements of a set
+ * @sqlfn splitNspans()
+ */
+Datum
+Set_split_n_spans(PG_FUNCTION_ARGS)
+{
+  Set *s = PG_GETARG_SET_P(0);
+  int span_count = PG_GETARG_INT32(1);
+  int count;
+  Span *spans = set_split_n_spans(s, span_count, &count);
+  PG_FREE_IF_COPY(s, 0);
+  if (! spans)
+    PG_RETURN_NULL();
+  ArrayType *result = spanarr_to_array(spans, count);
+  pfree(spans);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
+PGDLLEXPORT Datum Set_split_each_n_spans(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Set_split_each_n_spans);
+/**
+ * @ingroup mobilitydb_setspan_conversion
+ * @brief Return an array of spans from the elements of a set obtained by
+ * merging a given number of successive elements
+ * @sqlfn splitEachNSpans()
+ */
+Datum
+Set_split_each_n_spans(PG_FUNCTION_ARGS)
+{
+  Set *s = PG_GETARG_SET_P(0);
+  int elem_count = PG_GETARG_INT32(1);
+  int count;
+  Span *spans = set_split_each_n_spans(s, elem_count, &count);
+  PG_FREE_IF_COPY(s, 0);
+  if (! spans)
+    PG_RETURN_NULL();
+  ArrayType *result = spanarr_to_array(spans, count);
+  pfree(spans);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
 PGDLLEXPORT Datum Intspan_to_floatspan(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(Intspan_to_floatspan);
 /**
@@ -257,8 +323,8 @@ Datum
 Span_to_range(PG_FUNCTION_ARGS)
 {
   Span *s = PG_GETARG_SPAN_P(0);
-  assert(s->basetype == T_INT4 || s->basetype == T_DATE ||
-    s->basetype == T_TIMESTAMPTZ);
+  assert(s->basetype == T_INT4 || s->basetype == T_INT8 || 
+    s->basetype == T_DATE || s->basetype == T_TIMESTAMPTZ);
   RangeType *range = range_make(s->lower, s->upper, s->lower_inc, s->upper_inc,
     s->basetype);
   PG_RETURN_POINTER(range);
@@ -282,10 +348,13 @@ range_set_span(RangeType *range, TypeCacheEntry *typcache, Span *result)
   bool empty;
   range_deserialize(typcache, range, &lower, &upper, &empty);
   Oid type_id = typcache->rngelemtype->type_id;
-  assert(type_id == INT4OID || type_id == DATEOID || type_id == TIMESTAMPTZOID);
+  assert(type_id == INT4OID || type_id == INT8OID || type_id == DATEOID || 
+    type_id == TIMESTAMPTZOID);
   meosType basetype;
   if (type_id == INT4OID)
     basetype = T_INT4;
+  else if (type_id == INT8OID)
+    basetype = T_INT8;
   else if (type_id == DATEOID)
     basetype = T_DATE;
   else /* type_id == TIMESTAMPTZOID */
@@ -310,6 +379,7 @@ Range_to_span(PG_FUNCTION_ARGS)
   RangeType *range = PG_GETARG_RANGE_P(0);
   TypeCacheEntry *typcache = range_get_typcache(fcinfo, RangeTypeGetOid(range));
   assert(typcache->rngelemtype->type_id == INT4OID ||
+    typcache->rngelemtype->type_id == INT8OID ||
     typcache->rngelemtype->type_id == DATEOID ||
     typcache->rngelemtype->type_id == TIMESTAMPTZOID);
   Span *result = palloc(sizeof(Span));
@@ -527,6 +597,34 @@ Tstzspan_shift_scale(PG_FUNCTION_ARGS)
   PG_RETURN_SPAN_P(tstzspan_shift_scale(s, shift, duration));
 }
 
+PGDLLEXPORT Datum Floatspan_floor(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Floatspan_floor);
+/**
+ * @ingroup mobilitydb_setspan_transf
+ * @brief Return a float span rounded down to the nearest integer
+ * @sqlfn floor()
+ */
+Datum
+Floatspan_floor(PG_FUNCTION_ARGS)
+{
+  Span *s = PG_GETARG_SPAN_P(0);
+  PG_RETURN_SPAN_P(floatspan_floor(s));
+}
+
+PGDLLEXPORT Datum Floatspan_ceil(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Floatspan_ceil);
+/**
+ * @ingroup mobilitydb_setspan_transf
+ * @brief Return a float span rounded up to the nearest integer
+ * @sqlfn ceil()
+ */
+Datum
+Floatspan_ceil(PG_FUNCTION_ARGS)
+{
+  Span *s = PG_GETARG_SPAN_P(0);
+  PG_RETURN_SPAN_P(floatspan_ceil(s));
+}
+
 PGDLLEXPORT Datum Floatspan_round(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(Floatspan_round);
 /**
