@@ -37,12 +37,8 @@
 #include <assert.h>
 /* PostgreSQL */
 #include <postgres.h>
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <access/heaptoast.h>
-  #include <access/detoast.h>
-#else
-  #include <access/tuptoaster.h>
-#endif
+#include <access/heaptoast.h>
+#include <access/detoast.h>
 #include <utils/timestamp.h>
 /* MEOS */
 #include <meos.h>
@@ -148,7 +144,7 @@ Spanset_constructor(PG_FUNCTION_ARGS)
   ensure_not_empty_array(array);
   int count;
   Span *spans = spanarr_extract(array, &count);
-  SpanSet *result = spanset_make_free(spans, count, NORMALIZE, ORDERED);
+  SpanSet *result = spanset_make_free(spans, count, NORMALIZE, ORDER_NO);
   PG_FREE_IF_COPY(array, 0);
   PG_RETURN_SPANSET_P(result);
 }
@@ -319,8 +315,8 @@ Datum
 Spanset_to_multirange(PG_FUNCTION_ARGS)
 {
   SpanSet *ss = PG_GETARG_SPANSET_P(0);
-  assert(ss->spantype == T_INTSPAN || ss->spantype == T_DATESPAN ||
-    ss->spantype == T_TSTZSPAN);
+  assert(ss->spantype == T_INTSPAN || ss->spantype == T_BIGINTSPAN ||
+    ss->spantype == T_DATESPAN || ss->spantype == T_TSTZSPAN);
   MultirangeType *result = multirange_make(ss);
   PG_FREE_IF_COPY(ss, 0);
   PG_RETURN_MULTIRANGE_P(result);
@@ -352,7 +348,7 @@ Multirange_to_spanset(PG_FUNCTION_ARGS)
     range_set_span(range, typcache->rngtype, &spans[i]);
   }
   SpanSet *result = spanset_make_free(spans, mrange->rangeCount, NORMALIZE,
-    ORDERED);
+    ORDER_NO);
   PG_FREE_IF_COPY(mrange, 0);
   PG_RETURN_SPANSET_P(result);
 }
@@ -727,23 +723,6 @@ Spanset_span_n(PG_FUNCTION_ARGS)
   PG_RETURN_SPAN_P(result);
 }
 
-PGDLLEXPORT Datum Spanset_spans(PG_FUNCTION_ARGS);
-PG_FUNCTION_INFO_V1(Spanset_spans);
-/**
- * @ingroup mobilitydb_setspan_accessor
- * @brief Return the array of spans of a span set
- * @sqlfn spans()
- */
-Datum
-Spanset_spans(PG_FUNCTION_ARGS)
-{
-  SpanSet *ss = PG_GETARG_SPANSET_P(0);
-  const Span **spans = spanset_sps(ss);
-  ArrayType *result = spanarr_to_array(spans, ss->count);
-  PG_FREE_IF_COPY(ss, 0);
-  PG_RETURN_ARRAYTYPE_P(result);
-}
-
 /*****************************************************************************
  * Transformation functions
  *
@@ -860,6 +839,38 @@ Tstzspanset_shift_scale(PG_FUNCTION_ARGS)
   PG_RETURN_SPANSET_P(result);
 }
 
+PGDLLEXPORT Datum Floatspanset_floor(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Floatspanset_floor);
+/**
+ * @ingroup mobilitydb_setspan_transf
+ * @brief Return a float span set rounded down to the nearest integer
+ * @sqlfn floor()
+ */
+Datum
+Floatspanset_floor(PG_FUNCTION_ARGS)
+{
+  SpanSet *ss = PG_GETARG_SPANSET_P(0);
+  SpanSet *result = floatspanset_floor(ss);
+  PG_FREE_IF_COPY(ss, 0);
+  PG_RETURN_SPANSET_P(result);
+}
+
+PGDLLEXPORT Datum Floatspanset_ceil(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Floatspanset_ceil);
+/**
+ * @ingroup mobilitydb_setspan_transf
+ * @brief Return a float span set rounded up to the nearest integer
+ * @sqlfn ceil()
+ */
+Datum
+Floatspanset_ceil(PG_FUNCTION_ARGS)
+{
+  SpanSet *ss = PG_GETARG_SPANSET_P(0);
+  SpanSet *result = floatspanset_ceil(ss);
+  PG_FREE_IF_COPY(ss, 0);
+  PG_RETURN_SPANSET_P(result);
+}
+
 PGDLLEXPORT Datum Floatspanset_round(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(Floatspanset_round);
 /**
@@ -878,6 +889,72 @@ Floatspanset_round(PG_FUNCTION_ARGS)
   PG_RETURN_SPANSET_P(result);
 }
 
+PGDLLEXPORT Datum Spanset_spans(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Spanset_spans);
+/**
+ * @ingroup mobilitydb_temporal_bbox_topo
+ * @brief Return an array of spans from the spans of a spanset
+ * @sqlfn spans()
+ */
+Datum
+Spanset_spans(PG_FUNCTION_ARGS)
+{
+  SpanSet *ss = PG_GETARG_SPANSET_P(0);
+  Span *spans = spanset_spans(ss);
+  int count = ss->count;
+  PG_FREE_IF_COPY(ss, 0);
+  if (! spans)
+    PG_RETURN_NULL();
+  ArrayType *result = spanarr_to_array(spans, count);
+  pfree(spans);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
+PGDLLEXPORT Datum Spanset_split_n_spans(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Spanset_split_n_spans);
+/**
+ * @ingroup mobilitydb_temporal_bbox_topo
+ * @brief Return an array of N spans from the spans of a spanset
+ * @sqlfn splitNspans()
+ */
+Datum
+Spanset_split_n_spans(PG_FUNCTION_ARGS)
+{
+  SpanSet *ss = PG_GETARG_SPANSET_P(0);
+  int span_count = PG_GETARG_INT32(1);
+  int count;
+  Span *spans = spanset_split_n_spans(ss, span_count, &count);
+  PG_FREE_IF_COPY(ss, 0);
+  if (! spans)
+    PG_RETURN_NULL();
+  ArrayType *result = spanarr_to_array(spans, count);
+  pfree(spans);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
+PGDLLEXPORT Datum Spanset_split_each_n_spans(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Spanset_split_each_n_spans);
+/**
+ * @ingroup mobilitydb_temporal_bbox_topo
+ * @brief Return an array of spans from a spanset obtained by merging a given
+ * number of successive composing spans
+ * @sqlfn splitEachNspans()
+ */
+Datum
+Spanset_split_each_n_spans(PG_FUNCTION_ARGS)
+{
+  SpanSet *ss = PG_GETARG_SPANSET_P(0);
+  int span_count = PG_GETARG_INT32(1);
+  int count;
+  Span *spans = spanset_split_each_n_spans(ss, span_count, &count);
+  PG_FREE_IF_COPY(ss, 0);
+  if (! spans)
+    PG_RETURN_NULL();
+  ArrayType *result = spanarr_to_array(spans, count);
+  pfree(spans);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
 /*****************************************************************************
  * Comparison functions for defining B-tree indexes
  *****************************************************************************/
