@@ -567,9 +567,7 @@ Tbox_shift_value(PG_FUNCTION_ARGS)
 {
   TBox *box = PG_GETARG_TBOX_P(0);
   Datum shift = PG_GETARG_DATUM(1);
-  meosType basetype = oid_type(get_fn_expr_argtype(fcinfo->flinfo, 1));
-  PG_RETURN_TBOX_P(tbox_shift_scale_value(box, shift, 0, basetype, true,
-    false));
+  PG_RETURN_TBOX_P(tbox_shift_scale_value(box, shift, 0, true, false));
 }
 
 PGDLLEXPORT Datum Tbox_shift_time(PG_FUNCTION_ARGS);
@@ -599,9 +597,7 @@ Tbox_scale_value(PG_FUNCTION_ARGS)
 {
   TBox *box = PG_GETARG_TBOX_P(0);
   Datum width = PG_GETARG_DATUM(1);
-  meosType basetype = oid_type(get_fn_expr_argtype(fcinfo->flinfo, 1));
-  PG_RETURN_TBOX_P(tbox_shift_scale_value(box, 0, width, basetype, false,
-    true));
+  PG_RETURN_TBOX_P(tbox_shift_scale_value(box, 0, width, false, true));
 }
 
 PGDLLEXPORT Datum Tbox_scale_time(PG_FUNCTION_ARGS);
@@ -633,9 +629,7 @@ Tbox_shift_scale_value(PG_FUNCTION_ARGS)
   TBox *box = PG_GETARG_TBOX_P(0);
   Datum shift = PG_GETARG_DATUM(1);
   Datum width = PG_GETARG_DATUM(2);
-  meosType basetype = oid_type(get_fn_expr_argtype(fcinfo->flinfo, 1));
-  PG_RETURN_TBOX_P(tbox_shift_scale_value(box, shift, width, basetype, true,
-    true));
+  PG_RETURN_TBOX_P(tbox_shift_scale_value(box, shift, width, true, true));
 }
 
 PGDLLEXPORT Datum Tbox_shift_scale_time(PG_FUNCTION_ARGS);
