@@ -39,12 +39,8 @@
 /* PostgreSQL */
 #include <postgres.h>
 #include <funcapi.h>
-#if POSTGRESQL_VERSION_NUMBER >= 130000
-  #include <access/heaptoast.h>
-  #include <access/detoast.h>
-#else
-  #include <access/tuptoaster.h>
-#endif
+#include <access/heaptoast.h>
+#include <access/detoast.h>
 #include <libpq/pqformat.h>
 #include <utils/timestamp.h>
 /* MEOS */
@@ -114,7 +110,7 @@ time_max_header_size(void)
  * in PostGIS functions such as #transform, #geography_distance, or
  * #geography_azimuth that need to access the proj cache
  */
-static FunctionCallInfo _FCINFO;
+static FunctionCallInfo MOBDB_PG_FCINFO;
 
 /**
  * @brief Fetch from the cache the fcinfo of the external function
@@ -122,8 +118,8 @@ static FunctionCallInfo _FCINFO;
 FunctionCallInfo
 fetch_fcinfo()
 {
-  assert(_FCINFO);
-  return _FCINFO;
+  assert(MOBDB_PG_FCINFO);
+  return MOBDB_PG_FCINFO;
 }
 
 /**
@@ -132,7 +128,7 @@ fetch_fcinfo()
 void
 store_fcinfo(FunctionCallInfo fcinfo)
 {
-  _FCINFO = fcinfo;
+  MOBDB_PG_FCINFO = fcinfo;
   return;
 }
 
@@ -147,13 +143,11 @@ store_fcinfo(FunctionCallInfo fcinfo)
 bool
 ensure_not_empty_array(ArrayType *array)
 {
-  if (ArrayGetNItems(ARR_NDIM(array), ARR_DIMS(array)) == 0)
-  {
-    ereport(ERROR, (errcode(ERRCODE_ARRAY_ELEMENT_ERROR),
-      errmsg("The input array cannot be empty")));
-    return false;
-  }
-  return true;
+  if (ArrayGetNItems(ARR_NDIM(array), ARR_DIMS(array)) > 0)
+    return true;
+  ereport(ERROR, (errcode(ERRCODE_ARRAY_ELEMENT_ERROR),
+    errmsg("The input array cannot be empty")));
+  return false;
 }
 
 /*****************************************************************************
@@ -230,8 +224,7 @@ PG_FUNCTION_INFO_V1(Temporal_typmod_out);
 Datum
 Temporal_typmod_out(PG_FUNCTION_ARGS)
 {
-  char *s = palloc(64);
-  char *str = s;
+  char *str = palloc(TYPMOD_MAXLEN);
   int32 typmod = PG_GETARG_INT32(0);
   int16 subtype = TYPMOD_GET_SUBTYPE(typmod);
   /* No type? Then no typmod at all. Return empty string.  */
@@ -240,8 +233,8 @@ Temporal_typmod_out(PG_FUNCTION_ARGS)
     *str = '\0';
     PG_RETURN_CSTRING(str);
   }
-  sprintf(str, "(%s)", tempsubtype_name(subtype));
-  PG_RETURN_CSTRING(s);
+  snprintf(str, TYPMOD_MAXLEN, "(%s)", tempsubtype_name(subtype));
+  PG_RETURN_CSTRING(str);
 }
 
 PGDLLEXPORT Datum Temporal_enforce_typmod(PG_FUNCTION_ARGS);
@@ -478,6 +471,7 @@ temporal_write(const Temporal *temp, StringInfo buf)
 {
   pq_sendbyte(buf, temp->temptype);
   pq_sendbyte(buf, temp->subtype);
+  assert(temptype_subtype(temp->subtype));
   assert(temp->subtype == TINSTANT || temp->subtype == TSEQUENCE);
   if (temp->subtype == TINSTANT)
     tinstant_write((TInstant *) temp, buf);
@@ -904,7 +898,7 @@ Temporal_valueset(PG_FUNCTION_ARGS)
     PG_FREE_IF_COPY(temp, 0);
     PG_RETURN_ARRAYTYPE_P(result);
   }
-  Set *result = set_make_free(values, count, basetype, ORDERED);
+  Set *result = set_make_free(values, count, basetype, ORDER_NO);
   PG_FREE_IF_COPY(temp, 0);
   PG_RETURN_SET_P(result);
 }
@@ -957,6 +951,26 @@ Temporal_end_value(PG_FUNCTION_ARGS)
   PG_RETURN_DATUM(result);
 }
 
+PGDLLEXPORT Datum Temporal_value_n(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Temporal_value_n);
+/**
+ * @ingroup mobilitydb_temporal_accessor
+ * @brief Return the n-th value of a temporal value
+ * @sqlfn valueN()
+ */
+Datum
+Temporal_value_n(PG_FUNCTION_ARGS)
+{
+  Temporal *temp = PG_GETARG_TEMPORAL_P(0);
+  int n = PG_GETARG_INT32(1); /* Assume 1-based */
+  Datum result;
+  bool found = temporal_value_n(temp, n, &result);
+  PG_FREE_IF_COPY(temp, 0);
+  if (! found)
+    PG_RETURN_NULL();
+  PG_RETURN_DATUM(result);
+}
+
 PGDLLEXPORT Datum Temporal_min_value(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(Temporal_min_value);
 /**
@@ -1703,9 +1717,9 @@ temporal_unnest_state_make(const Temporal *temp)
 void
 temporal_unnest_state_next(TempUnnestState *state)
 {
-  if (!state || state->done)
+  if (! state || state->done)
     return;
-  /* Move to the next bucket */
+  /* Move to the next bin */
   state->i++;
   if (state->i == state->count)
     state->done = true;
@@ -1723,11 +1737,6 @@ Datum
 Temporal_unnest(PG_FUNCTION_ARGS)
 {
   FuncCallContext *funcctx;
-  TempUnnestState *state;
-  bool isnull[2] = {0,0}; /* needed to say no value is null */
-  Datum tuple_arr[2]; /* used to construct the composite return value */
-  HeapTuple tuple;
-  Datum result; /* the actual composite return value */
 
   /* If the function is being called for the first time */
   if (SRF_IS_FIRSTCALL())
@@ -1751,8 +1760,8 @@ Temporal_unnest(PG_FUNCTION_ARGS)
   /* Stuff done on every call of the function */
   funcctx = SRF_PERCALL_SETUP();
   /* Get state */
-  state = funcctx->user_fctx;
-  /* Stop when we've used up all buckets */
+  TempUnnestState *state = funcctx->user_fctx;
+  /* Stop when we've used up all bins */
   if (state->done)
   {
     /* Switch to memory context appropriate for multiple function calls */
@@ -1766,20 +1775,22 @@ Temporal_unnest(PG_FUNCTION_ARGS)
   }
 
   /* Get value */
-  tuple_arr[0] = state->values[state->i];
+  Datum values[2]; /* used to construct the composite return value */
+  values[0] = state->values[state->i];
   /* Get span set */
   Temporal *rest = temporal_restrict_value(state->temp,
     state->values[state->i], REST_AT);
-  if (!rest)
+  if (! rest)
     elog(ERROR, "Unexpected error with temporal value %s",
       temporal_out(state->temp, OUT_DEFAULT_DECIMAL_DIGITS));
-  tuple_arr[1] = PointerGetDatum(temporal_time(rest));
+  values[1] = PointerGetDatum(temporal_time(rest));
   pfree(rest);
   /* Advance state */
   temporal_unnest_state_next(state);
   /* Form tuple and return */
-  tuple = heap_form_tuple(funcctx->tuple_desc, tuple_arr, isnull);
-  result = HeapTupleGetDatum(tuple);
+  bool isnull[2] = {0,0}; /* needed to say no value is null */
+  HeapTuple tuple = heap_form_tuple(funcctx->tuple_desc, values, isnull);
+  Datum result = HeapTupleGetDatum(tuple);
   SRF_RETURN_NEXT(funcctx, result);
 }
 
@@ -1859,7 +1870,7 @@ Temporal_merge_array(PG_FUNCTION_ARGS)
   ensure_not_empty_array(array);
   int count;
   Temporal **temparr = temparr_extract(array, &count);
-  Temporal *result = temporal_merge_array(temparr, count);
+  Temporal *result = temporal_merge_array((const Temporal **) temparr, count);
   pfree(temparr);
   PG_FREE_IF_COPY(array, 0);
   PG_RETURN_TEMPORAL_P(result);
