@@ -36,6 +36,7 @@
 
 /* C */
 #include <assert.h>
+#include <float.h>
 /* PostgreSQL */
 #include <postgres.h>
 #include <lib/stringinfo.h>
@@ -808,6 +809,59 @@ Stbox_tmax_inc(PG_FUNCTION_ARGS)
   PG_RETURN_BOOL(result);
 }
 
+PGDLLEXPORT Datum Stbox_area(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Stbox_area);
+/**
+ * @ingroup mobilitydb_box_accessor
+ * @brief Return the area of a spatiotemporal box
+ * @sqlfn area()
+ */
+Datum
+Stbox_area(PG_FUNCTION_ARGS)
+{
+  STBox *box = PG_GETARG_STBOX_P(0);
+  bool spheroid = PG_GETARG_BOOL(1);
+  double result = stbox_area(box, spheroid);
+  if (result == DBL_MAX)
+    PG_RETURN_NULL();
+  PG_RETURN_FLOAT8(result);
+}
+
+PGDLLEXPORT Datum Stbox_volume(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Stbox_volume);
+/**
+ * @ingroup mobilitydb_box_accessor
+ * @brief Return the volume of a 3D spatiotemporal box
+ * @sqlfn volume()
+ */
+Datum
+Stbox_volume(PG_FUNCTION_ARGS)
+{
+  STBox *box = PG_GETARG_STBOX_P(0);
+  double result = stbox_volume(box);
+  if (result == DBL_MAX)
+    PG_RETURN_NULL();
+  PG_RETURN_FLOAT8(result);
+}
+
+PGDLLEXPORT Datum Stbox_perimeter(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Stbox_perimeter);
+/**
+ * @ingroup mobilitydb_box_accessor
+ * @brief Return the area of a spatiotemporal box
+ * @sqlfn area()
+ */
+Datum
+Stbox_perimeter(PG_FUNCTION_ARGS)
+{
+  STBox *box = PG_GETARG_STBOX_P(0);
+  bool spheroid = PG_GETARG_BOOL(1);
+  double result = stbox_perimeter(box, spheroid);
+  if (result == DBL_MAX)
+    PG_RETURN_NULL();
+  PG_RETURN_FLOAT8(result);
+}
+
 /*****************************************************************************
  * Transformation functions
  *****************************************************************************/
@@ -919,6 +973,35 @@ Stbox_round(PG_FUNCTION_ARGS)
   PG_RETURN_STBOX_P(stbox_round(box, maxdd));
 }
 
+PGDLLEXPORT Datum Stboxarr_round(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(Stboxarr_round);
+/**
+ * @ingroup mobilitydb_temporal_transf
+ * @brief Return an array of temporal points with the precision of the
+ * coordinates set to a number of decimal places
+ * @sqlfn round()
+ */
+Datum
+Stboxarr_round(PG_FUNCTION_ARGS)
+{
+  ArrayType *array = PG_GETARG_ARRAYTYPE_P(0);
+  /* Return NULL on empty array */
+  int count = ArrayGetNItems(ARR_NDIM(array), ARR_DIMS(array));
+  if (count == 0)
+  {
+    PG_FREE_IF_COPY(array, 0);
+    PG_RETURN_NULL();
+  }
+  int maxdd = PG_GETARG_INT32(1);
+
+  STBox *boxarr = stboxarr_extract(array, &count);
+  STBox *resarr = stboxarr_round(boxarr, count, maxdd);
+  ArrayType *result = stboxarr_to_array(resarr, count);
+  pfree(boxarr);
+  PG_FREE_IF_COPY(array, 0);
+  PG_RETURN_ARRAYTYPE_P(result);
+}
+
 /*****************************************************************************
  * Topological operators
  *****************************************************************************/
@@ -1365,9 +1448,12 @@ Stbox_extent_transfn(PG_FUNCTION_ARGS)
     PG_RETURN_STBOX_P(stbox_cp(box1));
 
   /* Both boxes are not null */
-  ensure_same_srid(stbox_srid(box1), stbox_srid(box2));
   ensure_same_dimensionality(box1->flags, box2->flags);
-  ensure_same_geodetic(box1->flags, box2->flags);
+  if (MEOS_FLAGS_GET_X(box1->flags))
+  {
+    ensure_same_srid(stbox_srid(box1), stbox_srid(box2));
+    ensure_same_geodetic(box1->flags, box2->flags);
+  }
   STBox *result = palloc(sizeof(STBox));
   memcpy(result, box1, sizeof(STBox));
   stbox_expand(box2, result);
