@@ -109,6 +109,7 @@
 #include "general/temporal.h"
 #include "general/type_util.h"
 #include "point/stbox.h"
+#include "point/stbox_index.h"
 /* MobilityDB */
 #include "pg_general/meos_catalog.h"
 #include "pg_general/temporal.h"
@@ -1371,13 +1372,13 @@ Stbox_kdtree_inner_consistent(PG_FUNCTION_ARGS)
 }
 
 /*****************************************************************************
- * SP-GiST leaf-level consistency function
+ * SP-GiST leaf consistency function
  *****************************************************************************/
 
 PGDLLEXPORT Datum Stbox_spgist_leaf_consistent(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(Stbox_spgist_leaf_consistent);
 /**
- * @brief SP-GiST leaf-level consistency function for temporal points
+ * @brief SP-GiST leaf consistency function for temporal points
  */
 Datum
 Stbox_spgist_leaf_consistent(PG_FUNCTION_ARGS)
@@ -1399,10 +1400,10 @@ Stbox_spgist_leaf_consistent(PG_FUNCTION_ARGS)
   {
     StrategyNumber strategy = in->scankeys[i].sk_strategy;
     /* Update the recheck flag according to the strategy */
-    out->recheck |= tpoint_index_recheck(strategy);
+    out->recheck |= stbox_index_recheck(strategy);
 
     if (tpoint_spgist_get_stbox(&in->scankeys[i], &box))
-      result = stbox_index_consistent_leaf(key, &box, strategy);
+      result = stbox_index_leaf_consistent(key, &box, strategy);
     else
       result = false;
     /* If any check is failed, we have found our answer. */
