@@ -143,6 +143,7 @@ SELECT duration(tstzspanset '{[2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2
 SELECT duration(tstzspanset '{(2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2000-01-05,2000-01-06]}', true);
 SELECT duration(tstzspanset '{[2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2000-01-05,2000-01-06]}', true);
 
+
 SELECT numSpans(intspanset '{[1,2),[3,4),[5,6)}');
 SELECT numSpans(floatspanset '{[1,2),[3,4),[5,6)}');
 SELECT numSpans(datespanset '{[2000-01-01,2000-01-02),[2000-01-03,2000-01-04),[2000-01-05,2000-01-06)}');
@@ -198,6 +199,76 @@ SELECT spans(tstzspanset '{[2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2000
 SELECT spans(tstzspanset '{(2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2000-01-05,2000-01-06]}');
 SELECT spans(tstzspanset '{[2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2000-01-05,2000-01-06]}');
 
+-------------------------------------------------------------------------------
+
+-- Maximum number of spans in last argument
+SELECT splitNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 1);
+SELECT splitNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 2);
+SELECT splitNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 3);
+SELECT splitNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 4);
+SELECT splitNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 5);
+SELECT splitNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 6);
+
+SELECT splitNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 1);
+SELECT splitNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 2);
+SELECT splitNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 3);
+SELECT splitNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 4);
+SELECT splitNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 5);
+SELECT splitNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 6);
+
+SELECT splitNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 1);
+SELECT splitNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 2);
+SELECT splitNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 3);
+SELECT splitNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 4);
+SELECT splitNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 5);
+SELECT splitNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 6);
+
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 1);
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 2);
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 3);
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 4);
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 5);
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 6);
+
+/* Errors */
+SELECT splitNspans(tstzspanset '{[2000-01-01, 2000-01-02)}', -1);
+
+-------------------------------------------------------------------------------
+
+-- Maximum number of spans in last argument
+SELECT splitEachNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 1);
+SELECT splitEachNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 2);
+SELECT splitEachNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 3);
+SELECT splitEachNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 4);
+SELECT splitEachNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 5);
+SELECT splitEachNspans(intspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 6);
+
+SELECT splitEachNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 1);
+SELECT splitEachNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 2);
+SELECT splitEachNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 3);
+SELECT splitEachNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 4);
+SELECT splitEachNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 5);
+SELECT splitEachNspans(floatspanset '{[1, 2), [3, 4), [5, 6), [7, 8), [9, 10)}', 6);
+
+SELECT splitEachNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 1);
+SELECT splitEachNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 2);
+SELECT splitEachNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 3);
+SELECT splitEachNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 4);
+SELECT splitEachNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 5);
+SELECT splitEachNspans(datespanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 6);
+
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 1);
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 2);
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 3);
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 4);
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 5);
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02), [2000-01-03, 2000-01-04), [2000-01-05, 2000-01-06), [2000-01-07, 2000-01-08), [2000-01-09, 2000-01-10)}', 6);
+
+/* Errors */
+SELECT splitEachNspans(tstzspanset '{[2000-01-01, 2000-01-02)}', -1);
+
+-------------------------------------------------------------------------------
+
 SELECT numDates(datespanset '{[2000-01-01,2000-01-02)}');
 SELECT numDates(datespanset '{[2000-01-01,2000-01-02),[2000-01-03,2000-01-04),[2000-01-05,2000-01-06)}');
 
@@ -307,6 +378,8 @@ SELECT spanset_hash_extended(tstzspanset '{[2000-01-01,2000-01-02]}', 1) <> span
 -- Transformation functions
 -------------------------------------------------------------------------------
 
+SELECT floor(floatspanset '{[1.5,2.5),[3.5,4.5),[5.5,6.5)}');
+SELECT ceil(floatspanset '{[1.5,2.5),[3.5,4.5),[5.5,6.5)}');
 SELECT round(floatspanset '{[1.12345,2.12345),[3.12345,4.12345),[5.12345,6.12345)}', 2);
 
 SELECT shift(intspanset '{[1,2),[3,4),[5,6)}', 2);
@@ -333,3 +406,4 @@ SELECT shiftScale(tstzspanset '{(2000-01-01,2000-01-02),(2000-01-03,2000-01-04),
 SELECT shiftScale(tstzspanset '{[2000-01-01,2000-01-02),(2000-01-03,2000-01-04),(2000-01-05,2000-01-06]}', '5 min', '1 hour');
 
 -------------------------------------------------------------------------------
+
