@@ -258,6 +258,10 @@ SELECT MAX(minValue(temp)) FROM tbl_tint;
 SELECT round(MAX(minValue(temp))::numeric, 6) FROM tbl_tfloat;
 SELECT MAX(minValue(temp)) FROM tbl_ttext;
 
+SELECT MAX(valueN(temp, numInstants(temp))) FROM tbl_tint;
+SELECT round(MAX(valueN(temp, numInstants(temp)))::numeric, 6) FROM tbl_tfloat;
+SELECT MAX(valueN(temp, numInstants(temp))) FROM tbl_ttext;
+
 SELECT MAX(maxValue(temp)) FROM tbl_tint;
 SELECT round(MAX(maxValue(temp))::numeric, 6) FROM tbl_tfloat;
 SELECT MAX(maxValue(temp)) FROM tbl_ttext;
@@ -474,6 +478,16 @@ SELECT MAX(startTimestamp(tsample(ti, '15 minutes'))) FROM tbl_tint_discseq;
 SELECT MAX(startTimestamp(tsample(seq, '15 minutes'))) FROM tbl_tint_seq;
 SELECT MAX(startTimestamp(tsample(ss, '15 minutes'))) FROM tbl_tint_seqset;
 
+SELECT MAX(numInstants(tsample(inst, '15 minutes', interp := 'step'))) FROM tbl_tint_inst;
+SELECT MAX(numInstants(tsample(ti, '15 minutes', interp := 'step'))) FROM tbl_tint_discseq;
+SELECT MAX(numInstants(tsample(seq, '15 minutes', interp := 'step'))) FROM tbl_tint_seq;
+SELECT MAX(numInstants(tsample(ss, '15 minutes', interp := 'step'))) FROM tbl_tint_seqset;
+
+SELECT MAX(numInstants(tsample(inst, '15 minutes', interp := 'linear'))) FROM tbl_tfloat_inst;
+SELECT MAX(numInstants(tsample(ti, '15 minutes', interp := 'linear'))) FROM tbl_tfloat_discseq;
+SELECT MAX(numInstants(tsample(seq, '15 minutes', interp := 'linear'))) FROM tbl_tfloat_seq;
+SELECT MAX(numInstants(tsample(ss, '15 minutes', interp := 'linear'))) FROM tbl_tfloat_seqset;
+
 -------------------------------------------------------------------------------
 -- stop function
 
