@@ -284,6 +284,18 @@ SELECT tfloat '[-1@2000-01-01, 1@2000-01-02]' / tfloat '[-1@2000-01-01, 1@2000-0
 
 -------------------------------------------------------------------------------
 
+SELECT floor(tfloat '1.5@2000-01-01');
+SELECT floor(tfloat '{1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03}');
+SELECT floor(tfloat '[1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03]');
+SELECT floor(tfloat '{[1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03],[3.5@2000-01-04, 3.5@2000-01-05]}');
+
+SELECT ceil(tfloat '1.5@2000-01-01');
+SELECT ceil(tfloat '{1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03}');
+SELECT ceil(tfloat '[1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03]');
+SELECT ceil(tfloat '{[1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03],[3.5@2000-01-04, 3.5@2000-01-05]}');
+
+-------------------------------------------------------------------------------
+
 SELECT round(tfloat '1.5@2000-01-01',0);
 SELECT round(tfloat '{1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03}',0);
 SELECT round(tfloat '[1.5@2000-01-01, 2.5@2000-01-02, 1.5@2000-01-03]',0);
