@@ -164,26 +164,31 @@ SELECT MAX(Xmin(round(stbox(temp), 6))) FROM tbl_tgeogpoint;
 SELECT MAX(Xmin(round(stbox(temp), 6))) FROM tbl_tgeompoint3D;
 SELECT MAX(Xmin(round(stbox(temp), 6))) FROM tbl_tgeogpoint3D;
 
-/* There is no st_memSize neither MAX for geography. */
-SELECT MAX(st_memSize(getValue(inst))) FROM tbl_tgeompoint_inst;
-SELECT MAX(st_memSize(getValue(inst)::geometry)) FROM tbl_tgeogpoint_inst;
-SELECT MAX(st_memSize(getValue(inst))) FROM tbl_tgeompoint3D_inst;
-SELECT MAX(st_memSize(getValue(inst)::geometry)) FROM tbl_tgeogpoint3D_inst;
+/* There is no ST_MemSize neither MAX for geography. */
+SELECT MAX(ST_MemSize(getValue(inst))) FROM tbl_tgeompoint_inst;
+SELECT MAX(ST_MemSize(getValue(inst)::geometry)) FROM tbl_tgeogpoint_inst;
+SELECT MAX(ST_MemSize(getValue(inst))) FROM tbl_tgeompoint3D_inst;
+SELECT MAX(ST_MemSize(getValue(inst)::geometry)) FROM tbl_tgeogpoint3D_inst;
 
 SELECT MAX(memSize(valueSet(temp))) FROM tbl_tgeompoint;
 SELECT MAX(memSize(valueSet(temp))) FROM tbl_tgeogpoint;
 SELECT MAX(memSize(valueSet(temp))) FROM tbl_tgeompoint3D;
 SELECT MAX(memSize(valueSet(temp))) FROM tbl_tgeogpoint3D;
 
-SELECT MAX(st_memSize(startValue(temp))) FROM tbl_tgeompoint;
-SELECT MAX(st_memSize(startValue(temp)::geometry)) FROM tbl_tgeogpoint;
-SELECT MAX(st_memSize(startValue(temp))) FROM tbl_tgeompoint3D;
-SELECT MAX(st_memSize(startValue(temp)::geometry)) FROM tbl_tgeogpoint3D;
+SELECT MAX(ST_MemSize(startValue(temp))) FROM tbl_tgeompoint;
+SELECT MAX(ST_MemSize(startValue(temp)::geometry)) FROM tbl_tgeogpoint;
+SELECT MAX(ST_MemSize(startValue(temp))) FROM tbl_tgeompoint3D;
+SELECT MAX(ST_MemSize(startValue(temp)::geometry)) FROM tbl_tgeogpoint3D;
 
-SELECT MAX(st_memSize(endValue(temp))) FROM tbl_tgeompoint;
-SELECT MAX(st_memSize(endValue(temp)::geometry)) FROM tbl_tgeogpoint;
-SELECT MAX(st_memSize(endValue(temp))) FROM tbl_tgeompoint3D;
-SELECT MAX(st_memSize(endValue(temp)::geometry)) FROM tbl_tgeogpoint3D;
+SELECT MAX(ST_MemSize(endValue(temp))) FROM tbl_tgeompoint;
+SELECT MAX(ST_MemSize(endValue(temp)::geometry)) FROM tbl_tgeogpoint;
+SELECT MAX(ST_MemSize(endValue(temp))) FROM tbl_tgeompoint3D;
+SELECT MAX(ST_MemSize(endValue(temp)::geometry)) FROM tbl_tgeogpoint3D;
+
+SELECT MAX(ST_MemSize(valueN(temp, 1))) FROM tbl_tgeompoint;
+SELECT MAX(ST_MemSize(valueN(temp, 1)::geometry)) FROM tbl_tgeogpoint;
+SELECT MAX(ST_MemSize(valueN(temp, 1))) FROM tbl_tgeompoint3D;
+SELECT MAX(ST_MemSize(valueN(temp, 1)::geometry)) FROM tbl_tgeogpoint3D;
 
 SELECT MAX(getTimestamp(inst)) FROM tbl_tgeompoint_inst;
 SELECT MAX(getTimestamp(inst)) FROM tbl_tgeogpoint_inst;
@@ -337,6 +342,16 @@ SELECT MAX(startTimestamp(tsample(ti, '15 minutes'))) FROM tbl_tgeompoint_discse
 SELECT MAX(startTimestamp(tsample(seq, '15 minutes'))) FROM tbl_tgeompoint_seq;
 SELECT MAX(startTimestamp(tsample(ss, '15 minutes'))) FROM tbl_tgeompoint_seqset;
 
+SELECT MAX(numInstants(tsample(inst, '15 minutes', interp := 'step'))) FROM tbl_tgeompoint_inst;
+SELECT MAX(numInstants(tsample(ti, '15 minutes', interp := 'step'))) FROM tbl_tgeompoint_discseq;
+SELECT MAX(numInstants(tsample(seq, '15 minutes', interp := 'step'))) FROM tbl_tgeompoint_seq;
+SELECT MAX(numInstants(tsample(ss, '15 minutes', interp := 'step'))) FROM tbl_tgeompoint_seqset;
+
+SELECT MAX(numInstants(tsample(inst, '15 minutes', interp := 'linear'))) FROM tbl_tgeompoint_inst;
+SELECT MAX(numInstants(tsample(ti, '15 minutes', interp := 'linear'))) FROM tbl_tgeompoint_discseq;
+SELECT MAX(numInstants(tsample(seq, '15 minutes', interp := 'linear'))) FROM tbl_tgeompoint_seq;
+SELECT MAX(numInstants(tsample(ss, '15 minutes', interp := 'linear'))) FROM tbl_tgeompoint_seqset;
+
 -------------------------------------------------------------------------------
 -- Stop function
 
@@ -422,8 +437,8 @@ SELECT SUM(numInstants(update(t1.temp, t2.temp))) FROM tbl_tgeogpoint t1, tbl_tg
 -- Local aggregate functions
 ------------------------------------------------------------------------------
 
-SELECT MAX(st_memsize(twCentroid(temp))) FROM tbl_tgeompoint;
-SELECT MAX(st_memsize(twCentroid(temp))) FROM tbl_tgeompoint3D;
+SELECT MAX(ST_memsize(twCentroid(temp))) FROM tbl_tgeompoint;
+SELECT MAX(ST_memsize(twCentroid(temp))) FROM tbl_tgeompoint3D;
 
 ------------------------------------------------------------------------------
 -- Comparison functions and B-tree indexing
