@@ -31,26 +31,61 @@
 -- Multidimensional tiling
 -------------------------------------------------------------------------------
 
-SELECT tileList(tgeompoint '[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0) LIMIT 3;
-SELECT tileList(tgeompoint 'SRID=3812;[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0, geometry 'Point(3 3)') LIMIT 3;
-SELECT tileList(tgeompoint '[Point(3 3 3)@2000-01-15, Point(15 15 15)@2000-01-25]'::stbox, 2.0, geometry 'Point(3 3 3)') LIMIT 3;
-SELECT tileList(tgeompoint '[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0, interval '2 days', 'Point(3 3)', '2000-01-15') LIMIT 3;
-SELECT tileList(tgeompoint '[Point(3 3 3)@2000-01-15, Point(15 15 15)@2000-01-25]'::stbox, 2.0, interval '2 days', 'Point(3 3 3)', '2000-01-15') LIMIT 3;
+SELECT spaceTiles(tgeompoint '[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0) LIMIT 3;
+SELECT spaceTiles(tgeompoint 'SRID=3812;[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0, geometry 'Point(3 3)') LIMIT 3;
+SELECT spaceTiles(tgeompoint '[Point(3 3 3)@2000-01-15, Point(15 15 15)@2000-01-25]'::stbox, 2.0, geometry 'Point(3 3 3)') LIMIT 3;
+SELECT spaceTimeTiles(tgeompoint '[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0, interval '2 days', 'Point(3 3)', '2000-01-15') LIMIT 3;
+SELECT spaceTimeTiles(tgeompoint '[Point(3 3 3)@2000-01-15, Point(15 15 15)@2000-01-25]'::stbox, 2.0, interval '2 days', 'Point(3 3 3)', '2000-01-15') LIMIT 3;
 /* Errors */
-SELECT tileList(tgeompoint '[Point(3 3 3)@2000-01-15, Point(15 15 15)@2000-01-25]'::stbox, 2.0, geometry 'Point(3 3)');
-SELECT tileList(tgeompoint 'SRID=3812;[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0, geometry 'SRID=5676;Point(1 1)');
-SELECT tileList(tgeogpoint '[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0);
+SELECT spaceTiles(tgeompoint '[Point(3 3 3)@2000-01-15, Point(15 15 15)@2000-01-25]'::stbox, 2.0, geometry 'Point(3 3)');
+SELECT spaceTiles(tgeompoint 'SRID=3812;[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0, geometry 'SRID=5676;Point(1 1)');
+SELECT spaceTiles(tgeogpoint '[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]'::stbox, 2.0);
 
-SELECT tile(geometry 'Point(3 3)', 2.0);
-SELECT tile(geometry 'Point(3 3 3)', 2.0);
-SELECT tile(geometry 'Point(3 3)', timestamptz '2000-01-15', 2.0, interval '2 days');
-SELECT tile(geometry 'Point(3 3)', timestamptz '2000-01-15', 2.0, interval '2 days');
-SELECT tile(geometry 'Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'Point(1 1 1)', '2020-06-15');
+SELECT getSpaceTile(geometry 'Point(3 3)', 2.0);
+SELECT getSpaceTile(geometry 'Point(3 3 3)', 2.0);
+SELECT getStboxTimeTile(timestamptz '2000-01-15', interval '2 days');
+SELECT getStboxTimeTile(timestamptz '2000-01-15', interval '2 days', '2020-06-15');
+SELECT getSpaceTimeTile(geometry 'Point(3 3)', timestamptz '2000-01-15', 2.0, interval '2 days');
+SELECT getSpaceTimeTile(geometry 'Point(3 3)', timestamptz '2000-01-15', 2.0, interval '2 days');
+SELECT getSpaceTimeTile(geometry 'Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'Point(1 1 1)', '2020-06-15');
 
-SELECT tile(geometry 'SRID=3812;Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'SRID=3812;Point(1 1 1)', '2020-06-15');
+SELECT getSpaceTimeTile(geometry 'SRID=3812;Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'SRID=3812;Point(1 1 1)', '2020-06-15');
 /* Errors */
-SELECT tile(geometry 'Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'Point(1 1)', '2020-06-15');
-SELECT tile(geometry 'SRID=3812;Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'SRID=2154;Point(1 1)', '2020-06-15');
+SELECT getSpaceTimeTile(geometry 'Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'Point(1 1)', '2020-06-15');
+SELECT getSpaceTimeTile(geometry 'SRID=3812;Point(3 3 3)', timestamptz '2000-01-15', 2.0, interval '2 days', geometry 'SRID=2154;Point(1 1)', '2020-06-15');
+
+-------------------------------------------------------------------------------
+-- Space boxes
+-------------------------------------------------------------------------------
+
+SELECT round(spaceBoxes(tgeompoint '[Point(1 1)@2000-01-01, Point(10 10)@2000-01-10]', 2.0), 6);
+SELECT round(spaceBoxes(tgeompoint 'SRID=3812;[Point(1 1)@2000-01-01, Point(10 10)@2000-01-10]', 2.0, geometry 'Point(1 1)'), 6);
+SELECT round(spaceBoxes(tgeompoint '[Point(1 1 1)@2000-01-01, Point(10 10 10)@2000-01-10]', 2.0, geometry 'Point(1 1 1)'), 6);
+
+/* Errors */
+SELECT spaceBoxes(tgeompoint '[Point(1 1 1)@2000-01-01, Point(10 10 10)@2000-01-10]', 2.0, geometry 'Point(1 1)');
+SELECT spaceBoxes(tgeompoint 'SRID=3812;[Point(1 1)@2000-01-01, Point(10 10)@2000-01-10]', 2.0, geometry 'SRID=5676;Point(1 1)');
+
+-------------------------------------------------------------------------------
+-- time boxes
+-------------------------------------------------------------------------------
+
+SELECT round(timeBoxes(tgeompoint '[Point(1 1)@2000-01-01, Point(10 10)@2000-01-10]', interval '2 days', '2000-01-01'), 6);
+SELECT round(timeBoxes(tgeompoint '[Point(1 1 1)@2000-01-01, Point(10 10 10)@2000-01-10]', interval '2 days', '2000-01-01'));
+
+/* Errors */
+SELECT timeBoxes(tgeompoint '[Point(1 1 1)@2000-01-01, Point(10 10 10)@2000-01-10]', interval '2 months', '2000-01-01');
+
+-------------------------------------------------------------------------------
+-- SpaceTime boxes
+-------------------------------------------------------------------------------
+
+SELECT round(spaceTimeBoxes(tgeompoint '[Point(1 1)@2000-01-01, Point(10 10)@2000-01-10]', 2.0, interval '2 days', 'Point(1 1)', '2000-01-01'), 6);
+SELECT round(spaceTimeBoxes(tgeompoint '[Point(1 1 1)@2000-01-01, Point(10 10 10)@2000-01-10]', 2.0, interval '2 days', 'Point(1 1 1)', '2000-01-01'));
+
+/* Errors */
+SELECT spaceTimeBoxes(tgeompoint '[Point(1 1 1)@2000-01-01, Point(10 10 10)@2000-01-10]', 2.0, interval '2 days', 'Point(1 1)', '2000-01-01');
+SELECT spaceTimeBoxes(tgeompoint 'SRID=3812;[Point(3 3)@2000-01-15, Point(15 15)@2000-01-25]', 2.0, interval '2 days', 'SRID=5676;Point(1 1)', '2000-01-01');
 
 -------------------------------------------------------------------------------
 -- Space split
