@@ -30,7 +30,8 @@
 
 /* Internal prototype */
 static CIRC_NODE* circ_nodes_merge(CIRC_NODE** nodes, int num_nodes);
-// static double circ_tree_distance_tree_internal(const CIRC_NODE* n1, const CIRC_NODE* n2, double threshold, double* min_dist, double* max_dist, GEOGRAPHIC_POINT* closest1, GEOGRAPHIC_POINT* closest2);
+// MobilityDB removed static
+double circ_tree_distance_tree_internal(const CIRC_NODE* n1, const CIRC_NODE* n2, double threshold, double* min_dist, double* max_dist, GEOGRAPHIC_POINT* closest1, GEOGRAPHIC_POINT* closest2);
 
 
 /**
@@ -674,7 +675,6 @@ circ_internal_nodes_sort(CIRC_NODE **nodes, uint32_t num_nodes, const CIRC_NODE
 
 /***********************************************************************/
 
-// static
 double
 circ_tree_distance_tree_internal(const CIRC_NODE* n1, const CIRC_NODE* n2, double threshold, double* min_dist, double* max_dist, GEOGRAPHIC_POINT* closest1, GEOGRAPHIC_POINT* closest2)
 {
@@ -771,11 +771,11 @@ circ_tree_distance_tree_internal(const CIRC_NODE* n1, const CIRC_NODE* n2, doubl
 			/* Node 2 is a point */
 			else
 			{
-				geographic_point_init(n2->p1->x, n2->p1->y, &gp1);
+				geographic_point_init(n2->p1->x, n2->p1->y, &gp2);
 				geographic_point_init(n1->p1->x, n1->p1->y, &(e.start));
 				geographic_point_init(n1->p2->x, n1->p2->y, &(e.end));
-				close1 = gp1;
-				d = edge_distance_to_point(&e, &gp1, &close2);
+				close2 = gp2;
+				d = edge_distance_to_point(&e, &gp2, &close1);
 			}
 			LWDEBUGF(4, "  got distance %g", d);
 		}
@@ -874,27 +874,27 @@ void circ_tree_print(const CIRC_NODE* node, int depth)
 
 	if (circ_node_is_leaf(node))
 	{
-		printf("%*s[%d] C(%.5g %.5g) R(%.5g) ((%.5g %.5g),(%.5g,%.5g))",
+		printf("%*s[%d] C(%.8g %.8g) R(%.8g) ((%.8g %.8g),(%.8g,%.8g))",
 		  3*depth + 6, "NODE", node->edge_num,
 		  node->center.lon, node->center.lat,
 		  node->radius,
 		  node->p1->x, node->p1->y,
 		  node->p2->x, node->p2->y
 		);
-  		if ( node->geom_type )
-  		{
-  			printf(" %s", lwtype_name(node->geom_type));
-  		}
-  		if ( node->geom_type == POLYGONTYPE )
-  		{
-  			printf(" O(%.5g %.5g)", node->pt_outside.x, node->pt_outside.y);
-  		}
-  		printf("\n");
+		if ( node->geom_type )
+		{
+			printf(" %s", lwtype_name(node->geom_type));
+		}
+		if ( node->geom_type == POLYGONTYPE )
+		{
+			printf(" O(%.8g %.8g)", node->pt_outside.x, node->pt_outside.y);
+		}
+		printf("\n");
 
 	}
 	else
 	{
-		printf("%*s C(%.5g %.5g) R(%.5g)",
+		printf("%*s C(%.8g %.8g) R(%.8g)",
 		  3*depth + 6, "NODE",
 		  node->center.lon, node->center.lat,
 		  node->radius
@@ -903,10 +903,10 @@ void circ_tree_print(const CIRC_NODE* node, int depth)
 		{
 			printf(" %s", lwtype_name(node->geom_type));
 		}
-  		if ( node->geom_type == POLYGONTYPE )
-  		{
-  			printf(" O(%.15g %.15g)", node->pt_outside.x, node->pt_outside.y);
-  		}
+		if ( node->geom_type == POLYGONTYPE )
+		{
+			printf(" O(%.15g %.15g)", node->pt_outside.x, node->pt_outside.y);
+		}
 		printf("\n");
 	}
 	for ( i = 0; i < node->num_nodes; i++ )
@@ -916,12 +916,13 @@ void circ_tree_print(const CIRC_NODE* node, int depth)
 	return;
 }
 
+
 static CIRC_NODE*
 lwpoint_calculate_circ_tree(const LWPOINT* lwpoint)
 {
 	CIRC_NODE* node;
 	node = circ_tree_new(lwpoint->point);
-	node->geom_type = lwgeom_get_type((LWGEOM*)lwpoint);
+	node->geom_type = lwgeom_get_type((LWGEOM*)lwpoint);;
 	return node;
 }
 
@@ -1026,3 +1027,83 @@ lwgeom_calculate_circ_tree(const LWGEOM* lwgeom)
 	}
 
 }
+
+
+/***********************************************************************
+ * Closest point and closest line functions for geographies.
+ ***********************************************************************/
+
+LWGEOM *
+geography_tree_closestpoint(const LWGEOM* lwgeom1, const LWGEOM* lwgeom2, double threshold)
+{
+	CIRC_NODE* circ_tree1 = NULL;
+	CIRC_NODE* circ_tree2 = NULL;
+	double min_dist = FLT_MAX;
+	double max_dist = FLT_MAX;
+	GEOGRAPHIC_POINT closest1, closest2;
+	LWGEOM *result;
+	POINT4D p;
+
+	circ_tree1 = lwgeom_calculate_circ_tree(lwgeom1);
+	circ_tree2 = lwgeom_calculate_circ_tree(lwgeom2);
+
+	/* Quietly decrease the threshold just a little to avoid cases where */
+	/* the actual spheroid distance is larger than the sphere distance */
+	/* causing the return value to be larger than the threshold value */
+	// double threshold_radians = 0.95 * threshold / spheroid->radius;
+	double threshold_radians = threshold / WGS84_RADIUS;
+
+	circ_tree_distance_tree_internal(
+		circ_tree1, circ_tree2, threshold_radians,
+		&min_dist, &max_dist, &closest1, &closest2);
+
+	p.x = rad2deg(closest1.lon);
+	p.y = rad2deg(closest1.lat);
+	result = (LWGEOM *)lwpoint_make2d(lwgeom_get_srid(lwgeom1), p.x, p.y);
+
+	circ_tree_free(circ_tree1);
+	circ_tree_free(circ_tree2);
+	return result;
+}
+
+
+LWGEOM *
+geography_tree_shortestline(const LWGEOM* lwgeom1, const LWGEOM* lwgeom2, double threshold, const SPHEROID *spheroid)
+{
+  CIRC_NODE* circ_tree1 = NULL;
+  CIRC_NODE* circ_tree2 = NULL;
+  double min_dist = FLT_MAX;
+  double max_dist = FLT_MAX;
+  GEOGRAPHIC_POINT closest1, closest2;
+  LWGEOM *geoms[2];
+  LWGEOM *result;
+  POINT4D p1, p2;
+  uint32_t srid = lwgeom1->srid;
+
+  circ_tree1 = lwgeom_calculate_circ_tree(lwgeom1);
+  circ_tree2 = lwgeom_calculate_circ_tree(lwgeom2);
+
+  /* Quietly decrease the threshold just a little to avoid cases where */
+  /* the actual spheroid distance is larger than the sphere distance */
+  /* causing the return value to be larger than the threshold value */
+  // double threshold_radians = 0.95 * threshold / spheroid->radius;
+  double threshold_radians = threshold / spheroid->radius;
+
+  circ_tree_distance_tree_internal(circ_tree1, circ_tree2, threshold_radians,
+      &min_dist, &max_dist, &closest1, &closest2);
+
+  p1.x = rad2deg(closest1.lon);
+  p1.y = rad2deg(closest1.lat);
+  p2.x = rad2deg(closest2.lon);
+  p2.y = rad2deg(closest2.lat);
+
+  geoms[0] = (LWGEOM *)lwpoint_make2d(srid, p1.x, p1.y);
+  geoms[1] = (LWGEOM *)lwpoint_make2d(srid, p2.x, p2.y);
+  result = (LWGEOM *)lwline_from_lwgeom_array(srid, 2, geoms);
+
+  lwgeom_free(geoms[0]);
+  lwgeom_free(geoms[1]);
+  circ_tree_free(circ_tree1);
+  circ_tree_free(circ_tree2);
+  return result;
+}
